@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -40,7 +40,6 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.regex.Pattern;
 
-import com.google.common.collect.Lists;
 import com.puppycrawl.tools.checkstyle.BriefUtLogger;
 import com.puppycrawl.tools.checkstyle.Checker;
 import com.puppycrawl.tools.checkstyle.ConfigurationLoader;
@@ -62,6 +61,13 @@ public class BaseCheckTestSupport {
 
     protected final ByteArrayOutputStream stream = new ByteArrayOutputStream();
 
+    /**
+     * Returns {@link Configuration} based on Google's checks xml-configuration (google_checks.xml).
+     * This implementation uses {@link ConfigurationLoader} in order to load configuration
+     * from xml-file.
+     * @return {@link Configuration} based on Google's checks xml-configuration (google_checks.xml).
+     * @throws CheckstyleException if exception occurs during configuration loading.
+     */
     protected static Configuration getConfiguration() throws CheckstyleException {
         if (configuration == null) {
             configuration = ConfigurationLoader.loadConfiguration(XML_NAME, new PropertiesExpander(
@@ -71,10 +77,21 @@ public class BaseCheckTestSupport {
         return configuration;
     }
 
-    protected static DefaultConfiguration createCheckConfig(Class<?> clazz) {
+    /**
+     * Creates {@link DefaultConfiguration} instance for the given check class.
+     * @param clazz check class.
+     * @return {@link DefaultConfiguration} instance.
+     */
+    private static DefaultConfiguration createCheckConfig(Class<?> clazz) {
         return new DefaultConfiguration(clazz.getName());
     }
 
+    /**
+     * Creates {@link Checker} instance based on specified {@link Configuration}.
+     * @param checkConfig {@link Configuration} instance.
+     * @return {@link Checker} instance.
+     * @throws CheckstyleException if an exception occurs during checker configuration.
+     */
     protected Checker createChecker(Configuration checkConfig)
             throws Exception {
         final DefaultConfiguration dc = createCheckerConfig(checkConfig);
@@ -90,6 +107,12 @@ public class BaseCheckTestSupport {
         return checker;
     }
 
+    /**
+     * Creates {@link DefaultConfiguration} or the {@link Checker}.
+     * based on the given {@link Configuration}.
+     * @param config {@link Configuration} instance.
+     * @return {@link DefaultConfiguration} for the {@link Checker}.
+     */
     protected DefaultConfiguration createCheckerConfig(Configuration config) {
         final DefaultConfiguration dc =
                 new DefaultConfiguration("configuration");
@@ -101,11 +124,32 @@ public class BaseCheckTestSupport {
         return dc;
     }
 
+    /**
+     * Returns canonical path for the file with the given file name.
+     * The path is formed based on the specific root location.
+     * This implementation uses 'src/it/resources/com/google/checkstyle/test/' as a root location.
+     * @param fileName file name.
+     * @return canonical path for the the file with the given file name.
+     * @throws IOException if I/O exception occurs while forming the path.
+     */
     protected String getPath(String fileName) throws IOException {
         return new File("src/it/resources/com/google/checkstyle/test/" + fileName)
                 .getCanonicalPath();
     }
 
+    /**
+     * Performs verification of the file with given file name. Uses specified configuration.
+     * Expected messages are represented by the array of strings, warning line numbers are
+     * represented by the array of integers.
+     * This implementation uses overloaded
+     * {@link BaseCheckTestSupport#verify(Checker, File[], String, String[], Integer...)} method
+     * inside.
+     * @param config configuration.
+     * @param fileName file name to verify.
+     * @param expected an array of expected messages.
+     * @param warnsExpected an array of expected warning numbers.
+     * @throws Exception if exception occurs during verification process.
+     */
     protected void verify(Configuration config, String fileName, String[] expected,
             Integer... warnsExpected) throws Exception {
         verify(createChecker(config),
@@ -113,23 +157,32 @@ public class BaseCheckTestSupport {
                 fileName, expected, warnsExpected);
     }
 
+    /**
+     * Performs verification of files. Uses provided {@link Checker} instance.
+     * @param checker {@link Checker} instance.
+     * @param processedFiles files to process.
+     * @param messageFileName message file name.
+     * @param expected an array of expected messages.
+     * @param warnsExpected an array of expected warning line numbers.
+     * @throws Exception if exception occurs during verification process.
+     */
     protected void verify(Checker checker,
             File[] processedFiles,
             String messageFileName,
             String[] expected,
             Integer... warnsExpected)
-        throws Exception {
+            throws Exception {
         stream.flush();
-        final List<File> theFiles = Lists.newArrayList();
+        final List<File> theFiles = new ArrayList<>();
         Collections.addAll(theFiles, processedFiles);
-        final List<Integer> theWarnings = Lists.newArrayList();
+        final List<Integer> theWarnings = new ArrayList<>();
         Collections.addAll(theWarnings, warnsExpected);
         final int errs = checker.process(theFiles);
 
         // process each of the lines
         final ByteArrayInputStream inputStream =
                 new ByteArrayInputStream(stream.toByteArray());
-        try (final LineNumberReader lnr = new LineNumberReader(
+        try (LineNumberReader lnr = new LineNumberReader(
                 new InputStreamReader(inputStream, StandardCharsets.UTF_8))) {
 
             int previousLineNumber = 0;
@@ -143,8 +196,8 @@ public class BaseCheckTestSupport {
                 parseInt = parseInt.substring(0, parseInt.indexOf(':'));
                 final int lineNumber = Integer.parseInt(parseInt);
                 assertTrue("input file is expected to have a warning comment on line number "
-                        + lineNumber, theWarnings.remove((Integer) lineNumber)
-                            || previousLineNumber == lineNumber);
+                        + lineNumber, previousLineNumber == lineNumber
+                            || theWarnings.remove((Integer) lineNumber));
                 previousLineNumber = lineNumber;
             }
 
@@ -193,20 +246,73 @@ public class BaseCheckTestSupport {
         return null;
     }
 
+    /**
+     * Returns {@link Configuration} instance for the given check name.
+     * This implementation uses {@link BaseCheckTestSupport#getConfiguration()} method inside.
+     * @param checkName check name.
+     * @return {@link Configuration} instance for the given check name.
+     * @throws CheckstyleException if exception occurs during configuration loading.
+     */
     protected static Configuration getCheckConfig(String checkName) throws CheckstyleException {
-        Configuration result = null;
+        final Configuration result;
+        final List<Configuration> configs = getCheckConfigs(checkName);
+        if (configs.size() == 1) {
+            result = configs.get(0);
+        }
+        else {
+            throw new IllegalStateException("multiple instances of the same Check are detected");
+        }
+        return result;
+    }
+
+    /**
+     * Returns {@link Configuration} instance for the given check name.
+     * This implementation uses {@link BaseCheckTestSupport#getConfiguration()} method inside.
+     * @param checkName check name.
+     * @return {@link Configuration} instance for the given check name.
+     * @throws CheckstyleException if exception occurs during configuration loading.
+     */
+    protected static Configuration getCheckConfig(String checkName, String checkId)
+            throws CheckstyleException {
+        final Configuration result;
+        final List<Configuration> configs = getCheckConfigs(checkName);
+        if (configs.size() == 1) {
+            result = configs.get(0);
+        }
+        else {
+            result = configs.stream().filter(conf -> {
+                try {
+                    return conf.getAttribute("id").equals(checkId);
+                }
+                catch (CheckstyleException ex) {
+                    throw new IllegalStateException("problem to get ID attribute from " + conf, ex);
+                }
+            })
+            .findFirst().orElseGet(null);
+        }
+        return result;
+    }
+
+    /**
+     * Returns a list of all {@link Configuration} instances for the given check name.
+     * This implementation uses {@link BaseCheckTestSupport#getConfiguration()} method inside.
+     * @param checkName check name.
+     * @return {@link Configuration} instance for the given check name.
+     * @throws CheckstyleException if exception occurs during configuration loading.
+     */
+    protected static List<Configuration> getCheckConfigs(String checkName)
+            throws CheckstyleException {
+        final List<Configuration> result = new ArrayList<>();
         for (Configuration currentConfig : getConfiguration().getChildren()) {
             if ("TreeWalker".equals(currentConfig.getName())) {
                 for (Configuration checkConfig : currentConfig.getChildren()) {
                     if (checkName.equals(checkConfig.getName())) {
-                        result = checkConfig;
-                        break;
+                        result.add(checkConfig);
                     }
                 }
             }
             else if (checkName.equals(currentConfig.getName())) {
-                result = currentConfig;
-                break;
+                result.add(currentConfig);
             }
         }
         return result;
@@ -220,6 +326,13 @@ public class BaseCheckTestSupport {
         return path;
     }
 
+    /**
+     * Returns an array of integers which represents the warning line numbers in the file
+     * with the given file name.
+     * @param fileName file name.
+     * @return an array of integers which represents the warning line numbers.
+     * @throws IOException if I/O exception occurs while reading the file.
+     */
     protected Integer[] getLinesWithWarn(String fileName) throws IOException {
         final List<Integer> result = new ArrayList<>();
         try (BufferedReader br = new BufferedReader(new InputStreamReader(
