@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -23,24 +23,23 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.net.URI;
 import java.util.ArrayDeque;
+import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Deque;
+import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
+import java.util.Optional;
 
 import javax.xml.parsers.ParserConfigurationException;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.xml.sax.Attributes;
 import org.xml.sax.InputSource;
 import org.xml.sax.SAXException;
 import org.xml.sax.SAXParseException;
 
-import com.google.common.annotations.VisibleForTesting;
-import com.google.common.collect.Lists;
-import com.google.common.collect.Maps;
 import com.puppycrawl.tools.checkstyle.api.AbstractLoader;
 import com.puppycrawl.tools.checkstyle.api.CheckstyleException;
 import com.puppycrawl.tools.checkstyle.api.Configuration;
@@ -53,8 +52,6 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
  * @author Oliver Burn
  */
 public final class ConfigurationLoader {
-    /** Logger for ConfigurationLoader. */
-    private static final Log LOG = LogFactory.getLog(ConfigurationLoader.class);
 
     /** The public ID for version 1_0 of the configuration dtd. */
     private static final String DTD_PUBLIC_ID_1_0 =
@@ -119,7 +116,7 @@ public final class ConfigurationLoader {
      */
     private ConfigurationLoader(final PropertyResolver overrideProps,
                                 final boolean omitIgnoredModules)
-        throws ParserConfigurationException, SAXException {
+            throws ParserConfigurationException, SAXException {
         saxHandler = new InternalLoader();
         overridePropsResolver = overrideProps;
         this.omitIgnoredModules = omitIgnoredModules;
@@ -130,7 +127,7 @@ public final class ConfigurationLoader {
      * @return map between local resources and dtd ids.
      */
     private static Map<String, String> createIdToResourceNameMap() {
-        final Map<String, String> map = Maps.newHashMap();
+        final Map<String, String> map = new HashMap<>();
         map.put(DTD_PUBLIC_ID_1_0, DTD_RESOURCE_NAME_1_0);
         map.put(DTD_PUBLIC_ID_1_1, DTD_RESOURCE_NAME_1_1);
         map.put(DTD_PUBLIC_ID_1_2, DTD_RESOURCE_NAME_1_2);
@@ -149,7 +146,7 @@ public final class ConfigurationLoader {
      * @throws SAXException if an error occurs
      */
     private void parseInputSource(InputSource source)
-        throws IOException, SAXException {
+            throws IOException, SAXException {
         saxHandler.parseInputSource(source);
     }
 
@@ -177,7 +174,7 @@ public final class ConfigurationLoader {
      */
     public static Configuration loadConfiguration(String config,
         PropertyResolver overridePropsResolver, boolean omitIgnoredModules)
-        throws CheckstyleException {
+            throws CheckstyleException {
         // figure out if this is a File or a URL
         final URI uri = CommonUtils.getUriByFilename(config);
         final InputSource source = new InputSource(uri.toString());
@@ -205,7 +202,7 @@ public final class ConfigurationLoader {
     @Deprecated
     public static Configuration loadConfiguration(InputStream configStream,
         PropertyResolver overridePropsResolver, boolean omitIgnoredModules)
-        throws CheckstyleException {
+            throws CheckstyleException {
         return loadConfiguration(new InputSource(configStream),
                                  overridePropsResolver, omitIgnoredModules);
     }
@@ -224,7 +221,7 @@ public final class ConfigurationLoader {
      */
     public static Configuration loadConfiguration(InputSource configSource,
             PropertyResolver overridePropsResolver, boolean omitIgnoredModules)
-        throws CheckstyleException {
+            throws CheckstyleException {
         try {
             final ConfigurationLoader loader =
                 new ConfigurationLoader(overridePropsResolver,
@@ -247,8 +244,6 @@ public final class ConfigurationLoader {
      * Replaces {@code ${xxx}} style constructions in the given value
      * with the string value of the corresponding data types.
      *
-     * <p>The method is package visible to facilitate testing.
-     *
      * <p>Code copied from ant -
      * http://cvs.apache.org/viewcvs/jakarta-ant/src/main/org/apache/tools/ant/ProjectHelper.java
      *
@@ -266,16 +261,15 @@ public final class ConfigurationLoader {
      *                           {@code ${} without a closing
      *                           {@code }}
      */
-    @VisibleForTesting
-    static String replaceProperties(
+    private static String replaceProperties(
             String value, PropertyResolver props, String defaultValue)
-        throws CheckstyleException {
+            throws CheckstyleException {
         if (value == null) {
             return null;
         }
 
-        final List<String> fragments = Lists.newArrayList();
-        final List<String> propertyRefs = Lists.newArrayList();
+        final List<String> fragments = new ArrayList<>();
+        final List<String> propertyRefs = new ArrayList<>();
         parsePropertyString(value, fragments, propertyRefs);
 
         final StringBuilder sb = new StringBuilder();
@@ -323,7 +317,7 @@ public final class ConfigurationLoader {
     private static void parsePropertyString(String value,
                                            List<String> fragments,
                                            List<String> propertyRefs)
-        throws CheckstyleException {
+            throws CheckstyleException {
         int prev = 0;
         //search for the next instance of $ from the 'prev' position
         int pos = value.indexOf(DOLLAR_SIGN, prev);
@@ -405,7 +399,7 @@ public final class ConfigurationLoader {
          * @throws ParserConfigurationException if an error occurs
          */
         InternalLoader()
-            throws SAXException, ParserConfigurationException {
+                throws SAXException, ParserConfigurationException {
             super(createIdToResourceNameMap());
         }
 
@@ -414,7 +408,7 @@ public final class ConfigurationLoader {
                                  String localName,
                                  String qName,
                                  Attributes attributes)
-            throws SAXException {
+                throws SAXException {
             if (qName.equals(MODULE)) {
                 //create configuration
                 final String name = attributes.getValue(NAME);
@@ -470,21 +464,24 @@ public final class ConfigurationLoader {
         @Override
         public void endElement(String uri,
                                String localName,
-                               String qName) {
+                               String qName) throws SAXException {
             if (qName.equals(MODULE)) {
 
                 final Configuration recentModule =
                     configStack.pop();
 
-                // remove modules with severity ignore if these modules should
-                // be omitted
+                // get severity attribute if it exists
                 SeverityLevel level = null;
-                try {
-                    final String severity = recentModule.getAttribute(SEVERITY);
-                    level = SeverityLevel.getInstance(severity);
-                }
-                catch (final CheckstyleException ex) {
-                    LOG.debug("Severity not set, ignoring exception", ex);
+                if (containsAttribute(recentModule, SEVERITY)) {
+                    try {
+                        final String severity = recentModule.getAttribute(SEVERITY);
+                        level = SeverityLevel.getInstance(severity);
+                    }
+                    catch (final CheckstyleException ex) {
+                        throw new SAXException(
+                                "Problem during accessing '" + SEVERITY + "' attribute for "
+                                        + recentModule.getName(), ex);
+                    }
                 }
 
                 // omit this module if these should be omitted and the module
@@ -499,5 +496,18 @@ public final class ConfigurationLoader {
                 }
             }
         }
+
+        /**
+         * Util method to recheck attribute in module.
+         * @param module module to check
+         * @param attributeName name of attribute in module to find
+         * @return true if attribute is present in module
+         */
+        private boolean containsAttribute(Configuration module, String attributeName) {
+            final String[] names = module.getAttributeNames();
+            final Optional<String> result = Arrays.stream(names)
+                    .filter(name -> name.equals(attributeName)).findFirst();
+            return result.isPresent();
+        }
     }
 }
