@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -25,6 +25,7 @@ import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.net.URL;
+import java.util.ArrayList;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
@@ -42,17 +43,18 @@ import org.apache.tools.ant.types.FileSet;
 import org.apache.tools.ant.types.Path;
 import org.apache.tools.ant.types.Reference;
 
-import com.google.common.collect.Lists;
 import com.google.common.io.Closeables;
 import com.puppycrawl.tools.checkstyle.Checker;
 import com.puppycrawl.tools.checkstyle.ConfigurationLoader;
-import com.puppycrawl.tools.checkstyle.DefaultContext;
 import com.puppycrawl.tools.checkstyle.DefaultLogger;
+import com.puppycrawl.tools.checkstyle.ModuleFactory;
+import com.puppycrawl.tools.checkstyle.PackageObjectFactory;
 import com.puppycrawl.tools.checkstyle.PropertiesExpander;
 import com.puppycrawl.tools.checkstyle.XMLLogger;
 import com.puppycrawl.tools.checkstyle.api.AuditListener;
 import com.puppycrawl.tools.checkstyle.api.CheckstyleException;
 import com.puppycrawl.tools.checkstyle.api.Configuration;
+import com.puppycrawl.tools.checkstyle.api.RootModule;
 import com.puppycrawl.tools.checkstyle.api.SeverityLevel;
 import com.puppycrawl.tools.checkstyle.api.SeverityLevelCounter;
 
@@ -71,13 +73,13 @@ public class CheckstyleAntTask extends Task {
     private static final String TIME_SUFFIX = " ms.";
 
     /** Contains the filesets to process. */
-    private final List<FileSet> fileSets = Lists.newArrayList();
+    private final List<FileSet> fileSets = new ArrayList<>();
 
     /** Contains the formatters to log to. */
-    private final List<Formatter> formatters = Lists.newArrayList();
+    private final List<Formatter> formatters = new ArrayList<>();
 
     /** Contains the Properties to override. */
-    private final List<Property> overrideProps = Lists.newArrayList();
+    private final List<Property> overrideProps = new ArrayList<>();
 
     /** Class path to locate class files. */
     private Path classpath;
@@ -115,7 +117,7 @@ public class CheckstyleAntTask extends Task {
     ////////////////////////////////////////////////////////////////////////////
 
     /**
-     * Tells this task to set the named property to "true" when there
+     * Tells this task to write failure message to the named property when there
      * is a violation.
      * @param propertyName the name of the property to set
      *                      in the event of an failure.
@@ -226,6 +228,8 @@ public class CheckstyleAntTask extends Task {
      * @param url the URL of the configuration to use
      * @deprecated please use setConfigUrl instead
      */
+    // -@cs[AbbreviationAsWordInName] Should be removed at 7.0 version,
+    // we keep for some time to avoid braking compatibility.
     @Deprecated
     public void setConfigURL(URL url) {
         setConfigUrl(url);
@@ -260,7 +264,7 @@ public class CheckstyleAntTask extends Task {
     }
 
     ////////////////////////////////////////////////////////////////////////////
-    // Setters for Checker configuration attributes
+    // Setters for Root Module's configuration attributes
     ////////////////////////////////////////////////////////////////////////////
 
     /**
@@ -283,7 +287,7 @@ public class CheckstyleAntTask extends Task {
         try {
             // output version info in debug mode
             final ResourceBundle compilationProperties = ResourceBundle
-                    .getBundle("checkstylecompilation");
+                    .getBundle("checkstylecompilation", Locale.ROOT);
             final String version = compilationProperties
                     .getString("checkstyle.compile.version");
             final String compileTimestamp = compilationProperties
@@ -314,36 +318,45 @@ public class CheckstyleAntTask extends Task {
      * @param checkstyleVersion Checkstyle compile version.
      */
     private void realExecute(String checkstyleVersion) {
-        // Create the checker
-        Checker checker = null;
+        // Create the root module
+        RootModule rootModule = null;
         try {
-            checker = createChecker();
+            rootModule = createRootModule();
 
             // setup the listeners
             final AuditListener[] listeners = getListeners();
             for (AuditListener element : listeners) {
-                checker.addListener(element);
+                rootModule.addListener(element);
             }
             final SeverityLevelCounter warningCounter =
                 new SeverityLevelCounter(SeverityLevel.WARNING);
-            checker.addListener(warningCounter);
+            rootModule.addListener(warningCounter);
 
-            processFiles(checker, warningCounter, checkstyleVersion);
+            processFiles(rootModule, warningCounter, checkstyleVersion);
         }
         finally {
-            if (checker != null) {
-                checker.destroy();
-            }
+            destroyRootModule(rootModule);
         }
     }
 
     /**
-     * Scans and processes files by means given checker.
-     * @param checker Checker to process files
-     * @param warningCounter Checker's counter of warnings
+     * Destroy root module. This method exists only due to bug in cobertura library
+     * https://github.com/cobertura/cobertura/issues/170
+     * @param rootModule Root module that was used to process files
+     */
+    private static void destroyRootModule(RootModule rootModule) {
+        if (rootModule != null) {
+            rootModule.destroy();
+        }
+    }
+
+    /**
+     * Scans and processes files by means given root module.
+     * @param rootModule Root module to process files
+     * @param warningCounter Root Module's counter of warnings
      * @param checkstyleVersion Checkstyle compile version
      */
-    private void processFiles(Checker checker, final SeverityLevelCounter warningCounter,
+    private void processFiles(RootModule rootModule, final SeverityLevelCounter warningCounter,
             final String checkstyleVersion) {
         final long startTime = System.currentTimeMillis();
         final List<File> files = scanFileSets();
@@ -359,7 +372,7 @@ public class CheckstyleAntTask extends Task {
 
         try {
             final long processingStartTime = System.currentTimeMillis();
-            numErrs = checker.process(files);
+            numErrs = rootModule.process(files);
             final long processingEndTime = System.currentTimeMillis();
             log("To process the files took " + (processingEndTime - processingStartTime)
                 + TIME_SUFFIX, Project.MSG_VERBOSE);
@@ -386,11 +399,11 @@ public class CheckstyleAntTask extends Task {
     }
 
     /**
-     * Creates new instance of {@code Checker}.
-     * @return new instance of {@code Checker}
+     * Creates new instance of the root module.
+     * @return new instance of the root module
      */
-    private Checker createChecker() {
-        final Checker checker;
+    private RootModule createRootModule() {
+        final RootModule rootModule;
         try {
             final Properties props = createOverridingProperties();
             final Configuration config =
@@ -399,24 +412,29 @@ public class CheckstyleAntTask extends Task {
                     new PropertiesExpander(props),
                     omitIgnoredModules);
 
-            final DefaultContext context = new DefaultContext();
-            final ClassLoader loader = new AntClassLoader(getProject(),
-                    classpath);
-            context.add("classloader", loader);
-
             final ClassLoader moduleClassLoader =
                 Checker.class.getClassLoader();
-            context.add("moduleClassLoader", moduleClassLoader);
 
-            checker = new Checker();
-            checker.contextualize(context);
-            checker.configure(config);
+            final ModuleFactory factory = new PackageObjectFactory(
+                    Checker.class.getPackage().getName() + ".", moduleClassLoader);
+
+            rootModule = (RootModule) factory.createModule(config.getName());
+            rootModule.setModuleClassLoader(moduleClassLoader);
+
+            if (rootModule instanceof Checker) {
+                final ClassLoader loader = new AntClassLoader(getProject(),
+                        classpath);
+
+                ((Checker) rootModule).setClassLoader(loader);
+            }
+
+            rootModule.configure(config);
         }
         catch (final CheckstyleException ex) {
-            throw new BuildException(String.format(Locale.ROOT, "Unable to create a Checker: "
+            throw new BuildException(String.format(Locale.ROOT, "Unable to create Root Module: "
                     + "configLocation {%s}, classpath {%s}.", configLocation, classpath), ex);
         }
-        return checker;
+        return rootModule;
     }
 
     /**
@@ -494,7 +512,7 @@ public class CheckstyleAntTask extends Task {
      * @return the list of files included via the filesets.
      */
     protected List<File> scanFileSets() {
-        final List<File> list = Lists.newArrayList();
+        final List<File> list = new ArrayList<>();
         if (fileName != null) {
             // oops we've got an additional one to process, don't
             // forget it. No sweat, it's fully resolved via the setter.
@@ -540,7 +558,7 @@ public class CheckstyleAntTask extends Task {
      */
     public static class Formatter {
         /** The formatter type. */
-        private FormatterType formatterType;
+        private FormatterType type;
         /** The file to output to. */
         private File toFile;
         /** Whether or not the write to the named file. */
@@ -551,12 +569,7 @@ public class CheckstyleAntTask extends Task {
          * @param type the type
          */
         public void setType(FormatterType type) {
-            final String val = type.getValue();
-            if (!E_XML.equals(val) && !E_PLAIN.equals(val)) {
-                throw new BuildException("Invalid formatter type: " + val);
-            }
-
-            formatterType = type;
+            this.type = type;
         }
 
         /**
@@ -582,8 +595,8 @@ public class CheckstyleAntTask extends Task {
          * @throws IOException if an error occurs
          */
         public AuditListener createListener(Task task) throws IOException {
-            if (formatterType != null
-                    && E_XML.equals(formatterType.getValue())) {
+            if (type != null
+                    && E_XML.equals(type.getValue())) {
                 return createXmlLogger(task);
             }
             return createDefaultLogger(task);
@@ -596,7 +609,7 @@ public class CheckstyleAntTask extends Task {
          * @throws IOException if an error occurs
          */
         private AuditListener createDefaultLogger(Task task)
-            throws IOException {
+                throws IOException {
             if (toFile == null || !useFile) {
                 return new DefaultLogger(
                     new LogOutputStream(task, Project.MSG_DEBUG),
