@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -55,7 +55,7 @@ public final class LocalizedMessage
      * Avoids repetitive calls to ResourceBundle.getBundle().
      */
     private static final Map<String, ResourceBundle> BUNDLE_CACHE =
-        Collections.synchronizedMap(new HashMap<String, ResourceBundle>());
+        Collections.synchronizedMap(new HashMap<>());
 
     /** The default severity level if one is not specified. */
     private static final SeverityLevel DEFAULT_SEVERITY = SeverityLevel.ERROR;
@@ -102,6 +102,7 @@ public final class LocalizedMessage
      * @param sourceClass the Class that is the source of the message
      * @param customMessage optional custom message overriding the default
      */
+    // -@cs[ParameterNumber] Class is immutable, we need that amount of arguments.
     public LocalizedMessage(int lineNo,
                             int columnNo,
                             String bundle,
@@ -140,6 +141,7 @@ public final class LocalizedMessage
      * @param sourceClass the Class that is the source of the message
      * @param customMessage optional custom message overriding the default
      */
+    // -@cs[ParameterNumber] Class is immutable, we need that amount of arguments.
     public LocalizedMessage(int lineNo,
                             int columnNo,
                             String bundle,
@@ -171,6 +173,7 @@ public final class LocalizedMessage
      * @param sourceClass the source class for the message
      * @param customMessage optional custom message overriding the default
      */
+    // -@cs[ParameterNumber] Class is immutable, we need that amount of arguments.
     public LocalizedMessage(int lineNo,
                             String bundle,
                             String key,
@@ -207,6 +210,7 @@ public final class LocalizedMessage
                 sourceClass, customMessage);
     }
 
+    // -@cs[CyclomaticComplexity] equals - a lot of fields to check.
     @Override
     public boolean equals(Object object) {
         if (this == object) {
