@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -30,6 +30,7 @@ import com.puppycrawl.tools.checkstyle.grammars.GeneratedJavaTokenTypes;
  *
  * @author Oliver Burn
  * @author <a href="mailto:dobratzp@ele.uri.edu">Peter Dobratz</a>
+ * @noinspection JavaDoc
  */
 public final class TokenTypes {
     // The following three types are never part of an AST,
@@ -485,6 +486,9 @@ public final class TokenTypes {
      *
      * <p>For example:</p>
      *
+     * <pre>
+     * extends java.util.LinkedList
+     * </pre>
      *
      * <p>parses as:</p>
      * <pre>
@@ -1680,6 +1684,7 @@ public final class TokenTypes {
      *                     +--RPAREN ())
      *         +--SEMI (;)
      *         +--RCURLY (})
+     *     +--DO_WHILE (while)
      *     +--LPAREN (()
      *     +--EXPR
      *         |
@@ -2854,6 +2859,37 @@ public final class TokenTypes {
      * <code>LITERAL_FOR</code>.  The children of this element may be
      * a parameter definition, the colon literal and an expression.
      *
+     * <p>For example:</p>
+     * <pre>
+     * for (int value : values) {
+     *     doSmth();
+     * }
+     * </pre>
+     * <p>parses as:</p>
+     * <pre>
+     * --LITERAL_FOR (for)
+     *    |--LPAREN (()
+     *    |--FOR_EACH_CLAUSE
+     *    |   |--VARIABLE_DEF
+     *    |   |   |--MODIFIERS
+     *    |   |   |--TYPE
+     *    |   |   |   `--LITERAL_INT (int)
+     *    |   |   `--IDENT (value)
+     *    |   |--COLON (:)
+     *    |   `--EXPR
+     *    |       `--IDENT (values
+     *    |--RPAREN ())
+     *    `--SLIST ({)
+     *        |--EXPR
+     *        |   `--METHOD_CALL (()
+     *        |       |--IDENT (doSmth)
+     *        |       |--ELIST
+     *        |       `--RPAREN ())
+     *        |--SEMI (;)
+     *        `--RCURLY (})
+     *
+     * </pre>
+     *
      * @see #VARIABLE_DEF
      * @see #ELIST
      * @see #LITERAL_FOR
@@ -3363,7 +3399,7 @@ public final class TokenTypes {
     /**
      * Text of single-line or block comment.
      *
-     *<pre>
+     * <pre>
      * +--SINGLE_LINE_COMMENT
      *         |
      *         +--COMMENT_CONTENT
