@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,11 +19,10 @@
 
 package com.puppycrawl.tools.checkstyle.checks.blocks;
 
-import org.apache.commons.lang3.ArrayUtils;
-
-import com.puppycrawl.tools.checkstyle.api.Check;
+import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
+import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
 /**
  * <p>
@@ -134,7 +133,7 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * @author <a href="mailto:nesterenko-aleksey@list.ru">Aleksey Nesterenko</a>
  * @author <a href="mailto:andreyselkin@gmail.com">Andrei Selkin</a>
  */
-public class NeedBracesCheck extends Check {
+public class NeedBracesCheck extends AbstractCheck {
     /**
      * A key is pointing to the warning message text in "messages.properties"
      * file.
@@ -194,7 +193,7 @@ public class NeedBracesCheck extends Check {
 
     @Override
     public int[] getRequiredTokens() {
-        return ArrayUtils.EMPTY_INT_ARRAY;
+        return CommonUtils.EMPTY_INT_ARRAY;
     }
 
     @Override
@@ -205,15 +204,30 @@ public class NeedBracesCheck extends Check {
             && ast.findFirstToken(TokenTypes.LITERAL_IF) != null) {
             isElseIf = true;
         }
-
+        final boolean isDefaultInAnnotation = isDefaultInAnnotation(ast);
         final boolean skipStatement = isSkipStatement(ast);
         final boolean skipEmptyLoopBody = allowEmptyLoopBody && isEmptyLoopBody(ast);
 
-        if (slistAST == null && !isElseIf && !skipStatement && !skipEmptyLoopBody) {
+        if (slistAST == null && !isElseIf && !isDefaultInAnnotation
+                && !skipStatement && !skipEmptyLoopBody) {
             log(ast.getLineNo(), MSG_KEY_NEED_BRACES, ast.getText());
         }
     }
 
+    /**
+     * Checks if ast is default in annotation
+     * @param ast ast to test.
+     * @return true if current ast is default and it is part of annatation.
+     */
+    private boolean isDefaultInAnnotation(DetailAST ast) {
+        boolean isDefaultInAnnotation = false;
+        if (ast.getType() == TokenTypes.LITERAL_DEFAULT
+                && ast.getParent().getType() == TokenTypes.ANNOTATION_FIELD_DEF) {
+            isDefaultInAnnotation = true;
+        }
+        return isDefaultInAnnotation;
+    }
+
     /**
      * Checks if current statement can be skipped by "need braces" warning.
      * @param statement if, for, while, do-while, lambda, else, case, default statements.
@@ -235,7 +249,7 @@ public class NeedBracesCheck extends Check {
      * @param ast ast token.
      * @return true if current loop statement does not have body.
      */
-    private boolean isEmptyLoopBody(DetailAST ast) {
+    private static boolean isEmptyLoopBody(DetailAST ast) {
         boolean noBodyLoop = false;
 
         if (ast.getType() == TokenTypes.LITERAL_FOR
@@ -411,6 +425,7 @@ public class NeedBracesCheck extends Check {
      * {@code
      * case 1: doSomeStuff(); break;
      * case 2: doSomeStuff(); break;
+     * case 3: ;
      * }
      * </p>
      * @param literalCase {@link TokenTypes#LITERAL_CASE case statement}.
@@ -419,12 +434,17 @@ public class NeedBracesCheck extends Check {
     private static boolean isSingleLineCase(DetailAST literalCase) {
         boolean result = false;
         final DetailAST slist = literalCase.getNextSibling();
-        final DetailAST block = slist.getFirstChild();
-        if (block.getType() != TokenTypes.SLIST) {
-            final DetailAST caseBreak = slist.findFirstToken(TokenTypes.LITERAL_BREAK);
-            final boolean atOneLine = literalCase.getLineNo() == block.getLineNo();
-            if (caseBreak != null) {
-                result = atOneLine && block.getLineNo() == caseBreak.getLineNo();
+        if (slist == null) {
+            result = true;
+        }
+        else {
+            final DetailAST block = slist.getFirstChild();
+            if (block.getType() != TokenTypes.SLIST) {
+                final DetailAST caseBreak = slist.findFirstToken(TokenTypes.LITERAL_BREAK);
+                final boolean atOneLine = literalCase.getLineNo() == block.getLineNo();
+                if (caseBreak != null) {
+                    result = atOneLine && block.getLineNo() == caseBreak.getLineNo();
+                }
             }
         }
         return result;
@@ -443,9 +463,14 @@ public class NeedBracesCheck extends Check {
     private static boolean isSingleLineDefault(DetailAST literalDefault) {
         boolean result = false;
         final DetailAST slist = literalDefault.getNextSibling();
-        final DetailAST block = slist.getFirstChild();
-        if (block.getType() != TokenTypes.SLIST) {
-            result = literalDefault.getLineNo() == block.getLineNo();
+        if (slist == null) {
+            result = true;
+        }
+        else {
+            final DetailAST block = slist.getFirstChild();
+            if (block != null && block.getType() != TokenTypes.SLIST) {
+                result = literalDefault.getLineNo() == block.getLineNo();
+            }
         }
         return result;
     }
