@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -22,9 +22,8 @@ package com.puppycrawl.tools.checkstyle.checks.blocks;
 import java.util.Locale;
 
 import org.apache.commons.beanutils.ConversionException;
-import org.apache.commons.lang3.ArrayUtils;
 
-import com.puppycrawl.tools.checkstyle.api.Check;
+import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.Scope;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
@@ -83,7 +82,7 @@ import com.puppycrawl.tools.checkstyle.utils.ScopeUtils;
  * @author Andrei Selkin
  * @author <a href="mailto:piotr.listkiewicz@gmail.com">liscju</a>
  */
-public class RightCurlyCheck extends Check {
+public class RightCurlyCheck extends AbstractCheck {
     /**
      * A key is pointing to the warning message text in "messages.properties"
      * file.
@@ -168,7 +167,7 @@ public class RightCurlyCheck extends Check {
 
     @Override
     public int[] getRequiredTokens() {
-        return ArrayUtils.EMPTY_INT_ARRAY;
+        return CommonUtils.EMPTY_INT_ARRAY;
     }
 
     @Override
@@ -176,22 +175,19 @@ public class RightCurlyCheck extends Check {
         final Details details = getDetails(ast);
         final DetailAST rcurly = details.rcurly;
 
-        if (rcurly == null || rcurly.getType() != TokenTypes.RCURLY) {
-            // we need to have both tokens to perform the check
-            return;
-        }
+        if (rcurly != null) {
+            final String violation;
+            if (shouldStartLine) {
+                final String targetSourceLine = getLines()[rcurly.getLineNo() - 1];
+                violation = validate(details, option, true, targetSourceLine);
+            }
+            else {
+                violation = validate(details, option, false, "");
+            }
 
-        final String violation;
-        if (shouldStartLine) {
-            final String targetSourceLine = getLines()[rcurly.getLineNo() - 1];
-            violation = validate(details, option, true, targetSourceLine);
-        }
-        else {
-            violation = validate(details, option, false, "");
-        }
-
-        if (!violation.isEmpty()) {
-            log(rcurly, violation, "}", rcurly.getColumnNo() + 1);
+            if (!violation.isEmpty()) {
+                log(rcurly, violation, "}", rcurly.getColumnNo() + 1);
+            }
         }
     }
 
@@ -314,6 +310,9 @@ public class RightCurlyCheck extends Check {
      * @param ast detail ast.
      * @return object that contain all details to make a validation.
      */
+    // -@cs[JavaNCSS] getDetails() method is a huge SWITCH, it has to be monolithic
+    // -@cs[ExecutableStatementCount] getDetails() method is a huge SWITCH, it has to be monolithic
+    // -@cs[NPathComplexity] getDetails() method is a huge SWITCH, it has to be monolithic
     private static Details getDetails(DetailAST ast) {
         // Attempt to locate the tokens to do the check
         boolean shouldCheckLastRcurly = false;
@@ -323,9 +322,19 @@ public class RightCurlyCheck extends Check {
 
         switch (ast.getType()) {
             case TokenTypes.LITERAL_TRY:
-                lcurly = ast.getFirstChild();
+                if (ast.getFirstChild().getType() == TokenTypes.RESOURCE_SPECIFICATION) {
+                    lcurly = ast.getFirstChild().getNextSibling();
+                }
+                else {
+                    lcurly = ast.getFirstChild();
+                }
                 nextToken = lcurly.getNextSibling();
                 rcurly = lcurly.getLastChild();
+
+                if (nextToken == null) {
+                    shouldCheckLastRcurly = true;
+                    nextToken = getNextToken(ast);
+                }
                 break;
             case TokenTypes.LITERAL_CATCH:
                 nextToken = ast.getNextSibling();
@@ -342,10 +351,11 @@ public class RightCurlyCheck extends Check {
                     shouldCheckLastRcurly = true;
                     nextToken = getNextToken(ast);
                     lcurly = ast.getLastChild();
-                    rcurly = lcurly.getLastChild();
                 }
                 else {
                     lcurly = nextToken.getPreviousSibling();
+                }
+                if (lcurly.getType() == TokenTypes.SLIST) {
                     rcurly = lcurly.getLastChild();
                 }
                 break;
@@ -354,7 +364,9 @@ public class RightCurlyCheck extends Check {
                 shouldCheckLastRcurly = true;
                 nextToken = getNextToken(ast);
                 lcurly = ast.getFirstChild();
-                rcurly = lcurly.getLastChild();
+                if (lcurly.getType() == TokenTypes.SLIST) {
+                    rcurly = lcurly.getLastChild();
+                }
                 break;
             case TokenTypes.CLASS_DEF:
                 final DetailAST child = ast.getLastChild();
@@ -369,9 +381,16 @@ public class RightCurlyCheck extends Check {
                 rcurly = lcurly.getLastChild();
                 nextToken = getNextToken(ast);
                 break;
+            case TokenTypes.LITERAL_DO:
+                nextToken = ast.findFirstToken(TokenTypes.DO_WHILE);
+                lcurly = ast.findFirstToken(TokenTypes.SLIST);
+                if (lcurly != null) {
+                    rcurly = lcurly.getLastChild();
+                }
+                break;
             default:
                 // ATTENTION! We have default here, but we expect case TokenTypes.METHOD_DEF,
-                // TokenTypes.LITERAL_FOR, TokenTypes.LITERAL_WHILE, TokenTypes.LITERAL_DO only.
+                // TokenTypes.LITERAL_FOR, TokenTypes.LITERAL_WHILE, only.
                 // It has been done to improve coverage to 100%. I couldn't replace it with
                 // if-else-if block because code was ugly and didn't pass pmd check.
 
