@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -21,8 +21,10 @@ package com.puppycrawl.tools.checkstyle.checks.coding;
 
 import java.util.ArrayDeque;
 import java.util.Deque;
+import java.util.HashSet;
+import java.util.Set;
 
-import com.puppycrawl.tools.checkstyle.api.Check;
+import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.Scope;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
@@ -31,9 +33,9 @@ import com.puppycrawl.tools.checkstyle.utils.ScopeUtils;
 /**
  * Checks that the parts of a class or interface declaration
  * appear in the order suggested by the
- * <a
- * href="http://www.oracle.com/technetwork/java/javase/documentation/codeconventions-141855.html#1852"
- * >Code Conventions for the Java Programming Language</a>.
+ * <a href=
+ * "http://www.oracle.com/technetwork/java/javase/documentation/codeconventions-141855.html#1852">
+ * Code Conventions for the Java Programming Language</a>.
  *
  *
  * <ol>
@@ -47,6 +49,18 @@ import com.puppycrawl.tools.checkstyle.utils.ScopeUtils;
  * <li> Methods </li>
  * </ol>
  *
+ * <p>ATTENTION: the check skips class fields which have
+ * <a href="http://docs.oracle.com/javase/specs/jls/se8/html/jls-8.html#jls-8.3.3">
+ * forward references </a> from validation due to the fact that we have Checkstyle's limitations
+ * to clearly detect user intention of fields location and grouping. For example,
+ * <pre>{@code
+ *      public class A {
+ *          private double x = 1.0;
+ *          private double y = 2.0;
+ *          public double slope = x / y; // will be skipped from validation due to forward reference
+ *      }
+ * }</pre>
+ *
  * <p>Available options:
  * <ul>
  * <li>ignoreModifiers</li>
@@ -93,7 +107,7 @@ import com.puppycrawl.tools.checkstyle.utils.ScopeUtils;
  *
  * @author r_auckenthaler
  */
-public class DeclarationOrderCheck extends Check {
+public class DeclarationOrderCheck extends AbstractCheck {
 
     /**
      * A key is pointing to the warning message text in "messages.properties"
@@ -133,9 +147,12 @@ public class DeclarationOrderCheck extends Check {
 
     /**
      * List of Declaration States. This is necessary due to
-     * inner classes that have their own state
+     * inner classes that have their own state.
      */
-    private final Deque<ScopeState> scopeStates = new ArrayDeque<>();
+    private Deque<ScopeState> scopeStates;
+
+    /** Set of all class field names.*/
+    private Set<String> classFieldNames;
 
     /** If true, ignores the check to constructors. */
     private boolean ignoreConstructors;
@@ -154,6 +171,7 @@ public class DeclarationOrderCheck extends Check {
             TokenTypes.METHOD_DEF,
             TokenTypes.MODIFIERS,
             TokenTypes.OBJBLOCK,
+            TokenTypes.VARIABLE_DEF,
         };
     }
 
@@ -162,6 +180,12 @@ public class DeclarationOrderCheck extends Check {
         return getAcceptableTokens();
     }
 
+    @Override
+    public void beginTree(DetailAST rootAST) {
+        scopeStates = new ArrayDeque<>();
+        classFieldNames = new HashSet<>();
+    }
+
     @Override
     public void visitToken(DetailAST ast) {
         final int parentType = ast.getParent().getType();
@@ -188,14 +212,20 @@ public class DeclarationOrderCheck extends Check {
                     state.currentScopeState = STATE_METHOD_DEF;
                 }
                 break;
+            case TokenTypes.VARIABLE_DEF:
+                if (ScopeUtils.isClassFieldDef(ast)) {
+                    final DetailAST fieldDef = ast.findFirstToken(TokenTypes.IDENT);
+                    classFieldNames.add(fieldDef.getText());
+                }
+                break;
             default:
                 break;
         }
     }
 
     /**
-     * Process constructor.
-     * @param ast constructor AST
+     * Processes constructor.
+     * @param ast constructor AST.
      */
     private void processConstructor(DetailAST ast) {
 
@@ -211,15 +241,30 @@ public class DeclarationOrderCheck extends Check {
     }
 
     /**
-     * Process modifiers.
-     * @param ast ast of Modifiers
+     * Processes modifiers.
+     * @param ast ast of Modifiers.
      */
     private void processModifiers(DetailAST ast) {
-
         final ScopeState state = scopeStates.peek();
-        if (ast.findFirstToken(TokenTypes.LITERAL_STATIC) == null) {
+        final boolean isStateValid = processModifiersState(ast, state);
+        processModifiersSubState(ast, state, isStateValid);
+    }
+
+    /**
+     * Process if given modifiers are appropriate in given state
+     * ({@code STATE_STATIC_VARIABLE_DEF}, {@code STATE_INSTANCE_VARIABLE_DEF},
+     * ({@code STATE_CTOR_DEF}, {@code STATE_METHOD_DEF}), if it is
+     * it updates states where appropriate or logs violation.
+     * @param modifierAst modifiers to process
+     * @param state current state
+     * @return true if modifierAst is valid in given state, false otherwise
+     */
+    private boolean processModifiersState(DetailAST modifierAst, ScopeState state) {
+        boolean isStateValid = true;
+        if (modifierAst.findFirstToken(TokenTypes.LITERAL_STATIC) == null) {
             if (state.currentScopeState > STATE_INSTANCE_VARIABLE_DEF) {
-                log(ast, MSG_INSTANCE);
+                isStateValid = false;
+                log(modifierAst, MSG_INSTANCE);
             }
             else if (state.currentScopeState == STATE_STATIC_VARIABLE_DEF) {
                 state.declarationAccess = Scope.PUBLIC;
@@ -230,18 +275,33 @@ public class DeclarationOrderCheck extends Check {
             if (state.currentScopeState > STATE_STATIC_VARIABLE_DEF) {
                 if (!ignoreModifiers
                         || state.currentScopeState > STATE_INSTANCE_VARIABLE_DEF) {
-                    log(ast, MSG_STATIC);
+                    isStateValid = false;
+                    log(modifierAst, MSG_STATIC);
                 }
             }
             else {
                 state.currentScopeState = STATE_STATIC_VARIABLE_DEF;
             }
         }
+        return isStateValid;
+    }
 
-        final Scope access = ScopeUtils.getScopeFromMods(ast);
+    /**
+     * Checks if given modifiers are valid in substate of given
+     * state({@code Scope}), if it is it updates substate or else it
+     * logs violation.
+     * @param modifiersAst modifiers to process
+     * @param state curent state
+     * @param isStateValid is main state for given modifiers is valid
+     */
+    private void processModifiersSubState(DetailAST modifiersAst, ScopeState state,
+                                          boolean isStateValid) {
+        final Scope access = ScopeUtils.getScopeFromMods(modifiersAst);
         if (state.declarationAccess.compareTo(access) > 0) {
-            if (!ignoreModifiers) {
-                log(ast, MSG_ACCESS);
+            if (isStateValid
+                    && !ignoreModifiers
+                    && !isForwardReference(modifiersAst.getParent())) {
+                log(modifiersAst, MSG_ACCESS);
             }
         }
         else {
@@ -249,6 +309,51 @@ public class DeclarationOrderCheck extends Check {
         }
     }
 
+    /**
+     * Checks whether an identifier references a field which has been already defined in class.
+     * @param fieldDef a field definition.
+     * @return true if an identifier references a field which has been already defined in class.
+     */
+    private boolean isForwardReference(DetailAST fieldDef) {
+        final DetailAST exprStartIdent = fieldDef.findFirstToken(TokenTypes.IDENT);
+        final Set<DetailAST> exprIdents = getAllTokensOfType(exprStartIdent, TokenTypes.IDENT);
+        boolean forwardReference = false;
+        for (DetailAST ident : exprIdents) {
+            if (classFieldNames.contains(ident.getText())) {
+                forwardReference = true;
+                break;
+            }
+        }
+        return forwardReference;
+    }
+
+    /**
+     * Collects all tokens of specific type starting with the current ast node.
+     * @param ast ast node.
+     * @param tokenType token type.
+     * @return a set of all tokens of specific type starting with the current ast node.
+     */
+    private static Set<DetailAST> getAllTokensOfType(DetailAST ast, int tokenType) {
+        DetailAST vertex = ast;
+        final Set<DetailAST> result = new HashSet<>();
+        final Deque<DetailAST> stack = new ArrayDeque<>();
+        while (vertex != null || !stack.isEmpty()) {
+            if (!stack.isEmpty()) {
+                vertex = stack.pop();
+            }
+            while (vertex != null) {
+                if (vertex.getType() == tokenType && !vertex.equals(ast)) {
+                    result.add(vertex);
+                }
+                if (vertex.getNextSibling() != null) {
+                    stack.push(vertex.getNextSibling());
+                }
+                vertex = vertex.getFirstChild();
+            }
+        }
+        return result;
+    }
+
     @Override
     public void leaveToken(DetailAST ast) {
         if (ast.getType() == TokenTypes.OBJBLOCK) {
