@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -22,7 +22,7 @@ package com.puppycrawl.tools.checkstyle.checks.coding;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import com.puppycrawl.tools.checkstyle.api.Check;
+import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 
@@ -67,7 +67,7 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  *
  * @author o_sukhodolsky
  */
-public class FallThroughCheck extends Check {
+public class FallThroughCheck extends AbstractCheck {
 
     /**
      * A key is pointing to the warning message text in "messages.properties"
@@ -84,11 +84,8 @@ public class FallThroughCheck extends Check {
     /** Do we need to check last case group. */
     private boolean checkLastCaseGroup;
 
-    /** Relief pattern to allow fall through to the next case branch. */
-    private String reliefPattern = "fallthru|falls? ?through";
-
-    /** Relief regexp. */
-    private Pattern regExp;
+    /** Relief regexp to allow fall through to the next case branch. */
+    private Pattern reliefPattern = Pattern.compile("fallthru|falls? ?through");
 
     @Override
     public int[] getDefaultTokens() {
@@ -111,7 +108,7 @@ public class FallThroughCheck extends Check {
      * @param pattern
      *            The regular expression pattern.
      */
-    public void setReliefPattern(String pattern) {
+    public void setReliefPattern(Pattern pattern) {
         reliefPattern = pattern;
     }
 
@@ -123,30 +120,21 @@ public class FallThroughCheck extends Check {
         checkLastCaseGroup = value;
     }
 
-    @Override
-    public void init() {
-        super.init();
-        regExp = Pattern.compile(reliefPattern);
-    }
-
     @Override
     public void visitToken(DetailAST ast) {
         final DetailAST nextGroup = ast.getNextSibling();
         final boolean isLastGroup = nextGroup.getType() != TokenTypes.CASE_GROUP;
-        if (isLastGroup && !checkLastCaseGroup) {
-            // we do not need to check last group
-            return;
-        }
+        if (!isLastGroup || checkLastCaseGroup) {
+            final DetailAST slist = ast.findFirstToken(TokenTypes.SLIST);
 
-        final DetailAST slist = ast.findFirstToken(TokenTypes.SLIST);
-
-        if (slist != null && !isTerminated(slist, true, true)
-            && !hasFallThroughComment(ast, nextGroup)) {
-            if (isLastGroup) {
-                log(ast, MSG_FALL_THROUGH_LAST);
-            }
-            else {
-                log(nextGroup, MSG_FALL_THROUGH);
+            if (slist != null && !isTerminated(slist, true, true)
+                && !hasFallThroughComment(ast, nextGroup)) {
+                if (isLastGroup) {
+                    log(ast, MSG_FALL_THROUGH_LAST);
+                }
+                else {
+                    log(nextGroup, MSG_FALL_THROUGH);
+                }
             }
         }
     }
@@ -279,7 +267,13 @@ public class FallThroughCheck extends Check {
         }
 
         if (!isTerminated) {
-            isTerminated = isTerminated(ast.getFirstChild(),
+            DetailAST firstChild = ast.getFirstChild();
+
+            if (firstChild.getType() == TokenTypes.RESOURCE_SPECIFICATION) {
+                firstChild = firstChild.getNextSibling();
+            }
+
+            isTerminated = isTerminated(firstChild,
                     useBreak, useContinue);
 
             DetailAST catchStmt = ast.findFirstToken(TokenTypes.LITERAL_CATCH);
@@ -342,7 +336,7 @@ public class FallThroughCheck extends Check {
         //    /+ FALLTHRU +/}
         //
         final String linePart = lines[endLineNo - 1].substring(0, endColNo);
-        if (matchesComment(regExp, linePart, endLineNo)) {
+        if (matchesComment(reliefPattern, linePart, endLineNo)) {
             allThroughComment = true;
         }
         else {
@@ -360,7 +354,7 @@ public class FallThroughCheck extends Check {
             final int startLineNo = currentCase.getLineNo();
             for (int i = endLineNo - 2; i > startLineNo - 1; i--) {
                 if (!lines[i].trim().isEmpty()) {
-                    allThroughComment = matchesComment(regExp, lines[i], i + 1);
+                    allThroughComment = matchesComment(reliefPattern, lines[i], i + 1);
                     break;
                 }
             }
