@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,17 +19,17 @@
 
 package com.puppycrawl.tools.checkstyle.checks.coding;
 
+import java.util.HashSet;
 import java.util.Locale;
 import java.util.Objects;
 import java.util.Set;
 import java.util.regex.Pattern;
 
-import com.google.common.collect.Sets;
-import com.puppycrawl.tools.checkstyle.api.Check;
+import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.Scope;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
-import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
+import com.puppycrawl.tools.checkstyle.utils.CheckUtils;
 import com.puppycrawl.tools.checkstyle.utils.ScopeUtils;
 
 /**
@@ -129,7 +129,7 @@ import com.puppycrawl.tools.checkstyle.utils.ScopeUtils;
  * @author Dmitri Priimak
  */
 public class HiddenFieldCheck
-    extends Check {
+    extends AbstractCheck {
     /**
      * A key is pointing to the warning message text in "messages.properties"
      * file.
@@ -142,7 +142,7 @@ public class HiddenFieldCheck
     private FieldFrame frame;
 
     /** Pattern for names of variables and parameters to ignore. */
-    private Pattern regexp;
+    private Pattern ignoreFormat;
 
     /** Controls whether to check the parameter of a property setter method. */
     private boolean ignoreSetter;
@@ -299,6 +299,7 @@ public class HiddenFieldCheck
      */
     private void processVariable(DetailAST ast) {
         if (!ScopeUtils.isInInterfaceOrAnnotationBlock(ast)
+            && !CheckUtils.isReceiverParameter(ast)
             && (ScopeUtils.isLocalVariableDef(ast)
                 || ast.getType() == TokenTypes.PARAMETER_DEF)) {
             // local variable or parameter. Does it shadow a field?
@@ -354,7 +355,7 @@ public class HiddenFieldCheck
      * @return true is regexp is matching
      */
     private boolean isMatchingRegexp(String name) {
-        return regexp != null && regexp.matcher(name).find();
+        return ignoreFormat != null && ignoreFormat.matcher(name).find();
     }
 
     /**
@@ -509,11 +510,11 @@ public class HiddenFieldCheck
     }
 
     /**
-     * Set the ignore format to the specified regular expression.
-     * @param format a {@code String} value
+     * Set the ignore format for the specified regular expression.
+     * @param pattern a pattern.
      */
-    public void setIgnoreFormat(String format) {
-        regexp = CommonUtils.createPattern(format);
+    public void setIgnoreFormat(Pattern pattern) {
+        ignoreFormat = pattern;
     }
 
     /**
@@ -575,10 +576,10 @@ public class HiddenFieldCheck
         private final FieldFrame parent;
 
         /** Set of instance field names. */
-        private final Set<String> instanceFields = Sets.newHashSet();
+        private final Set<String> instanceFields = new HashSet<>();
 
         /** Set of static field names. */
-        private final Set<String> staticFields = Sets.newHashSet();
+        private final Set<String> staticFields = new HashSet<>();
 
         /**
          * Creates new frame.
