@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -25,7 +25,7 @@ import java.util.regex.Pattern;
 
 import org.apache.commons.beanutils.ConversionException;
 
-import com.puppycrawl.tools.checkstyle.api.Check;
+import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.FullIdent;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
@@ -37,6 +37,8 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
  * (e.g., java. comes first, javax. comes second, then everything else)</li>
  * <li>adds a separation between groups : ensures that a blank line sit between
  * each group</li>
+ * <li>import groups aren't separated internally: ensures that
+ * each group aren't separated internally by blank line or comment</li>
  * <li>sorts imports inside each group: ensures that imports within each group
  * are in lexicographic order</li>
  * <li>sorts according to case: ensures that the comparison between import is
@@ -59,11 +61,13 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
  *   <tr><td>ordered</td><td>whether imports within group should be sorted</td>
  *       <td>Boolean</td><td>true</td></tr>
  *   <tr><td>separated</td><td>whether imports groups should be separated by, at least,
- *       one blank line</td><td>Boolean</td><td>false</td></tr>
+ *       one blank line and aren't separated internally</td><td>Boolean</td><td>false</td></tr>
  *   <tr><td>caseSensitive</td><td>whether string comparison should be case sensitive or not.
  *       Case sensitive sorting is in ASCII sort order</td><td>Boolean</td><td>true</td></tr>
  *   <tr><td>sortStaticImportsAlphabetically</td><td>whether static imports grouped by top or
  *       bottom option are sorted alphabetically or not</td><td>Boolean</td><td>false</td></tr>
+ *   <tr><td>useContainerOrderingForStatic</td><td>whether to use container ordering
+ *       (Eclipse IDE term) for static imports or not</td><td>Boolean</td><td>false</td></tr>
  * </table>
  *
  * <p>
@@ -76,7 +80,7 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
  *     <li>groups of non-static imports: &quot;java&quot; then &quot;javax&quot;
  *         packages first, then &quot;org&quot; and then all other imports</li>
  *     <li>imports will be sorted in the groups</li>
- *     <li>groups are separated by, at least, one blank line</li>
+ *     <li>groups are separated by, at least, one blank line and aren't separated internally</li>
  * </ul>
  *
  * <pre>
@@ -96,7 +100,7 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
  *     <li>groups of non-static imports: all imports except of &quot;javax&quot; and
  *         &quot;java&quot;, then &quot;javax&quot; and &quot;java&quot;</li>
  *     <li>imports will be sorted in the groups</li>
- *     <li>groups are separated by, at least, one blank line</li>
+ *     <li>groups are separated by, at least, one blank line and aren't separated internally</li>
  * </ul>
  *
  *         <p>
@@ -176,9 +180,10 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
  * @author David DIDIER
  * @author Steve McKay
  * @author <a href="mailto:nesterenko-aleksey@list.ru">Aleksey Nesterenko</a>
+ * @author Andrei Selkin
  */
 public class ImportOrderCheck
-    extends Check {
+    extends AbstractCheck {
 
     /**
      * A key is pointing to the warning message text in "messages.properties"
@@ -192,6 +197,12 @@ public class ImportOrderCheck
      */
     public static final String MSG_ORDERING = "import.ordering";
 
+    /**
+     * A key is pointing to the warning message text in "messages.properties"
+     * file.
+     */
+    public static final String MSG_SEPARATED_IN_GROUP = "import.groups.separated.internally";
+
     /** The special wildcard that catches all remaining groups. */
     private static final String WILDCARD_GROUP_NAME = "*";
 
@@ -219,6 +230,8 @@ public class ImportOrderCheck
     private boolean beforeFirstImport;
     /** Whether static imports should be sorted alphabetically or not. */
     private boolean sortStaticImportsAlphabetically;
+    /** Whether to use container ordering (Eclipse IDE term) for static imports or not. */
+    private boolean useContainerOrderingForStatic;
 
     /** The policy to enforce. */
     private ImportOrderOption option = ImportOrderOption.UNDER;
@@ -317,6 +330,14 @@ public class ImportOrderCheck
         sortStaticImportsAlphabetically = sortAlphabetically;
     }
 
+    /**
+     * Sets whether to use container ordering (Eclipse IDE term) for static imports or not.
+     * @param useContainerOrdering whether to use container ordering for static imports or not.
+     */
+    public void setUseContainerOrderingForStatic(boolean useContainerOrdering) {
+        useContainerOrderingForStatic = useContainerOrdering;
+    }
+
     @Override
     public int[] getDefaultTokens() {
         return getAcceptableTokens();
@@ -341,6 +362,7 @@ public class ImportOrderCheck
         beforeFirstImport = true;
     }
 
+    // -@cs[CyclomaticComplexity] SWITCH was transformed into IF-ELSE.
     @Override
     public void visitToken(DetailAST ast) {
         final FullIdent ident;
@@ -429,11 +451,26 @@ public class ImportOrderCheck
         else {
             log(line, MSG_ORDERING, name);
         }
+        if (checkSeparatorInGroup(groupIdx, isStatic, line)) {
+            log(line, MSG_SEPARATED_IN_GROUP, name);
+        }
 
         lastGroup = groupIdx;
         lastImport = name;
     }
 
+    /**
+     * Checks whether imports group separated internally.
+     * @param groupIdx group number.
+     * @param isStatic whether the token is static or not.
+     * @param line the line of the current import.
+     * @return true if imports group are separated internally.
+     */
+    private boolean checkSeparatorInGroup(int groupIdx, boolean isStatic, int line) {
+        return !beforeFirstImport && separated && groupIdx == lastGroup
+                && isStatic == lastImportStatic && line - lastImportLine > 1;
+    }
+
     /**
      * Checks whether static imports grouped by <b>top</b> or <b>bottom</b> option
      * are sorted alphabetically or not.
@@ -457,34 +494,113 @@ public class ImportOrderCheck
      */
     private void doVisitTokenInSameGroup(boolean isStatic,
             boolean previous, String name, int line) {
-        if (!ordered) {
-            return;
-        }
-
-        if (option == ImportOrderOption.INFLOW) {
-            // out of lexicographic order
-            if (compare(lastImport, name, caseSensitive) > 0) {
-                log(line, MSG_ORDERING, name);
+        if (ordered) {
+            if (option == ImportOrderOption.INFLOW) {
+                if (isWrongOrder(name, isStatic)) {
+                    log(line, MSG_ORDERING, name);
+                }
             }
+            else {
+                final boolean shouldFireError =
+                    // previous non-static but current is static (above)
+                    // or
+                    // previous static but current is non-static (under)
+                    previous
+                        ||
+                        // current and previous static or current and
+                        // previous non-static
+                        lastImportStatic == isStatic
+                    && isWrongOrder(name, isStatic);
+
+                if (shouldFireError) {
+                    log(line, MSG_ORDERING, name);
+                }
+            }
+        }
+    }
+
+    /**
+     * Checks whether import name is in wrong order.
+     * @param name import name.
+     * @param isStatic whether it is a static import name.
+     * @return true if import name is in wrong order.
+     */
+    private boolean isWrongOrder(String name, boolean isStatic) {
+        final boolean result;
+        if (isStatic && useContainerOrderingForStatic) {
+            result = compareContainerOrder(lastImport, name, caseSensitive) > 0;
         }
         else {
-            final boolean shouldFireError =
-                // previous non-static but current is static (above)
-                // or
-                // previous static but current is non-static (under)
-                previous
-                    ||
-                    // current and previous static or current and
-                    // previous non-static
-                    lastImportStatic == isStatic
-                &&
-                // and out of lexicographic order
-                compare(lastImport, name, caseSensitive) > 0;
-
-            if (shouldFireError) {
-                log(line, MSG_ORDERING, name);
-            }
+            // out of lexicographic order
+            result = compare(lastImport, name, caseSensitive) > 0;
         }
+        return result;
+    }
+
+    /**
+     * Compares two import strings.
+     * We first compare the container of the static import, container being the type enclosing
+     * the static element being imported. When this returns 0, we compare the qualified
+     * import name. For e.g. this is what is considered to be container names:
+     * <p>
+     * import static HttpConstants.COLON     => HttpConstants
+     * import static HttpHeaders.addHeader   => HttpHeaders
+     * import static HttpHeaders.setHeader   => HttpHeaders
+     * import static HttpHeaders.Names.DATE  => HttpHeaders.Names
+     * </p>
+     * <p>
+     * According to this logic, HttpHeaders.Names would come after HttpHeaders.
+     *
+     * For more details, see <a href="https://bugs.eclipse.org/bugs/show_bug.cgi?id=473629#c3">
+     * static imports comparison method</a> in Eclipse.
+     * </p>
+     *
+     * @param importName1 first import name.
+     * @param importName2 second import name.
+     * @param caseSensitive whether the comparison of fully qualified import names is case
+     *                      sensitive.
+     * @return the value {@code 0} if str1 is equal to str2; a value
+     *         less than {@code 0} if str is less than the str2 (container order
+     *         or lexicographical); and a value greater than {@code 0} if str1 is greater than str2
+     *         (container order or lexicographically).
+     */
+    private static int compareContainerOrder(String importName1, String importName2,
+                                             boolean caseSensitive) {
+        final String container1 = getImportContainer(importName1);
+        final String container2 = getImportContainer(importName2);
+        final int compareContainersOrderResult;
+        if (caseSensitive) {
+            compareContainersOrderResult = container1.compareTo(container2);
+        }
+        else {
+            compareContainersOrderResult = container1.compareToIgnoreCase(container2);
+        }
+        final int result;
+        if (compareContainersOrderResult == 0) {
+            result = compare(importName1, importName2, caseSensitive);
+        }
+        else {
+            result = compareContainersOrderResult;
+        }
+        return result;
+    }
+
+    /**
+     * Extracts import container name from fully qualified import name.
+     * An import container name is the type which encloses the static element being imported.
+     * For example, HttpConstants, HttpHeaders, HttpHeaders.Names are import container names:
+     * <p>
+     * import static HttpConstants.COLON     => HttpConstants
+     * import static HttpHeaders.addHeader   => HttpHeaders
+     * import static HttpHeaders.setHeader   => HttpHeaders
+     * import static HttpHeaders.Names.DATE  => HttpHeaders.Names
+     * </p>
+     * @param qualifiedImportName fully qualified import name.
+     * @return import container name.
+     */
+    private static String getImportContainer(String qualifiedImportName) {
+        final int lastDotIndex = qualifiedImportName.lastIndexOf('.');
+        return qualifiedImportName.substring(0, lastDotIndex);
     }
 
     /**
