@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -77,11 +77,6 @@ public class ArrayInitHandler extends BlockParentHandler {
         return getMainAst().findFirstToken(TokenTypes.RCURLY);
     }
 
-    @Override
-    protected boolean shouldStartWithRCurly() {
-        return false;
-    }
-
     @Override
     protected boolean canChildrenBeNested() {
         return true;
