@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -50,7 +50,8 @@ public class MethodCallHandler extends AbstractExpressionHandler {
             final MethodCallHandler container =
                     (MethodCallHandler) getParent();
             if (areOnSameLine(container.getMainAst(), getMainAst())
-                    || isChainedMethodCallWrapped()) {
+                    || isChainedMethodCallWrapped()
+                    || areMethodsChained(container.getMainAst(), getMainAst())) {
                 indentLevel = container.getIndent();
             }
             // we should increase indentation only if this is the first
@@ -76,6 +77,27 @@ public class MethodCallHandler extends AbstractExpressionHandler {
         return indentLevel;
     }
 
+    /**
+     * Checks if ast2 is a chained method call that starts on the same level as ast1 ends.
+     * In other words, if the right paren of ast1 is on the same level as the lparen of ast2:
+     *
+     * <code>
+     *     value.methodOne(
+     *         argument1
+     *     ).methodTwo(
+     *         argument2
+     *     );
+     * </code>
+     *
+     * @param ast1 Ast1
+     * @param ast2 Ast2
+     * @return True if ast2 begins on the same level that ast1 ends
+     */
+    private static boolean areMethodsChained(DetailAST ast1, DetailAST ast2) {
+        final DetailAST rparen = ast1.findFirstToken(TokenTypes.RPAREN);
+        return rparen.getLineNo() == ast2.getLineNo();
+    }
+
     /**
      * If this is the first chained method call which was moved to the next line.
      * @return true if chained class are wrapped
@@ -148,30 +170,24 @@ public class MethodCallHandler extends AbstractExpressionHandler {
     @Override
     public void checkIndentation() {
         final DetailAST exprNode = getMainAst().getParent();
-        if (exprNode.getParent().getType() != TokenTypes.SLIST) {
-            return;
+        if (exprNode.getParent().getType() == TokenTypes.SLIST) {
+            final DetailAST methodName = getMainAst().getFirstChild();
+            checkExpressionSubtree(methodName, getIndent(), false, false);
+
+            final DetailAST lparen = getMainAst();
+            final DetailAST rparen = getMainAst().findFirstToken(TokenTypes.RPAREN);
+            checkLParen(lparen);
+
+            if (rparen.getLineNo() != lparen.getLineNo()) {
+                checkExpressionSubtree(
+                    getMainAst().findFirstToken(TokenTypes.ELIST),
+                    new IndentLevel(getIndent(), getBasicOffset()),
+                    false, true);
+
+                checkRParen(lparen, rparen);
+                checkWrappingIndentation(getMainAst(), getMethodCallLastNode(getMainAst()));
+            }
         }
-        final DetailAST methodName = getMainAst().getFirstChild();
-        checkExpressionSubtree(methodName, getIndent(), false, false);
-
-        final DetailAST lparen = getMainAst();
-        final DetailAST rparen = getMainAst().findFirstToken(TokenTypes.RPAREN);
-        checkLParen(lparen);
-
-        if (rparen.getLineNo() == lparen.getLineNo()) {
-            return;
-        }
-
-        checkExpressionSubtree(
-            getMainAst().findFirstToken(TokenTypes.ELIST),
-            new IndentLevel(getIndent(), getBasicOffset()),
-            false, true);
-
-        checkRParen(lparen, rparen);
-        final LineWrappingHandler lineWrap =
-            new LineWrappingHandler(getIndentCheck(), getMainAst(),
-                    getMethodCallLastNode(getMainAst()));
-        lineWrap.checkIndentation();
     }
 
     @Override
