@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -57,19 +57,65 @@ public class MethodDefHandler extends BlockParentHandler {
         }
     }
 
+    /**
+     * Check the indentation level of the throws clause.
+     */
+    private void checkThrows() {
+        final DetailAST throwsAst = getMainAst().findFirstToken(TokenTypes.LITERAL_THROWS);
+
+        if (throwsAst != null) {
+            checkWrappingIndentation(throwsAst, throwsAst.getNextSibling(), getIndentCheck()
+                    .getThrowsIndent(), getLineStart(getMethodDefLineStart(getMainAst())),
+                    !isOnStartOfLine(throwsAst));
+        }
+    }
+
+    /**
+     * Gets the start line of the method, excluding any annotations. This is required because the
+     * current {@link TokenTypes#METHOD_DEF} may not always be the start as seen in
+     * https://github.com/checkstyle/checkstyle/issues/3145.
+     *
+     * @param mainAst
+     *            The method definition ast.
+     * @return The start column position of the method.
+     */
+    private int getMethodDefLineStart(DetailAST mainAst) {
+        // get first type position
+        int lineStart = mainAst.findFirstToken(TokenTypes.IDENT).getLineNo();
+
+        // check if there is a type before the indent
+        final DetailAST typeNode = mainAst.findFirstToken(TokenTypes.TYPE);
+        if (typeNode != null) {
+            lineStart = getFirstLine(lineStart, typeNode);
+        }
+
+        // check if there is a modifier before the type
+        for (DetailAST node = mainAst.findFirstToken(TokenTypes.MODIFIERS).getFirstChild();
+                node != null;
+                node = node.getNextSibling()) {
+            // skip annotations as we check them else where as outside the method
+            if (node.getType() == TokenTypes.ANNOTATION) {
+                continue;
+            }
+
+            if (node.getLineNo() < lineStart) {
+                lineStart = node.getLineNo();
+            }
+        }
+
+        return lineStart;
+    }
+
     @Override
     public void checkIndentation() {
         checkModifiers();
+        checkThrows();
 
-        final LineWrappingHandler lineWrap =
-            new LineWrappingHandler(getIndentCheck(), getMainAst(),
-                getMethodDefParamRightParen(getMainAst()));
-        lineWrap.checkIndentation();
-        if (getLCurly() == null) {
-            // abstract method def -- no body
-            return;
+        checkWrappingIndentation(getMainAst(), getMethodDefParamRightParen(getMainAst()));
+        // abstract method def -- no body
+        if (getLCurly() != null) {
+            super.checkIndentation();
         }
-        super.checkIndentation();
     }
 
     /**
