@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -53,10 +53,8 @@ public class SynchronizedHandler extends BlockParentHandler {
         if (!methodModifier) {
             super.checkIndentation();
             checkSynchronizedExpr();
-            final LineWrappingHandler lineWrap =
-                    new LineWrappingHandler(getIndentCheck(), getMainAst(),
-                            getSynchronizedStatementRightParen(getMainAst()));
-            lineWrap.checkIndentation();
+            checkWrappingIndentation(getMainAst(),
+                    getSynchronizedStatementRightParen(getMainAst()));
         }
     }
 
