@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -22,11 +22,10 @@ package com.puppycrawl.tools.checkstyle.checks.modifier;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.commons.lang3.ArrayUtils;
-
-import com.puppycrawl.tools.checkstyle.api.Check;
+import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
+import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
 /**
  * Checks for redundant modifiers in interface and annotation definitions,
@@ -54,7 +53,26 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  *
  * <p>Enums by definition are static implicit subclasses of java.lang.Enum&#60;E&#62;.
  * So, the <code>static</code> modifier on the enums is redundant. In addition,
- * if enum is inside of interface, <code>public</code> modifier is also redundant.
+ * if enum is inside of interface, <code>public</code> modifier is also redundant.</p>
+ *
+ * <p>Enums can also contain abstract methods and methods which can be overridden by the declared
+ * enumeration fields.
+ * See the following example:</p>
+ * <pre>
+ * public enum EnumClass {
+ *    FIELD_1,
+ *    FIELD_2 {
+ *        &#64;Override
+ *        public final void method1() {} // violation expected
+ *    };
+ *
+ *    public void method1() {}
+ *    public final void method2() {} // no violation expected
+ * }
+ * </pre>
+ *
+ * <p>Since these methods can be overridden in these situations, the final methods are not
+ * marked as redundant even though they can't be extended by other classes/enums.</p>
  *
  * <p>Final classes by definition cannot be extended so the <code>final</code>
  * modifier on the method of a final class is redundant.
@@ -97,7 +115,7 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * @author Vladislav Lisetskiy
  */
 public class RedundantModifierCheck
-    extends Check {
+    extends AbstractCheck {
 
     /**
      * A key is pointing to the warning message text in "messages.properties"
@@ -120,7 +138,7 @@ public class RedundantModifierCheck
 
     @Override
     public int[] getRequiredTokens() {
-        return ArrayUtils.EMPTY_INT_ARRAY;
+        return CommonUtils.EMPTY_INT_ARRAY;
     }
 
     @Override
@@ -133,6 +151,7 @@ public class RedundantModifierCheck
             TokenTypes.CTOR_DEF,
             TokenTypes.CLASS_DEF,
             TokenTypes.ENUM_DEF,
+            TokenTypes.RESOURCE,
         };
     }
 
@@ -141,22 +160,28 @@ public class RedundantModifierCheck
         if (ast.getType() == TokenTypes.INTERFACE_DEF) {
             checkInterfaceModifiers(ast);
         }
-        else if (ast.getType() == TokenTypes.CTOR_DEF) {
-            if (isEnumMember(ast)) {
-                checkEnumConstructorModifiers(ast);
-            }
-            else {
-                checkClassConstructorModifiers(ast);
-            }
-        }
         else if (ast.getType() == TokenTypes.ENUM_DEF) {
             checkEnumDef(ast);
         }
-        else if (isInterfaceOrAnnotationMember(ast)) {
-            processInterfaceOrAnnotation(ast);
-        }
-        else if (ast.getType() == TokenTypes.METHOD_DEF) {
-            processMethods(ast);
+        else {
+            if (ast.getType() == TokenTypes.CTOR_DEF) {
+                if (isEnumMember(ast)) {
+                    checkEnumConstructorModifiers(ast);
+                }
+                else {
+                    checkClassConstructorModifiers(ast);
+                }
+            }
+            else if (ast.getType() == TokenTypes.METHOD_DEF) {
+                processMethods(ast);
+            }
+            else if (ast.getType() == TokenTypes.RESOURCE) {
+                processResources(ast);
+            }
+
+            if (isInterfaceOrAnnotationMember(ast)) {
+                processInterfaceOrAnnotation(ast);
+            }
         }
     }
 
@@ -200,12 +225,7 @@ public class RedundantModifierCheck
             processInterfaceOrAnnotation(ast);
         }
         else if (ast.getParent() != null) {
-            final DetailAST modifiers = ast.findFirstToken(TokenTypes.MODIFIERS);
-            final DetailAST staticModifier = modifiers.findFirstToken(TokenTypes.LITERAL_STATIC);
-            if (staticModifier != null) {
-                log(staticModifier.getLineNo(), staticModifier.getColumnNo(),
-                        MSG_KEY, staticModifier.getText());
-            }
+            checkForRedundantModifier(ast, TokenTypes.LITERAL_STATIC);
         }
     }
 
@@ -240,7 +260,7 @@ public class RedundantModifierCheck
     }
 
     /**
-     * Process validation ofMethods.
+     * Process validation of Methods.
      * @param ast method AST
      */
     private void processMethods(DetailAST ast) {
@@ -258,7 +278,8 @@ public class RedundantModifierCheck
                 checkFinal = checkFinal || classModifiers.branchContains(TokenTypes.FINAL);
                 parent = null;
             }
-            else if (parent.getType() == TokenTypes.LITERAL_NEW) {
+            else if (parent.getType() == TokenTypes.LITERAL_NEW
+                    || parent.getType() == TokenTypes.ENUM_CONSTANT_DEF) {
                 checkFinal = true;
                 parent = null;
             }
@@ -267,15 +288,25 @@ public class RedundantModifierCheck
             }
         }
         if (checkFinal && !isAnnotatedWithSafeVarargs(ast)) {
-            DetailAST modifier = modifiers.getFirstChild();
-            while (modifier != null) {
-                final int type = modifier.getType();
-                if (type == TokenTypes.FINAL) {
-                    log(modifier.getLineNo(), modifier.getColumnNo(),
-                            MSG_KEY, modifier.getText());
-                    break;
-                }
-                modifier = modifier.getNextSibling();
+            checkForRedundantModifier(ast, TokenTypes.FINAL);
+        }
+
+        if (!ast.branchContains(TokenTypes.SLIST)) {
+            processAbstractMethodParameters(ast);
+        }
+    }
+
+    /**
+     * Process validation of parameters for Methods with no definition.
+     * @param ast method AST
+     */
+    private void processAbstractMethodParameters(DetailAST ast) {
+        final DetailAST parameters = ast.findFirstToken(TokenTypes.PARAMETERS);
+
+        for (DetailAST child = parameters.getFirstChild(); child != null; child = child
+                .getNextSibling()) {
+            if (child.getType() == TokenTypes.PARAMETER_DEF) {
+                checkForRedundantModifier(child, TokenTypes.FINAL);
             }
         }
     }
@@ -287,19 +318,28 @@ public class RedundantModifierCheck
     private void checkClassConstructorModifiers(DetailAST classCtorAst) {
         final DetailAST classDef = classCtorAst.getParent().getParent();
         if (!isClassPublic(classDef) && !isClassProtected(classDef)) {
-            checkForRedundantPublicModifier(classCtorAst);
+            checkForRedundantModifier(classCtorAst, TokenTypes.LITERAL_PUBLIC);
         }
     }
 
     /**
-     * Checks if given ast has redundant public modifier.
+     * Checks if given resource has redundant modifiers.
      * @param ast ast
      */
-    private void checkForRedundantPublicModifier(DetailAST ast) {
+    private void processResources(DetailAST ast) {
+        checkForRedundantModifier(ast, TokenTypes.FINAL);
+    }
+
+    /**
+     * Checks if given ast has a redundant modifier.
+     * @param ast ast
+     * @param modifierType The modifier to check for.
+     */
+    private void checkForRedundantModifier(DetailAST ast, int modifierType) {
         final DetailAST astModifiers = ast.findFirstToken(TokenTypes.MODIFIERS);
         DetailAST astModifier = astModifiers.getFirstChild();
         while (astModifier != null) {
-            if (astModifier.getType() == TokenTypes.LITERAL_PUBLIC) {
+            if (astModifier.getType() == modifierType) {
                 log(astModifier.getLineNo(), astModifier.getColumnNo(),
                         MSG_KEY, astModifier.getText());
             }
