@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -20,6 +20,7 @@
 package com.puppycrawl.tools.checkstyle.filters;
 
 import java.lang.ref.WeakReference;
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
@@ -30,7 +31,6 @@ import java.util.regex.PatternSyntaxException;
 
 import org.apache.commons.beanutils.ConversionException;
 
-import com.google.common.collect.Lists;
 import com.puppycrawl.tools.checkstyle.api.AuditEvent;
 import com.puppycrawl.tools.checkstyle.api.AutomaticBean;
 import com.puppycrawl.tools.checkstyle.api.FileContents;
@@ -88,25 +88,27 @@ public class SuppressWithNearbyCommentFilter
     private static final String DEFAULT_INFLUENCE_FORMAT = "0";
 
     /** Tagged comments. */
-    private final List<Tag> tags = Lists.newArrayList();
+    private final List<Tag> tags = new ArrayList<>();
 
     /** Whether to look for trigger in C-style comments. */
     private boolean checkC = true;
 
     /** Whether to look for trigger in C++-style comments. */
+    // -@cs[AbbreviationAsWordInName] We can not change it as,
+    // check's property is a part of API (used in configurations).
     private boolean checkCPP = true;
 
     /** Parsed comment regexp that marks checkstyle suppression region. */
-    private Pattern commentRegexp;
+    private Pattern commentFormat = Pattern.compile(DEFAULT_COMMENT_FORMAT);
 
     /** The comment pattern that triggers suppression. */
-    private String checkFormat;
+    private String checkFormat = DEFAULT_CHECK_FORMAT;
 
     /** The message format to suppress. */
     private String messageFormat;
 
     /** The influence of the suppression comment. */
-    private String influenceFormat;
+    private String influenceFormat = DEFAULT_INFLUENCE_FORMAT;
 
     /**
      * References the current FileContents for this filter.
@@ -117,24 +119,12 @@ public class SuppressWithNearbyCommentFilter
      */
     private WeakReference<FileContents> fileContentsReference = new WeakReference<>(null);
 
-    /**
-     * Constructs a SuppressionCommentFilter.
-     * Initializes comment on, comment off, and check formats
-     * to defaults.
-     */
-    public SuppressWithNearbyCommentFilter() {
-        setCommentFormat(DEFAULT_COMMENT_FORMAT);
-        checkFormat = DEFAULT_CHECK_FORMAT;
-        influenceFormat = DEFAULT_INFLUENCE_FORMAT;
-    }
-
     /**
      * Set the format for a comment that turns off reporting.
-     * @param format a {@code String} value.
-     * @throws ConversionException if unable to create Pattern object.
+     * @param pattern a pattern.
      */
-    public final void setCommentFormat(String format) {
-        commentRegexp = CommonUtils.createPattern(format);
+    public final void setCommentFormat(Pattern pattern) {
+        commentFormat = pattern;
     }
 
     /**
@@ -180,6 +170,8 @@ public class SuppressWithNearbyCommentFilter
      * Set whether to look in C++ comments.
      * @param checkCpp {@code true} if C++ comments are checked.
      */
+    // -@cs[AbbreviationAsWordInName] We can not change it as,
+    // check's property is a part of API (used in configurations).
     public void setCheckCPP(boolean checkCpp) {
         checkCPP = checkCpp;
     }
@@ -199,16 +191,14 @@ public class SuppressWithNearbyCommentFilter
         if (event.getLocalizedMessage() != null) {
             // Lazy update. If the first event for the current file, update file
             // contents and tag suppressions
-            final FileContents currentContents = FileContentsHolder.getContents();
+            final FileContents currentContents = FileContentsHolder.getCurrentFileContents();
 
-            if (currentContents != null) {
-                if (getFileContents() != currentContents) {
-                    setFileContents(currentContents);
-                    tagSuppressions();
-                }
-                if (matchesTag(event)) {
-                    accepted = false;
-                }
+            if (getFileContents() != currentContents) {
+                setFileContents(currentContents);
+                tagSuppressions();
+            }
+            if (matchesTag(event)) {
+                accepted = false;
             }
         }
         return accepted;
@@ -241,9 +231,7 @@ public class SuppressWithNearbyCommentFilter
         if (checkC) {
             final Collection<List<TextBlock>> cComments =
                 contents.getCComments().values();
-            for (final List<TextBlock> element : cComments) {
-                tagSuppressions(element);
-            }
+            cComments.forEach(this::tagSuppressions);
         }
         Collections.sort(tags);
     }
@@ -271,7 +259,7 @@ public class SuppressWithNearbyCommentFilter
      * @param line the line number of text.
      */
     private void tagCommentLine(String text, int line) {
-        final Matcher matcher = commentRegexp.matcher(text);
+        final Matcher matcher = commentFormat.matcher(text);
         if (matcher.find()) {
             addTag(matcher.group(0), line);
         }
@@ -321,18 +309,18 @@ public class SuppressWithNearbyCommentFilter
             String format = "";
             try {
                 format = CommonUtils.fillTemplateWithStringsByRegexp(
-                        filter.checkFormat, text, filter.commentRegexp);
+                        filter.checkFormat, text, filter.commentFormat);
                 tagCheckRegexp = Pattern.compile(format);
                 if (filter.messageFormat == null) {
                     tagMessageRegexp = null;
                 }
                 else {
                     format = CommonUtils.fillTemplateWithStringsByRegexp(
-                            filter.messageFormat, text, filter.commentRegexp);
+                            filter.messageFormat, text, filter.commentFormat);
                     tagMessageRegexp = Pattern.compile(format);
                 }
                 format = CommonUtils.fillTemplateWithStringsByRegexp(
-                        filter.influenceFormat, text, filter.commentRegexp);
+                        filter.influenceFormat, text, filter.commentFormat);
                 final int influence;
                 try {
                     if (CommonUtils.startsWithChar(format, '+')) {
