@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -20,6 +20,7 @@
 package com.puppycrawl.tools.checkstyle.filters;
 
 import java.lang.ref.WeakReference;
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
@@ -30,7 +31,6 @@ import java.util.regex.PatternSyntaxException;
 
 import org.apache.commons.beanutils.ConversionException;
 
-import com.google.common.collect.Lists;
 import com.puppycrawl.tools.checkstyle.api.AuditEvent;
 import com.puppycrawl.tools.checkstyle.api.AutomaticBean;
 import com.puppycrawl.tools.checkstyle.api.FileContents;
@@ -67,31 +67,33 @@ public class SuppressionCommentFilter
     implements Filter {
 
     /** Turns checkstyle reporting off. */
-    private static final String DEFAULT_OFF_FORMAT = "CHECKSTYLE\\:OFF";
+    private static final String DEFAULT_OFF_FORMAT = "CHECKSTYLE:OFF";
 
     /** Turns checkstyle reporting on. */
-    private static final String DEFAULT_ON_FORMAT = "CHECKSTYLE\\:ON";
+    private static final String DEFAULT_ON_FORMAT = "CHECKSTYLE:ON";
 
     /** Control all checks. */
     private static final String DEFAULT_CHECK_FORMAT = ".*";
 
     /** Tagged comments. */
-    private final List<Tag> tags = Lists.newArrayList();
+    private final List<Tag> tags = new ArrayList<>();
 
     /** Whether to look in comments of the C type. */
     private boolean checkC = true;
 
     /** Whether to look in comments of the C++ type. */
+    // -@cs[AbbreviationAsWordInName] we can not change it as,
+    // Check property is a part of API (used in configurations)
     private boolean checkCPP = true;
 
     /** Parsed comment regexp that turns checkstyle reporting off. */
-    private Pattern offRegexp;
+    private Pattern offCommentFormat = Pattern.compile(DEFAULT_OFF_FORMAT);
 
     /** Parsed comment regexp that turns checkstyle reporting on. */
-    private Pattern onRegexp;
+    private Pattern onCommentFormat = Pattern.compile(DEFAULT_ON_FORMAT);
 
     /** The check format to suppress. */
-    private String checkFormat;
+    private String checkFormat = DEFAULT_CHECK_FORMAT;
 
     /** The message format to suppress. */
     private String messageFormat;
@@ -105,33 +107,20 @@ public class SuppressionCommentFilter
      */
     private WeakReference<FileContents> fileContentsReference = new WeakReference<>(null);
 
-    /**
-     * Constructs a SuppressionCommentFilter.
-     * Initializes comment on, comment off, and check formats
-     * to defaults.
-     */
-    public SuppressionCommentFilter() {
-        setOnCommentFormat(DEFAULT_ON_FORMAT);
-        setOffCommentFormat(DEFAULT_OFF_FORMAT);
-        checkFormat = DEFAULT_CHECK_FORMAT;
-    }
-
     /**
      * Set the format for a comment that turns off reporting.
-     * @param format a {@code String} value.
-     * @throws ConversionException if unable to create Pattern object.
+     * @param pattern a pattern.
      */
-    public final void setOffCommentFormat(String format) {
-        offRegexp = CommonUtils.createPattern(format);
+    public final void setOffCommentFormat(Pattern pattern) {
+        offCommentFormat = pattern;
     }
 
     /**
      * Set the format for a comment that turns on reporting.
-     * @param format a {@code String} value
-     * @throws ConversionException if unable to create Pattern object.
+     * @param pattern a pattern.
      */
-    public final void setOnCommentFormat(String format) {
-        onRegexp = CommonUtils.createPattern(format);
+    public final void setOnCommentFormat(Pattern pattern) {
+        onCommentFormat = pattern;
     }
 
     /**
@@ -169,6 +158,8 @@ public class SuppressionCommentFilter
      * Set whether to look in C++ comments.
      * @param checkCpp {@code true} if C++ comments are checked.
      */
+    // -@cs[AbbreviationAsWordInName] We can not change it as,
+    // check's property is a part of API (used in configurations).
     public void setCheckCPP(boolean checkCpp) {
         checkCPP = checkCpp;
     }
@@ -188,16 +179,14 @@ public class SuppressionCommentFilter
         if (event.getLocalizedMessage() != null) {
             // Lazy update. If the first event for the current file, update file
             // contents and tag suppressions
-            final FileContents currentContents = FileContentsHolder.getContents();
+            final FileContents currentContents = FileContentsHolder.getCurrentFileContents();
 
-            if (currentContents != null) {
-                if (getFileContents() != currentContents) {
-                    setFileContents(currentContents);
-                    tagSuppressions();
-                }
-                final Tag matchTag = findNearestMatch(event);
-                accepted = matchTag == null || matchTag.isReportingOn();
+            if (getFileContents() != currentContents) {
+                setFileContents(currentContents);
+                tagSuppressions();
             }
+            final Tag matchTag = findNearestMatch(event);
+            accepted = matchTag == null || matchTag.isReportingOn();
         }
         return accepted;
     }
@@ -236,9 +225,7 @@ public class SuppressionCommentFilter
         if (checkC) {
             final Collection<List<TextBlock>> cComments = contents
                     .getCComments().values();
-            for (List<TextBlock> element : cComments) {
-                tagSuppressions(element);
-            }
+            cComments.forEach(this::tagSuppressions);
         }
         Collections.sort(tags);
     }
@@ -267,12 +254,12 @@ public class SuppressionCommentFilter
      * @param column the column number of text.
      */
     private void tagCommentLine(String text, int line, int column) {
-        final Matcher offMatcher = offRegexp.matcher(text);
+        final Matcher offMatcher = offCommentFormat.matcher(text);
         if (offMatcher.find()) {
             addTag(offMatcher.group(0), line, column, false);
         }
         else {
-            final Matcher onMatcher = onRegexp.matcher(text);
+            final Matcher onMatcher = onCommentFormat.matcher(text);
             if (onMatcher.find()) {
                 addTag(onMatcher.group(0), line, column, true);
             }
@@ -338,27 +325,27 @@ public class SuppressionCommentFilter
             try {
                 if (reportingOn) {
                     format = CommonUtils.fillTemplateWithStringsByRegexp(
-                            filter.checkFormat, text, filter.onRegexp);
+                            filter.checkFormat, text, filter.onCommentFormat);
                     tagCheckRegexp = Pattern.compile(format);
                     if (filter.messageFormat == null) {
                         tagMessageRegexp = null;
                     }
                     else {
                         format = CommonUtils.fillTemplateWithStringsByRegexp(
-                                filter.messageFormat, text, filter.onRegexp);
+                                filter.messageFormat, text, filter.onCommentFormat);
                         tagMessageRegexp = Pattern.compile(format);
                     }
                 }
                 else {
                     format = CommonUtils.fillTemplateWithStringsByRegexp(
-                            filter.checkFormat, text, filter.offRegexp);
+                            filter.checkFormat, text, filter.offCommentFormat);
                     tagCheckRegexp = Pattern.compile(format);
                     if (filter.messageFormat == null) {
                         tagMessageRegexp = null;
                     }
                     else {
                         format = CommonUtils.fillTemplateWithStringsByRegexp(
-                                filter.messageFormat, text, filter.offRegexp);
+                                filter.messageFormat, text, filter.offCommentFormat);
                         tagMessageRegexp = Pattern.compile(format);
                     }
                 }
@@ -425,12 +412,14 @@ public class SuppressionCommentFilter
             return Objects.equals(line, tag.line)
                     && Objects.equals(column, tag.column)
                     && Objects.equals(reportingOn, tag.reportingOn)
-                    && Objects.equals(text, tag.text);
+                    && Objects.equals(text, tag.text)
+                    && Objects.equals(tagCheckRegexp, tag.tagCheckRegexp)
+                    && Objects.equals(tagMessageRegexp, tag.tagMessageRegexp);
         }
 
         @Override
         public int hashCode() {
-            return Objects.hash(text, line, column, reportingOn);
+            return Objects.hash(text, line, column, reportingOn, tagCheckRegexp, tagMessageRegexp);
         }
 
         /**
