@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -20,8 +20,6 @@
 package com.puppycrawl.tools.checkstyle.gui;
 
 import javax.swing.ListSelectionModel;
-import javax.swing.event.ListSelectionEvent;
-import javax.swing.event.ListSelectionListener;
 import javax.swing.tree.DefaultTreeSelectionModel;
 import javax.swing.tree.TreePath;
 
@@ -45,7 +43,8 @@ class ListToTreeSelectionModelWrapper extends DefaultTreeSelectionModel {
      */
     ListToTreeSelectionModelWrapper(JTreeTable jTreeTable) {
         treeTable = jTreeTable;
-        getListSelectionModel().addListSelectionListener(createListSelectionListener());
+        getListSelectionModel().addListSelectionListener(event ->
+            updateSelectedPathsFromSelectedRows());
     }
 
     /**
@@ -55,7 +54,7 @@ class ListToTreeSelectionModelWrapper extends DefaultTreeSelectionModel {
      *
      * @return the list selection model
      */
-    final ListSelectionModel getListSelectionModel() {
+    protected final ListSelectionModel getListSelectionModel() {
         return listSelectionModel;
     }
 
@@ -82,15 +81,6 @@ class ListToTreeSelectionModelWrapper extends DefaultTreeSelectionModel {
         // paths are the only thing that needs to be updated.
     }
 
-    /**
-     * Creates an instance of ListSelectionHandler.
-     *
-     * @return An instance of ListSelectionHandler
-     */
-    private ListSelectionListener createListSelectionListener() {
-        return new ListSelectionHandler();
-    }
-
     /**
      * If {@code updatingListSelectionModel} is false, this will
      * reset the selected paths from the selected rows in the list
@@ -131,15 +121,4 @@ class ListToTreeSelectionModelWrapper extends DefaultTreeSelectionModel {
             }
         }
     }
-
-    /**
-     * Class responsible for calling updateSelectedPathsFromSelectedRows
-     * when the selection of the list changes.
-     */
-    private class ListSelectionHandler implements ListSelectionListener {
-        @Override
-        public void valueChanged(ListSelectionEvent event) {
-            updateSelectedPathsFromSelectedRows();
-        }
-    }
 }
