@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -25,12 +25,8 @@ import javax.swing.event.TreeModelListener;
 import javax.swing.tree.TreeModel;
 import javax.swing.tree.TreePath;
 
-import antlr.ASTFactory;
-import antlr.collections.AST;
-
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
-import com.puppycrawl.tools.checkstyle.api.TokenTypes;
-import com.puppycrawl.tools.checkstyle.utils.TokenUtils;
+import com.puppycrawl.tools.checkstyle.gui.MainFrameModel.ParseMode;
 
 /**
  * The model that backs the parse tree in the GUI.
@@ -38,16 +34,8 @@ import com.puppycrawl.tools.checkstyle.utils.TokenUtils;
  * @author Lars Kühne
  */
 public class ParseTreeTableModel implements TreeModel {
-
-    /** Column names. */
-    private static final String[] COLUMN_NAMES = {
-        "Tree", "Type", "Line", "Column", "Text",
-    };
-
-    /**
-     * The root node of the tree table model.
-     */
-    private final Object root;
+    /** Presentation model. */
+    private final ParseTreeTablePModel pModel;
 
     /**
      * A list of event listeners for the tree model.
@@ -58,37 +46,35 @@ public class ParseTreeTableModel implements TreeModel {
      * @param parseTree DetailAST parse tree.
      */
     public ParseTreeTableModel(DetailAST parseTree) {
-        root = createArtificialTreeRoot();
+        pModel = new ParseTreeTablePModel(parseTree);
         setParseTree(parseTree);
     }
 
-    /**
-     * Creates artificial tree root.
-     * @return Artificial tree root.
-     */
-    private static DetailAST createArtificialTreeRoot() {
-        final ASTFactory factory = new ASTFactory();
-        factory.setASTNodeClass(DetailAST.class.getName());
-        return (DetailAST) factory.create(TokenTypes.EOF, "ROOT");
-    }
-
     /**
      * Sets parse tree.
      * @param parseTree DetailAST parse tree.
      */
-    final void setParseTree(DetailAST parseTree) {
-        ((AST) root).setFirstChild(parseTree);
-        final Object[] path = {root};
+    protected final void setParseTree(DetailAST parseTree) {
+        pModel.setParseTree(parseTree);
+        final Object[] path = {pModel.getRoot()};
         // no need to setup remaining info, as the call results in a
         // table structure changed event anyway - we just pass nulls
         fireTreeStructureChanged(this, path, null, (Object[]) null);
     }
 
+    /**
+     * Set parse mode.
+     * @param mode ParseMode enum
+     */
+    protected void setParseMode(ParseMode mode) {
+        pModel.setParseMode(mode);
+    }
+
     /**
      * @return the number of available column.
      */
     public int getColumnCount() {
-        return COLUMN_NAMES.length;
+        return pModel.getColumnCount();
     }
 
     /**
@@ -96,36 +82,17 @@ public class ParseTreeTableModel implements TreeModel {
      * @return the name for column number {@code column}.
      */
     public String getColumnName(int column) {
-        return COLUMN_NAMES[column];
+        return pModel.getColumnName(column);
     }
 
     /**
      * @param column the column number
      * @return the type for column number {@code column}.
      */
+    // -@cs[ForbidWildcardAsReturnType] We need to satisfy javax.swing.table.AbstractTableModel
+    // public Class<?> getColumnClass(int columnIndex) {...}
     public Class<?> getColumnClass(int column) {
-        final Class<?> columnClass;
-
-        switch (column) {
-            case 0:
-                columnClass = ParseTreeTableModel.class;
-                break;
-            case 1:
-                columnClass = String.class;
-                break;
-            case 2:
-                columnClass = Integer.class;
-                break;
-            case 3:
-                columnClass = Integer.class;
-                break;
-            case 4:
-                columnClass = String.class;
-                break;
-            default:
-                columnClass = Object.class;
-        }
-        return columnClass;
+        return pModel.getColumnClass(column);
     }
 
     /**
@@ -135,70 +102,38 @@ public class ParseTreeTableModel implements TreeModel {
      *     at column number {@code column}.
      */
     public Object getValueAt(Object node, int column) {
-        final DetailAST ast = (DetailAST) node;
-        final Object value;
-
-        switch (column) {
-            case 1:
-                value = TokenUtils.getTokenName(ast.getType());
-                break;
-            case 2:
-                value = ast.getLineNo();
-                break;
-            case 3:
-                value = ast.getColumnNo();
-                break;
-            case 4:
-                value = ast.getText();
-                break;
-            default:
-                value = null;
-        }
-        return value;
+        return pModel.getValueAt(node, column);
     }
 
     @Override
     public Object getChild(Object parent, int index) {
-        final DetailAST ast = (DetailAST) parent;
-        int currentIndex = 0;
-        AST child = ast.getFirstChild();
-        while (currentIndex < index) {
-            child = child.getNextSibling();
-            currentIndex++;
-        }
-        return child;
+        return pModel.getChild(parent, index);
     }
 
     @Override
     public int getChildCount(Object parent) {
-        final DetailAST ast = (DetailAST) parent;
-        return ast.getChildCount();
+        return pModel.getChildCount(parent);
     }
 
     @Override
     public void valueForPathChanged(TreePath path, Object newValue) {
-        //No Code, as tree is read-only
+        // No Code, as tree is read-only
     }
 
     @Override
     public Object getRoot() {
-        return root;
+        return pModel.getRoot();
     }
 
     @Override
     public boolean isLeaf(Object node) {
-        return getChildCount(node) == 0;
+        return pModel.isLeaf(node);
     }
 
     // This is not called in the JTree's default mode: use a naive implementation.
     @Override
     public int getIndexOfChild(Object parent, Object child) {
-        for (int i = 0; i < getChildCount(parent); i++) {
-            if (getChild(parent, i).equals(child)) {
-                return i;
-            }
-        }
-        return -1;
+        return pModel.getIndexOfChild(parent, child);
     }
 
     @Override
@@ -222,7 +157,7 @@ public class ParseTreeTableModel implements TreeModel {
      * @param children An array of Object containing the inserted, removed, or changed objects.
      * @see EventListenerList
      */
-    final void fireTreeStructureChanged(Object source, Object[] path,
+    private void fireTreeStructureChanged(Object source, Object[] path,
                                   int[] childIndices,
                                   Object... children) {
         // Guaranteed to return a non-null array
@@ -250,6 +185,6 @@ public class ParseTreeTableModel implements TreeModel {
      * @return true if editable
      */
     public boolean isCellEditable(int column) {
-        return getColumnClass(column) == ParseTreeTableModel.class;
+        return pModel.isCellEditable(column);
     }
 }
