@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -113,12 +113,7 @@ public class TreeTableModelAdapter extends AbstractTableModel {
      * processed. SwingUtilities.invokeLater is used to handle this.
      */
     private void delayedFireTableDataChanged() {
-        SwingUtilities.invokeLater(new Runnable() {
-            @Override
-            public void run() {
-                fireTableDataChanged();
-            }
-        });
+        SwingUtilities.invokeLater(this::fireTableDataChanged);
     }
 
     /**
