@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,6 @@
 package com.puppycrawl.tools.checkstyle.utils;
 
 import antlr.collections.AST;
-
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.Scope;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
@@ -193,7 +192,7 @@ public final class ScopeUtils {
 
     /**
      * Returns whether the scope of a node is restricted to a code block.
-     * A code block is a method or constructor body, or a initializer block.
+     * A code block is a method or constructor body, an initializer block, or lambda body.
      *
      * @param node the node to check
      * @return a {@code boolean} value
@@ -207,9 +206,10 @@ public final class ScopeUtils {
              token = token.getParent()) {
             final int type = token.getType();
             if (type == TokenTypes.METHOD_DEF
-                || type == TokenTypes.CTOR_DEF
-                || type == TokenTypes.INSTANCE_INIT
-                || type == TokenTypes.STATIC_INIT) {
+                    || type == TokenTypes.CTOR_DEF
+                    || type == TokenTypes.INSTANCE_INIT
+                    || type == TokenTypes.STATIC_INIT
+                    || type == TokenTypes.LAMBDA) {
                 returnValue = true;
                 break;
             }
@@ -266,6 +266,17 @@ public final class ScopeUtils {
         return localVariableDef;
     }
 
+    /**
+     * Determines whether a node is a class field definition.
+     * I.e. if a variable is not declared in a code block, a for initializer,
+     * or a catch parameter.
+     * @param node the node to check.
+     * @return whether a node is a class field definition.
+     */
+    public static boolean isClassFieldDef(DetailAST node) {
+        return node.getType() == TokenTypes.VARIABLE_DEF && !isLocalVariableDef(node);
+    }
+
     /**
      * Checks whether ast node is in a specific scope.
      * @param ast the node to check.
