@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -29,17 +29,19 @@ import java.io.IOException;
 import java.io.InputStreamReader;
 import java.io.LineNumberReader;
 import java.nio.charset.StandardCharsets;
+import java.nio.file.Files;
+import java.nio.file.Paths;
 import java.text.MessageFormat;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Properties;
+import java.util.stream.Collectors;
 
-import com.google.common.base.Predicate;
-import com.google.common.collect.Lists;
 import com.google.common.collect.MapDifference;
 import com.google.common.collect.MapDifference.ValueDifference;
 import com.google.common.collect.Maps;
@@ -52,6 +54,12 @@ public class BaseCheckTestSupport {
         return new DefaultConfiguration(clazz.getName());
     }
 
+    /**
+     * Creates {@link Checker} instance based on the given {@link Configuration} instance.
+     * @param checkConfig {@link Configuration} instance.
+     * @return {@link Checker} instance based on the given {@link Configuration} instance.
+     * @throws Exception if an exception occurs during checker configuration.
+     */
     public Checker createChecker(Configuration checkConfig)
             throws Exception {
         final DefaultConfiguration dc = createCheckerConfig(checkConfig);
@@ -67,6 +75,13 @@ public class BaseCheckTestSupport {
         return checker;
     }
 
+    /**
+     * Creates {@link DefaultConfiguration} for the {@link Checker}
+     * based on the given {@link Configuration} instance.
+     * @param config {@link Configuration} instance.
+     * @return {@link DefaultConfiguration} for the {@link Checker}
+     * based on the given {@link Configuration} instance.
+     */
     protected DefaultConfiguration createCheckerConfig(Configuration config) {
         final DefaultConfiguration dc =
                 new DefaultConfiguration("configuration");
@@ -78,43 +93,143 @@ public class BaseCheckTestSupport {
         return dc;
     }
 
+    /**
+     * Returns canonical path for the file with the given file name.
+     * The path is formed base on the root location.
+     * This implementation uses 'src/test/resources/com/puppycrawl/tools/checkstyle/'
+     * as a root location.
+     * @param filename file name.
+     * @return canonical path for the file name.
+     * @throws IOException if I/O exception occurs while forming the path.
+     */
     protected String getPath(String filename) throws IOException {
         return new File("src/test/resources/com/puppycrawl/tools/checkstyle/" + filename)
                 .getCanonicalPath();
     }
 
+    /**
+     * Returns URI-representation of the path for the given file name.
+     * The path is formed base on the root location.
+     * This implementation uses 'src/test/resources/com/puppycrawl/tools/checkstyle/'
+     * as a root location.
+     * @param filename file name.
+     * @return URI-representation of the path for the file with the given file name.
+     */
     protected String getUriString(String filename) {
         return new File("src/test/resources/com/puppycrawl/tools/checkstyle/" + filename).toURI()
                 .toString();
     }
 
-    protected String getSrcPath(String filename) throws IOException {
+    /**
+     * Returns canonical path for the file with the given file name.
+     * The path is formed base on the sources location.
+     * This implementation uses 'src/test/java/com/puppycrawl/tools/checkstyle/'
+     * as a src location.
+     * @param filename file name.
+     * @return canonical path for the file with the given file name.
+     * @throws IOException if I/O exception occurs while forming the path.
+     */
+    protected static String getSrcPath(String filename) throws IOException {
         return new File("src/test/java/com/puppycrawl/tools/checkstyle/" + filename)
                 .getCanonicalPath();
     }
 
+    /**
+     * Returns canonical path for the file with the given file name.
+     * The path is formed base on the non-compilable resources location.
+     * This implementation uses 'src/test/resources-noncompilable/com/puppycrawl/tools/checkstyle/'
+     * as a non-compilable resource location.
+     * @param filename file name.
+     * @return canonical path for the file with the given file name.
+     * @throws IOException if I/O exception occurs while forming the path.
+     */
     protected String getNonCompilablePath(String filename) throws IOException {
         return new File("src/test/resources-noncompilable/com/puppycrawl/tools/checkstyle/"
                 + filename).getCanonicalPath();
     }
 
+    /**
+     * Performs verification of the given text ast tree representation.
+     * This implementation uses {@link BaseCheckTestSupport#verifyAst(String, String, boolean)}
+     * method inside.
+     * @param expectedTextPrintFileName expected text ast tree representation.
+     * @param actualJavaFileName actual text ast tree representation.
+     * @throws Exception if exception occurs during verification.
+     */
+    protected static void verifyAst(String expectedTextPrintFileName, String actualJavaFileName)
+            throws Exception {
+        verifyAst(expectedTextPrintFileName, actualJavaFileName, false);
+    }
+
+    /**
+     * Performs verification of the given text ast tree representation.
+     * @param expectedTextPrintFileName expected text ast tree representation.
+     * @param actualJavaFileName actual text ast tree representation.
+     * @param withComments whether to perform verification of comment nodes in tree.
+     * @throws Exception if exception occurs during verification.
+     */
+    protected static void verifyAst(String expectedTextPrintFileName, String actualJavaFileName,
+            boolean withComments) throws Exception {
+        final String expectedContents = new String(Files.readAllBytes(
+            Paths.get(expectedTextPrintFileName)), StandardCharsets.UTF_8)
+            .replaceAll("\\\\r\\\\n", "\\\\n");
+        final String actualContents = AstTreeStringPrinter.printFileAst(
+                new File(actualJavaFileName), withComments).replaceAll("\\\\r\\\\n", "\\\\n");
+
+        assertEquals("Generated AST from Java file should match pre-defined AST", expectedContents,
+                actualContents);
+    }
+
+    /**
+     * Performs verification of the file with the given file name. Uses specified configuration.
+     * Expected messages are represented by the array of strings.
+     * This implementation uses overloaded
+     * {@link BaseCheckTestSupport#verify(Checker, File[], String, String...)} method inside.
+     * @param aConfig configuration.
+     * @param fileName file name to verify.
+     * @param expected an array of expected messages.
+     * @throws Exception if exception occurs during verification process.
+     */
     protected void verify(Configuration aConfig, String fileName, String... expected)
             throws Exception {
         verify(createChecker(aConfig), fileName, fileName, expected);
     }
 
+    /**
+     * Performs verification of the file with the given file name.
+     * Uses provided {@link Checker} instance.
+     * Expected messages are represented by the array of strings.
+     * This implementation uses overloaded
+     * {@link BaseCheckTestSupport#verify(Checker, String, String, String...)} method inside.
+     * @param checker {@link Checker} instance.
+     * @param fileName file name to verify.
+     * @param expected an array of expected messages.
+     * @throws Exception if exception occurs during verification process.
+     */
     protected void verify(Checker checker, String fileName, String... expected)
             throws Exception {
         verify(checker, fileName, fileName, expected);
     }
 
+    /**
+     * Performs verification of the file with the given file name.
+     * Uses provided {@link Checker} instance.
+     * Expected messages are represented by the array of strings.
+     * This implementation uses overloaded
+     * {@link BaseCheckTestSupport#verify(Checker, File[], String, String...)} method inside.
+     * @param checker {@link Checker} instance.
+     * @param processedFilename file name to verify.
+     * @param messageFileName message file name.
+     * @param expected an array of expected messages.
+     * @throws Exception if exception occurs during verification process.
+     */
     protected void verify(Checker checker,
                           String processedFilename,
                           String messageFileName,
                           String... expected)
             throws Exception {
         verify(checker,
-                new File[]{new File(processedFilename)},
+                new File[] {new File(processedFilename)},
                 messageFileName, expected);
     }
 
@@ -128,20 +243,23 @@ public class BaseCheckTestSupport {
                           String... expected)
             throws Exception {
         stream.flush();
-        final List<File> theFiles = Lists.newArrayList();
+        final List<File> theFiles = new ArrayList<>();
         Collections.addAll(theFiles, processedFiles);
         final int errs = checker.process(theFiles);
 
         // process each of the lines
         final ByteArrayInputStream inputStream =
                 new ByteArrayInputStream(stream.toByteArray());
-        try (final LineNumberReader lnr = new LineNumberReader(
+        try (LineNumberReader lnr = new LineNumberReader(
                 new InputStreamReader(inputStream, StandardCharsets.UTF_8))) {
 
+            final List<String> actuals = lnr.lines().limit(expected.length)
+                    .sorted().collect(Collectors.toList());
+            Arrays.sort(expected);
+
             for (int i = 0; i < expected.length; i++) {
                 final String expectedResult = messageFileName + ":" + expected[i];
-                final String actual = lnr.readLine();
-                assertEquals("error message " + i, expectedResult, actual);
+                assertEquals("error message " + i, expectedResult, actuals.get(i));
             }
 
             assertEquals("unexpected output: " + lnr.readLine(),
@@ -151,24 +269,26 @@ public class BaseCheckTestSupport {
         checker.destroy();
     }
 
+    /**
+     * Performs verification of the given files.
+     * @param checker {@link Checker} instance
+     * @param processedFiles files to process.
+     * @param expectedViolations a map of expected violations per files.
+     * @throws Exception if exception occurs during verification process.
+     */
     protected void verify(Checker checker,
                           File[] processedFiles,
                           Map<String, List<String>> expectedViolations)
             throws Exception {
         stream.flush();
-        final List<File> theFiles = Lists.newArrayList();
+        final List<File> theFiles = new ArrayList<>();
         Collections.addAll(theFiles, processedFiles);
         final int errs = checker.process(theFiles);
 
         // process each of the lines
         final Map<String, List<String>> actualViolations = getActualViolations(errs);
         final Map<String, List<String>> realExpectedViolations =
-            Maps.filterValues(expectedViolations, new Predicate<List<String>>() {
-                @Override
-                public boolean apply(List<String> input) {
-                    return !input.isEmpty();
-                }
-            });
+            Maps.filterValues(expectedViolations, input -> !input.isEmpty());
         final MapDifference<String, List<String>> violationDifferences =
             Maps.difference(realExpectedViolations, actualViolations);
 
@@ -209,7 +329,7 @@ public class BaseCheckTestSupport {
         final ByteArrayInputStream inputStream =
                 new ByteArrayInputStream(stream.toByteArray());
 
-        try (final LineNumberReader lnr = new LineNumberReader(
+        try (LineNumberReader lnr = new LineNumberReader(
                 new InputStreamReader(inputStream, StandardCharsets.UTF_8))) {
 
             final Map<String, List<String>> actualViolations = new HashMap<>();
