@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -22,6 +22,7 @@ package com.puppycrawl.tools.checkstyle;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
+import static org.powermock.api.mockito.PowerMockito.when;
 
 import java.io.File;
 import java.io.FileInputStream;
@@ -32,6 +33,10 @@ import java.lang.reflect.Method;
 import java.util.Properties;
 
 import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.powermock.api.mockito.PowerMockito;
+import org.powermock.core.classloader.annotations.PrepareForTest;
+import org.powermock.modules.junit4.PowerMockRunner;
 import org.xml.sax.Attributes;
 import org.xml.sax.InputSource;
 
@@ -43,13 +48,15 @@ import com.puppycrawl.tools.checkstyle.api.Configuration;
  * @author Rick Giles
  * @author lkuehne
  */
+@RunWith(PowerMockRunner.class)
+@PrepareForTest({DefaultConfiguration.class, ConfigurationLoader.class})
 public class ConfigurationLoaderTest {
     private static String getConfigPath(String filename) {
         return "src/test/resources/com/puppycrawl/tools/checkstyle/configs/" + filename;
     }
 
     private static Configuration loadConfiguration(String name)
-        throws CheckstyleException {
+            throws CheckstyleException {
         return loadConfiguration(name, new Properties());
     }
 
@@ -61,6 +68,18 @@ public class ConfigurationLoaderTest {
                 fName, new PropertiesExpander(props));
     }
 
+    private static Method getReplacePropertiesMethod() throws Exception {
+        final Class<?>[] params = new Class<?>[3];
+        params[0] = String.class;
+        params[1] = PropertyResolver.class;
+        params[2] = String.class;
+        final Class<ConfigurationLoader> configurationLoaderClass = ConfigurationLoader.class;
+        final Method replacePropertiesMethod =
+            configurationLoaderClass.getDeclaredMethod("replaceProperties", params);
+        replacePropertiesMethod.setAccessible(true);
+        return replacePropertiesMethod;
+    }
+
     @Test
     public void testResourceLoadConfiguration() throws Exception {
         final Properties props = new Properties();
@@ -92,10 +111,9 @@ public class ConfigurationLoaderTest {
             fail("missing property name");
         }
         catch (CheckstyleException ex) {
-            assertTrue(
-                ex.getMessage().endsWith(
-                    "Attribute \"name\" is required and must be specified "
-                        + "for element type \"property\".:8:41"));
+            assertTrue(ex.getMessage().contains("\"name\""));
+            assertTrue(ex.getMessage().contains("\"property\""));
+            assertTrue(ex.getMessage().endsWith(":8:41"));
         }
     }
 
@@ -106,10 +124,9 @@ public class ConfigurationLoaderTest {
             fail("missing property value");
         }
         catch (CheckstyleException ex) {
-            assertTrue(
-                ex.getMessage().endsWith(
-                    "Attribute \"value\" is required and must be specified "
-                        + "for element type \"property\".:8:41"));
+            assertTrue(ex.getMessage().contains("\"value\""));
+            assertTrue(ex.getMessage().contains("\"property\""));
+            assertTrue(ex.getMessage().endsWith(":8:41"));
         }
     }
 
@@ -120,10 +137,9 @@ public class ConfigurationLoaderTest {
             fail("missing module name");
         }
         catch (CheckstyleException ex) {
-            assertTrue(
-                ex.getMessage().endsWith(
-                    "Attribute \"name\" is required and must be specified "
-                        + "for element type \"module\".:7:23"));
+            assertTrue(ex.getMessage().contains("\"name\""));
+            assertTrue(ex.getMessage().contains("\"module\""));
+            assertTrue(ex.getMessage().endsWith(":7:23"));
         }
     }
 
@@ -134,10 +150,9 @@ public class ConfigurationLoaderTest {
             fail("missing module parent");
         }
         catch (CheckstyleException ex) {
-            assertTrue(
-                ex.getMessage().endsWith(
-                    "Document root element \"property\", must match DOCTYPE "
-                        + "root \"module\".:8:38"));
+            assertTrue(ex.getMessage().contains("\"property\""));
+            assertTrue(ex.getMessage().contains("\"module\""));
+            assertTrue(ex.getMessage().endsWith(":8:38"));
         }
     }
 
@@ -231,47 +246,45 @@ public class ConfigurationLoaderTest {
     }
 
     @Test
-    public void testReplacePropertiesNoReplace()
-        throws CheckstyleException {
+    public void testReplacePropertiesNoReplace() throws Exception {
         final String[] testValues = {null, "", "a", "$a", "{a",
                                      "{a}", "a}", "$a}", "$", "a$b", };
         final Properties props = initProperties();
         for (String testValue : testValues) {
-            final String value = ConfigurationLoader.replaceProperties(
-                testValue, new PropertiesExpander(props), null);
+            final String value = (String) getReplacePropertiesMethod().invoke(
+                null, testValue, new PropertiesExpander(props), null);
             assertEquals("\"" + testValue + "\"", value, testValue);
         }
     }
 
     @Test
-    public void testReplacePropertiesSyntaxError() {
+    public void testReplacePropertiesSyntaxError() throws Exception {
         final Properties props = initProperties();
         try {
-            final String value = ConfigurationLoader.replaceProperties(
-                "${a", new PropertiesExpander(props), null);
+            final String value = (String) getReplacePropertiesMethod().invoke(
+                null, "${a", new PropertiesExpander(props), null);
             fail("expected to fail, instead got: " + value);
         }
-        catch (CheckstyleException ex) {
-            assertEquals("Syntax error in property: ${a", ex.getMessage());
+        catch (InvocationTargetException ex) {
+            assertEquals("Syntax error in property: ${a", ex.getCause().getMessage());
         }
     }
 
     @Test
-    public void testReplacePropertiesMissingProperty() {
+    public void testReplacePropertiesMissingProperty() throws Exception {
         final Properties props = initProperties();
         try {
-            final String value = ConfigurationLoader.replaceProperties(
-                "${c}", new PropertiesExpander(props), null);
+            final String value = (String) getReplacePropertiesMethod().invoke(
+                null, "${c}", new PropertiesExpander(props), null);
             fail("expected to fail, instead got: " + value);
         }
-        catch (CheckstyleException ex) {
-            assertEquals("Property ${c} has not been set", ex.getMessage());
+        catch (InvocationTargetException ex) {
+            assertEquals("Property ${c} has not been set", ex.getCause().getMessage());
         }
     }
 
     @Test
-    public void testReplacePropertiesReplace()
-        throws CheckstyleException {
+    public void testReplacePropertiesReplace() throws Exception {
         final String[][] testValues = {
             {"${a}", "A"},
             {"x${a}", "xA"},
@@ -288,8 +301,8 @@ public class ConfigurationLoaderTest {
         };
         final Properties props = initProperties();
         for (String[] testValue : testValues) {
-            final String value = ConfigurationLoader.replaceProperties(
-                testValue[0], new PropertiesExpander(props), null);
+            final String value = (String) getReplacePropertiesMethod().invoke(
+                null, testValue[0], new PropertiesExpander(props), null);
             assertEquals("\"" + testValue[0] + "\"",
                 testValue[1], value);
         }
@@ -367,15 +380,13 @@ public class ConfigurationLoaderTest {
                 constructor = constr;
             }
 
-            final Class<?>[] param = new Class<?>[4];
-            param[0] = String.class;
-            param[1] = String.class;
-            param[2] = String.class;
-            param[3] = Attributes.class;
-            final Method method = aClass.getDeclaredMethod("startElement", param);
             final Object objParent = ctorParent.newInstance(null, true);
             final Object obj = constructor.newInstance(objParent);
 
+            final Class<?>[] param = new Class<?>[] {String.class, String.class,
+                String.class, Attributes.class, };
+            final Method method = aClass.getDeclaredMethod("startElement", param);
+
             method.invoke(obj, "", "", "hello", null);
 
             fail("Exception is expected");
@@ -475,8 +486,8 @@ public class ConfigurationLoaderTest {
         final Properties props = new Properties();
         final String defaultValue = "defaultValue";
 
-        final String value = ConfigurationLoader.replaceProperties("${checkstyle.basedir}",
-                new PropertiesExpander(props), defaultValue);
+        final String value = (String) getReplacePropertiesMethod().invoke(
+            null, "${checkstyle.basedir}", new PropertiesExpander(props), defaultValue);
 
         assertEquals(defaultValue, value);
     }
@@ -497,4 +508,39 @@ public class ConfigurationLoaderTest {
             fail("unexpected exception");
         }
     }
+
+    /**
+     * This SuppressWarning("unchecked") required to suppress
+     * "Unchecked generics array creation for varargs parameter" during mock
+     * @throws Exception could happen from PowerMokito calls and getAttribute
+     */
+    @SuppressWarnings("unchecked")
+    @Test
+    public void testConfigWithIgnoreExceptionalAttributes() throws Exception {
+
+        // emulate exception from unrelated code, but that is same try-catch
+        final DefaultConfiguration tested = PowerMockito.mock(DefaultConfiguration.class);
+        when(tested.getAttributeNames()).thenReturn(new String[] {"severity"});
+        when(tested.getName()).thenReturn("MemberName");
+        when(tested.getAttribute("severity")).thenThrow(CheckstyleException.class);
+        // to void creation of 2 other mocks for now reason, only one moc is used for all cases
+        PowerMockito.whenNew(DefaultConfiguration.class)
+                .withArguments("MemberName").thenReturn(tested);
+        PowerMockito.whenNew(DefaultConfiguration.class)
+                .withArguments("Checker").thenReturn(tested);
+        PowerMockito.whenNew(DefaultConfiguration.class)
+                .withArguments("TreeWalker").thenReturn(tested);
+
+        try {
+            ConfigurationLoader.loadConfiguration(
+                    getConfigPath("config_with_ignore.xml"),
+                    new PropertiesExpander(new Properties()), true);
+            fail("Exception is expected");
+        }
+        catch (CheckstyleException expected) {
+            assertEquals("Problem during accessing 'severity' attribute for MemberName",
+                    expected.getCause().getMessage());
+        }
+    }
+
 }
