@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,7 +19,7 @@
 
 package com.puppycrawl.tools.checkstyle;
 
-import static org.apache.commons.lang3.ArrayUtils.EMPTY_BYTE_ARRAY;
+import static com.puppycrawl.tools.checkstyle.utils.CommonUtils.EMPTY_BYTE_ARRAY;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotEquals;
 import static org.junit.Assert.assertTrue;
@@ -36,6 +36,7 @@ import java.net.URLConnection;
 import java.net.URLStreamHandler;
 import java.util.Arrays;
 import java.util.Enumeration;
+import java.util.HashSet;
 import java.util.Set;
 
 import org.junit.Test;
@@ -43,7 +44,6 @@ import org.mockito.Mockito;
 import org.xml.sax.Attributes;
 import org.xml.sax.SAXException;
 
-import com.google.common.collect.Sets;
 import com.puppycrawl.tools.checkstyle.api.CheckstyleException;
 
 /**
@@ -54,7 +54,7 @@ import com.puppycrawl.tools.checkstyle.api.CheckstyleException;
 public class PackageNamesLoaderTest {
     @Test
     public void testDefault()
-        throws CheckstyleException {
+            throws CheckstyleException {
         final Set<String> packageNames = PackageNamesLoader
                 .getPackageNames(Thread.currentThread()
                         .getContextClassLoader());
@@ -79,14 +79,13 @@ public class PackageNamesLoaderTest {
             "com.puppycrawl.tools.checkstyle.checks.regexp.",
             "com.puppycrawl.tools.checkstyle.checks.sizes.",
             "com.puppycrawl.tools.checkstyle.checks.whitespace.",
+            "com.puppycrawl.tools.checkstyle.filefilters.",
             "com.puppycrawl.tools.checkstyle.filters.",
-
         };
 
         assertEquals("pkgNames.length.", checkstylePackages.length,
             pkgNames.size());
-        final Set<String> checkstylePackagesSet =
-            Sets.newHashSet(Arrays.asList(checkstylePackages));
+        final Set<String> checkstylePackagesSet = new HashSet<>(Arrays.asList(checkstylePackages));
         assertEquals("names set.", checkstylePackagesSet, pkgNames);
     }
 
