@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,38 +19,33 @@
 
 package com.puppycrawl.tools.checkstyle;
 
-import static org.hamcrest.CoreMatchers.anyOf;
-import static org.hamcrest.CoreMatchers.instanceOf;
-import static org.junit.Assert.assertThat;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
 import java.io.BufferedWriter;
 import java.io.File;
 import java.io.FileOutputStream;
-import java.io.IOException;
 import java.io.OutputStreamWriter;
 import java.io.Writer;
 import java.nio.charset.StandardCharsets;
-import java.nio.file.InvalidPathException;
 import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.List;
-import java.util.Locale;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 
-import org.apache.commons.lang3.ArrayUtils;
-import org.junit.Assume;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
 
-import com.puppycrawl.tools.checkstyle.api.Check;
+import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.CheckstyleException;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 import com.puppycrawl.tools.checkstyle.checks.coding.HiddenFieldCheck;
 import com.puppycrawl.tools.checkstyle.checks.javadoc.JavadocPackageCheck;
 import com.puppycrawl.tools.checkstyle.checks.naming.ConstantNameCheck;
 import com.puppycrawl.tools.checkstyle.checks.naming.TypeNameCheck;
+import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
 public class TreeWalkerTest extends BaseCheckTestSupport {
     @Rule
@@ -61,7 +56,7 @@ public class TreeWalkerTest extends BaseCheckTestSupport {
         final DefaultConfiguration checkConfig =
                 createCheckConfig(ConstantNameCheck.class);
         final File file = temporaryFolder.newFile("file.java");
-        try (final Writer writer = new BufferedWriter(
+        try (Writer writer = new BufferedWriter(
                 new OutputStreamWriter(new FileOutputStream(file), StandardCharsets.UTF_8))) {
             final String content = "public class Main { public static final int k = 5 + 4; }";
             writer.write(content);
@@ -77,33 +72,37 @@ public class TreeWalkerTest extends BaseCheckTestSupport {
         final DefaultConfiguration checkConfig =
                 createCheckConfig(ConstantNameCheck.class);
         final File file = temporaryFolder.newFile("file.pdf");
-        try (final BufferedWriter writer = new BufferedWriter(
+        try (BufferedWriter writer = new BufferedWriter(
                 new OutputStreamWriter(new FileOutputStream(file), StandardCharsets.UTF_8))) {
             final String content = "public class Main { public static final int k = 5 + 4; }";
             writer.write(content);
         }
-        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
+        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         verify(checkConfig, file.getPath(), expected);
     }
 
     @Test
     public void testAcceptableTokens()
-        throws Exception {
+            throws Exception {
         final DefaultConfiguration checkConfig =
             createCheckConfig(HiddenFieldCheck.class);
         checkConfig.addAttribute("tokens", "VARIABLE_DEF, ENUM_DEF, CLASS_DEF, METHOD_DEF,"
                 + "IMPORT");
-        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
         try {
+            final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
             verify(checkConfig, getPath("InputMain.java"), expected);
             fail("CheckstyleException is expected");
         }
         catch (CheckstyleException ex) {
             final String errorMsg = ex.getMessage();
-            assertTrue(errorMsg.contains("cannot initialize module"
-                    + " com.puppycrawl.tools.checkstyle.TreeWalker - Token \"IMPORT\""
-                    + " was not found in Acceptable tokens list in check"
+            final Pattern expected = Pattern.compile(Pattern.quote("cannot initialize module"
+                    + " com.puppycrawl.tools.checkstyle.TreeWalker - Token ")
+                    + "\"(ENUM_DEF|CLASS_DEF|METHOD_DEF|IMPORT)\""
+                    + Pattern.quote(" was not found in Acceptable tokens list in check"
                     + " com.puppycrawl.tools.checkstyle.checks.coding.HiddenFieldCheck"));
+
+            final Matcher errorMsgMatcher = expected.matcher(errorMsg);
+            assertTrue("Failure for: " + errorMsg, errorMsgMatcher.matches());
         }
     }
 
@@ -111,7 +110,7 @@ public class TreeWalkerTest extends BaseCheckTestSupport {
     public void testOnEmptyFile() throws Exception {
         final DefaultConfiguration checkConfig = createCheckConfig(HiddenFieldCheck.class);
         final String pathToEmptyFile = temporaryFolder.newFile("file.java").getPath();
-        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
+        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
 
         verify(checkConfig, pathToEmptyFile, expected);
     }
@@ -119,9 +118,9 @@ public class TreeWalkerTest extends BaseCheckTestSupport {
     @Test
     public void testWithCheckNotHavingTreeWalkerAsParent() throws Exception {
         final DefaultConfiguration checkConfig = createCheckConfig(JavadocPackageCheck.class);
-        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
 
         try {
+            final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
             verify(checkConfig, temporaryFolder.newFile().getPath(), expected);
             fail("CheckstyleException is expected");
         }
@@ -138,129 +137,13 @@ public class TreeWalkerTest extends BaseCheckTestSupport {
         treeWalker.setCacheFile(temporaryFolder.newFile().getPath());
     }
 
-    @Test
-    public void testDestroyNonExistingCache() throws Exception {
-
-        // We use assumption to satisfy coverage rate on OS Windows, since persist() method of
-        // class PropertyCacheFile does not throw IOException on OS Linux when path to a cache
-        // directory is invalid on OS Windows.
-        Assume.assumeTrue(System.getProperty("os.name")
-            .toLowerCase(Locale.ENGLISH).startsWith("windows"));
-
-        final TreeWalker treeWalker = new TreeWalker();
-        treeWalker.configure(new DefaultConfiguration("default config"));
-        final String tempFilePath = temporaryFolder.newFile().getPath() + ".\\\'";
-        treeWalker.setCacheFile(tempFilePath);
-        try {
-            treeWalker.destroy();
-            fail("Exception did not happen");
-        }
-        catch (IllegalStateException ex) {
-            assertTrue(ex.getCause() instanceof IOException);
-        }
-    }
-
-    @Test
-    public void testDestroyCacheFileWithInvalidPath() throws Exception {
-        final TreeWalker treeWalker = new TreeWalker();
-        treeWalker.configure(new DefaultConfiguration("default config"));
-        if (System.getProperty("os.name")
-                        .toLowerCase(Locale.ENGLISH).startsWith("windows")) {
-            // https://support.microsoft.com/en-us/kb/177506 but this only for NTFS
-            // WindowsServer 2012 use Resilient File System (ReFS), so any name is ok
-            final File file = new File("C\\:invalid");
-            treeWalker.setCacheFile(file.getAbsolutePath());
-        }
-        else {
-            treeWalker.setCacheFile(File.separator + ":invalid");
-        }
-        try {
-            treeWalker.destroy();
-            fail("Exception did not happen");
-        }
-        catch (IllegalStateException ex) {
-            assertThat(ex.getCause(), anyOf(instanceOf(IOException.class),
-                instanceOf(InvalidPathException.class)));
-        }
-    }
-
-    @Test
-    public void testCacheFile() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(HiddenFieldCheck.class);
-
-        final DefaultConfiguration treeWalkerConfig = createCheckConfig(TreeWalker.class);
-        treeWalkerConfig.addAttribute("cacheFile", temporaryFolder.newFile().getPath());
-        treeWalkerConfig.addChild(checkConfig);
-
-        final DefaultConfiguration checkerConfig = new DefaultConfiguration("configuration");
-        checkerConfig.addAttribute("charset", "UTF-8");
-        checkerConfig.addChild(treeWalkerConfig);
-
-        final Checker checker = new Checker();
-        final Locale locale = Locale.ROOT;
-        checker.setLocaleCountry(locale.getCountry());
-        checker.setLocaleLanguage(locale.getLanguage());
-        checker.setModuleClassLoader(Thread.currentThread().getContextClassLoader());
-        checker.configure(checkerConfig);
-        checker.addListener(new BriefUtLogger(stream));
-
-        final String pathToEmptyFile = temporaryFolder.newFile("file.java").getPath();
-        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
-
-        verify(checker, pathToEmptyFile, pathToEmptyFile, expected);
-        // one more time to reuse cache
-        verify(checker, pathToEmptyFile, pathToEmptyFile, expected);
-    }
-
-    @Test
-    public void testCacheFileChangeInConfig() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(HiddenFieldCheck.class);
-
-        final DefaultConfiguration treeWalkerConfig = createCheckConfig(TreeWalker.class);
-        treeWalkerConfig.addAttribute("cacheFile", temporaryFolder.newFile().getPath());
-        treeWalkerConfig.addChild(checkConfig);
-
-        final DefaultConfiguration checkerConfig = new DefaultConfiguration("configuration");
-        checkerConfig.addAttribute("charset", "UTF-8");
-        checkerConfig.addChild(treeWalkerConfig);
-
-        final Checker checker = new Checker();
-        final Locale locale = Locale.ROOT;
-        checker.setLocaleCountry(locale.getCountry());
-        checker.setLocaleLanguage(locale.getLanguage());
-        checker.setModuleClassLoader(Thread.currentThread().getContextClassLoader());
-        checker.configure(checkerConfig);
-        checker.addListener(new BriefUtLogger(stream));
-
-        final String pathToEmptyFile = temporaryFolder.newFile("file.java").getPath();
-        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
-
-        verify(checker, pathToEmptyFile, pathToEmptyFile, expected);
-
-        // update Checker config
-        //checker.destroy();
-        //checker.configure(checkerConfig);
-
-        final Checker otherChecker = new Checker();
-        otherChecker.setLocaleCountry(locale.getCountry());
-        otherChecker.setLocaleLanguage(locale.getLanguage());
-        otherChecker.setModuleClassLoader(Thread.currentThread().getContextClassLoader());
-        otherChecker.configure(checkerConfig);
-        otherChecker.addListener(new BriefUtLogger(stream));
-        // here is diff with previous checker
-        checkerConfig.addAttribute("fileExtensions", "java,javax");
-
-        // one more time on updated config
-        verify(otherChecker, pathToEmptyFile, pathToEmptyFile, expected);
-    }
-
     @Test
     public void testForInvalidCheckImplementation() throws Exception {
         final DefaultConfiguration checkConfig = createCheckConfig(BadJavaDocCheck.class);
         final String pathToEmptyFile = temporaryFolder.newFile("file.java").getPath();
-        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
 
         try {
+            final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
             verify(checkConfig, pathToEmptyFile, expected);
         }
         catch (CheckstyleException ex) {
@@ -273,9 +156,8 @@ public class TreeWalkerTest extends BaseCheckTestSupport {
         final TreeWalker treeWalker = new TreeWalker();
         treeWalker.setTabWidth(1);
         treeWalker.configure(new DefaultConfiguration("default config"));
-        treeWalker.setCacheFile(temporaryFolder.newFile().getPath());
         final File file = new File("src/main/resources/checkstyle_packages.xml");
-        treeWalker.processFiltered(file, new ArrayList<String>());
+        treeWalker.processFiltered(file, new ArrayList<>());
     }
 
     @Test
@@ -283,9 +165,8 @@ public class TreeWalkerTest extends BaseCheckTestSupport {
         final TreeWalker treeWalker = new TreeWalker();
         treeWalker.configure(createCheckConfig(TypeNameCheck.class));
         final PackageObjectFactory factory = new PackageObjectFactory(
-                new HashSet<String>(), Thread.currentThread().getContextClassLoader());
+            new HashSet<>(), Thread.currentThread().getContextClassLoader());
         treeWalker.setModuleFactory(factory);
-        treeWalker.setCacheFile(temporaryFolder.newFile().getPath());
         treeWalker.setupChild(createCheckConfig(TypeNameCheck.class));
         final File file = temporaryFolder.newFile("file.java");
         final List<String> lines = new ArrayList<>();
@@ -298,9 +179,8 @@ public class TreeWalkerTest extends BaseCheckTestSupport {
         final TreeWalker treeWalker = new TreeWalker();
         treeWalker.configure(createCheckConfig(TypeNameCheck.class));
         final PackageObjectFactory factory = new PackageObjectFactory(
-                new HashSet<String>(), Thread.currentThread().getContextClassLoader());
+            new HashSet<>(), Thread.currentThread().getContextClassLoader());
         treeWalker.setModuleFactory(factory);
-        treeWalker.setCacheFile(temporaryFolder.newFile().getPath());
         treeWalker.setupChild(createCheckConfig(TypeNameCheck.class));
         final File file = temporaryFolder.newFile("file.java");
         final List<String> lines = new ArrayList<>();
@@ -320,9 +200,8 @@ public class TreeWalkerTest extends BaseCheckTestSupport {
         final TreeWalker treeWalker = new TreeWalker();
         treeWalker.configure(createCheckConfig(TypeNameCheck.class));
         final PackageObjectFactory factory = new PackageObjectFactory(
-                new HashSet<String>(), Thread.currentThread().getContextClassLoader());
+            new HashSet<>(), Thread.currentThread().getContextClassLoader());
         treeWalker.setModuleFactory(factory);
-        treeWalker.setCacheFile(temporaryFolder.newFile().getPath());
         treeWalker.setupChild(createCheckConfig(TypeNameCheck.class));
         final File file = temporaryFolder.newFile("file.java");
         final List<String> lines = new ArrayList<>();
@@ -342,9 +221,9 @@ public class TreeWalkerTest extends BaseCheckTestSupport {
         final DefaultConfiguration checkConfig =
             createCheckConfig(RequiredTokenIsNotInDefaultsCheck.class);
         final String pathToEmptyFile = temporaryFolder.newFile("file.java").getPath();
-        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
 
         try {
+            final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
             verify(checkConfig, pathToEmptyFile, expected);
             fail("CheckstyleException is expected");
         }
@@ -361,9 +240,9 @@ public class TreeWalkerTest extends BaseCheckTestSupport {
         final DefaultConfiguration checkConfig =
             createCheckConfig(RequiredTokenIsEmptyIntArray.class);
         final String pathToEmptyFile = temporaryFolder.newFile("file.java").getPath();
-        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
 
         try {
+            final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
             verify(checkConfig, pathToEmptyFile, expected);
         }
         catch (CheckstyleException ignored) {
@@ -372,7 +251,7 @@ public class TreeWalkerTest extends BaseCheckTestSupport {
         }
     }
 
-    private static class BadJavaDocCheck extends Check {
+    private static class BadJavaDocCheck extends AbstractCheck {
         @Override
         public int[] getDefaultTokens() {
             return getAcceptableTokens();
@@ -380,7 +259,7 @@ public class TreeWalkerTest extends BaseCheckTestSupport {
 
         @Override
         public int[] getAcceptableTokens() {
-            return new int[]{TokenTypes.SINGLE_LINE_COMMENT};
+            return new int[] {TokenTypes.SINGLE_LINE_COMMENT};
         }
 
         @Override
@@ -389,7 +268,7 @@ public class TreeWalkerTest extends BaseCheckTestSupport {
         }
     }
 
-    private static class RequiredTokenIsNotInDefaultsCheck extends Check {
+    private static class RequiredTokenIsNotInDefaultsCheck extends AbstractCheck {
         @Override
         public int[] getRequiredTokens() {
             return new int[] {TokenTypes.ASSIGN};
@@ -402,14 +281,14 @@ public class TreeWalkerTest extends BaseCheckTestSupport {
 
         @Override
         public int[] getAcceptableTokens() {
-            return ArrayUtils.EMPTY_INT_ARRAY;
+            return CommonUtils.EMPTY_INT_ARRAY;
         }
     }
 
-    private static class RequiredTokenIsEmptyIntArray extends Check {
+    private static class RequiredTokenIsEmptyIntArray extends AbstractCheck {
         @Override
         public int[] getRequiredTokens() {
-            return ArrayUtils.EMPTY_INT_ARRAY;
+            return CommonUtils.EMPTY_INT_ARRAY;
         }
 
         @Override
@@ -419,8 +298,7 @@ public class TreeWalkerTest extends BaseCheckTestSupport {
 
         @Override
         public int[] getAcceptableTokens() {
-            return ArrayUtils.EMPTY_INT_ARRAY;
+            return CommonUtils.EMPTY_INT_ARRAY;
         }
     }
-
 }
