@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,10 +19,12 @@
 
 package com.puppycrawl.tools.checkstyle.api;
 
+import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
+import java.lang.reflect.Field;
 import java.lang.reflect.InvocationTargetException;
 
 import org.apache.commons.beanutils.ConversionException;
@@ -67,6 +69,25 @@ public class AutomaticBeanTest {
         testBean.setupChild(null);
     }
 
+    @Test
+    public void testSetupInvalidChildFromBaseClass() throws Exception {
+        final TestBean testBean = new TestBean();
+        final DefaultConfiguration parentConf = new DefaultConfiguration("parentConf");
+        final DefaultConfiguration childConf = new DefaultConfiguration("childConf");
+        final Field field = AutomaticBean.class.getDeclaredField("configuration");
+        field.setAccessible(true);
+        field.set(testBean, parentConf);
+
+        try {
+            testBean.setupChild(childConf);
+            fail("expecting checkstyle exception");
+        }
+        catch (CheckstyleException ex) {
+            assertEquals("expected exception", "childConf is not allowed as a child in parentConf",
+                    ex.getMessage());
+        }
+    }
+
     @Test
     public void testContextualizeInvocationTargetException() {
         final TestBean testBean = new TestBean();
@@ -97,12 +118,18 @@ public class AutomaticBeanTest {
         }
     }
 
-    @Test(expected = IllegalStateException.class)
+    @Test
     public void testTestBean() {
         final TestBean testBean = new TestBean();
         testBean.setVal(0);
         testBean.setWrong("wrongVal");
-        testBean.setExceptionalMethod("someValue");
+        try {
+            testBean.setExceptionalMethod("someValue");
+            fail("exception expected");
+        }
+        catch (IllegalStateException ex) {
+            assertEquals("null,wrongVal,0,someValue", ex.getMessage());
+        }
     }
 
     private static class TestBean extends AutomaticBean {
@@ -125,5 +152,9 @@ public class AutomaticBeanTest {
             throw new IllegalStateException(privateField + "," + wrong + "," + val + "," + value);
         }
 
+        public void doSmth() {
+            privateField = "some value, just for fun";
+        }
+
     }
 }
