@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -20,11 +20,13 @@
 package com.puppycrawl.tools.checkstyle.checks;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 import static org.mockito.Matchers.anyObject;
 
+import java.util.HashSet;
 import java.util.Set;
 
 import org.junit.Test;
@@ -33,14 +35,12 @@ import org.powermock.api.mockito.PowerMockito;
 import org.powermock.core.classloader.annotations.PrepareForTest;
 import org.powermock.modules.junit4.PowerMockRunner;
 
-import com.google.common.collect.Sets;
-
 @RunWith(PowerMockRunner.class)
 @PrepareForTest({ ClassResolver.class, ClassResolverTest.class })
 public class ClassResolverTest {
     @Test
     public void testMisc() throws ClassNotFoundException {
-        final Set<String> imports = Sets.newHashSet();
+        final Set<String> imports = new HashSet<>();
         imports.add("java.io.File");
         imports.add("nothing.will.match.*");
         imports.add("java.applet.*");
@@ -85,8 +85,8 @@ public class ClassResolverTest {
     }
 
     @Test
-    public void testExistedImportCantBeResolved() throws Exception {
-        final Set<String> imports = Sets.newHashSet();
+    public void testExistedImportCantBeResolved() {
+        final Set<String> imports = new HashSet<>();
         imports.add("java.applet.someClass");
         final ClassResolver classResolver = new ClassResolver(
                 Thread.currentThread().getContextClassLoader(),
@@ -104,7 +104,7 @@ public class ClassResolverTest {
 
     @Test
     public void testResolveInnerClass() throws Exception {
-        final Set<String> imports = Sets.newHashSet();
+        final Set<String> imports = new HashSet<>();
         final ClassResolver classResolver = new ClassResolver(
                 Thread.currentThread().getContextClassLoader(),
                 "java.util", imports);
@@ -114,8 +114,8 @@ public class ClassResolverTest {
     }
 
     @Test
-    public void testResolveInnerClassWithEmptyPackage() throws Exception {
-        final Set<String> imports = Sets.newHashSet();
+    public void testResolveInnerClassWithEmptyPackage() {
+        final Set<String> imports = new HashSet<>();
         final ClassResolver classResolver = new ClassResolver(
                 Thread.currentThread().getContextClassLoader(),
                 "", imports);
@@ -130,7 +130,7 @@ public class ClassResolverTest {
 
     @Test
     public void testResolveQualifiedNameFails() throws Exception {
-        final Set<String> imports = Sets.newHashSet();
+        final Set<String> imports = new HashSet<>();
         imports.add("java.applet.someClass");
 
         final ClassResolver classResolver = PowerMockito.spy(new ClassResolver(Thread
@@ -150,4 +150,32 @@ public class ClassResolverTest {
             assertTrue(ex.getMessage().endsWith("expected exception"));
         }
     }
+
+    /**
+     * This test exists to prevent any possible regression and let of
+     * https://github.com/checkstyle/checkstyle/issues/1192 to be persistent
+     * event is not very obvious
+     *
+     * @throws Exception when smth is not expected
+     */
+    @Test
+    public void testIsLoadableWithNoClassDefFoundError() throws Exception {
+        final Set<String> imports = new HashSet<>();
+        imports.add("java.applet.someClass");
+
+        final ClassResolver classResolver = PowerMockito.spy(new ClassResolver(Thread
+                .currentThread().getContextClassLoader(), "", imports));
+
+        PowerMockito.doThrow(new NoClassDefFoundError("expected exception"))
+                .when(classResolver, "safeLoad", anyObject());
+
+        try {
+            final boolean result = classResolver.isLoadable("someClass");
+            assertFalse("result should be false", result);
+        }
+        catch (NoClassDefFoundError ex) {
+            fail("NoClassDefFoundError is not expected");
+            assertTrue(ex.getMessage().endsWith("expected exception"));
+        }
+    }
 }
