@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -24,11 +24,11 @@ import static com.puppycrawl.tools.checkstyle.checks.annotation.SuppressWarnings
 import java.io.File;
 import java.io.IOException;
 
-import org.apache.commons.lang3.ArrayUtils;
 import org.junit.Test;
 
 import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
+import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
 public class SuppressWarningsCheckTest extends BaseCheckTestSupport {
     @Override
@@ -796,7 +796,7 @@ public class SuppressWarningsCheckTest extends BaseCheckTestSupport {
     public void testUncheckedInConstant() throws Exception {
         final DefaultConfiguration checkConfig = createCheckConfig(SuppressWarningsCheck.class);
 
-        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
+        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
 
         verify(checkConfig, getPath("InputSuppressWarningsConstants.java"), expected);
     }
@@ -805,7 +805,7 @@ public class SuppressWarningsCheckTest extends BaseCheckTestSupport {
     public void testValuePairAnnotation() throws Exception {
         final DefaultConfiguration checkConfig = createCheckConfig(SuppressWarningsCheck.class);
 
-        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
+        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
 
         verify(checkConfig, getPath("InputSuppressWarningsValuePair.java"), expected);
     }
