@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -24,11 +24,11 @@ import static com.puppycrawl.tools.checkstyle.checks.blocks.NeedBracesCheck.MSG_
 import java.io.File;
 import java.io.IOException;
 
-import org.apache.commons.lang3.ArrayUtils;
 import org.junit.Test;
 
 import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
+import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
 public class NeedBracesCheckTest extends BaseCheckTestSupport {
     @Override
@@ -99,7 +99,7 @@ public class NeedBracesCheckTest extends BaseCheckTestSupport {
         final String[] expected = {
             "7: " + getCheckMessage(MSG_KEY_NEED_BRACES, "->"),
         };
-        verify(checkConfig, getNonCompilablePath("InputSingleLineLambda.java"), expected);
+        verify(checkConfig, getPath("InputSingleLineLambda.java"), expected);
     }
 
     @Test
@@ -115,12 +115,22 @@ public class NeedBracesCheckTest extends BaseCheckTestSupport {
         verify(checkConfig, getPath("InputBracesSingleLineStatements.java"), expected);
     }
 
+    @Test
+    public void testSingleLineCaseDefault2() throws Exception {
+        final DefaultConfiguration checkConfig =
+                createCheckConfig(NeedBracesCheck.class);
+        checkConfig.addAttribute("tokens", "LITERAL_CASE, LITERAL_DEFAULT");
+        checkConfig.addAttribute("allowSingleLineStatement", "true");
+        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
+        verify(checkConfig, getPath("InputNeedBracesEmptyDefault.java"), expected);
+    }
+
     @Test
     public void testCycles() throws Exception {
         final DefaultConfiguration checkConfig = createCheckConfig(NeedBracesCheck.class);
         checkConfig.addAttribute("tokens", "LITERAL_WHILE, LITERAL_DO, LITERAL_FOR");
         checkConfig.addAttribute("allowSingleLineStatement", "true");
-        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
+        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputNeedBraces.java"), expected);
     }
 
@@ -178,4 +188,13 @@ public class NeedBracesCheckTest extends BaseCheckTestSupport {
         };
         verify(checkConfig, getPath("InputNeedBracesNoBodyLoops.java"), expected);
     }
+
+    @Test
+    public void testEmptySingleLineDefaultStmt() throws Exception {
+        final DefaultConfiguration checkConfig = createCheckConfig(NeedBracesCheck.class);
+        checkConfig.addAttribute("tokens", "LITERAL_DEFAULT");
+        checkConfig.addAttribute("allowSingleLineStatement", "true");
+        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
+        verify(checkConfig, getPath("InputNeedBracesEmptyDefault.java"), expected);
+    }
 }
