@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -40,7 +40,7 @@ public class IllegalTokenTextCheckTest
 
     @Test
     public void testCaseSensitive()
-        throws Exception {
+            throws Exception {
         final DefaultConfiguration checkConfig =
             createCheckConfig(IllegalTokenTextCheck.class);
         checkConfig.addAttribute("tokens", "STRING_LITERAL");
@@ -54,7 +54,7 @@ public class IllegalTokenTextCheckTest
 
     @Test
     public void testCaseInSensitive()
-        throws Exception {
+            throws Exception {
         final DefaultConfiguration checkConfig =
             createCheckConfig(IllegalTokenTextCheck.class);
         checkConfig.addAttribute("tokens", "STRING_LITERAL");
@@ -69,7 +69,7 @@ public class IllegalTokenTextCheckTest
 
     @Test
     public void testCustomMessage()
-        throws Exception {
+            throws Exception {
         final DefaultConfiguration checkConfig =
             createCheckConfig(IllegalTokenTextCheck.class);
         checkConfig.addAttribute("tokens", "STRING_LITERAL");
@@ -85,7 +85,7 @@ public class IllegalTokenTextCheckTest
 
     @Test
     public void testNullCustomMessage()
-        throws Exception {
+            throws Exception {
         final DefaultConfiguration checkConfig =
             createCheckConfig(IllegalTokenTextCheck.class);
         checkConfig.addAttribute("tokens", "STRING_LITERAL");
@@ -104,5 +104,22 @@ public class IllegalTokenTextCheckTest
         Assert.assertNotNull(check.getAcceptableTokens());
         Assert.assertNotNull(check.getDefaultTokens());
         Assert.assertNotNull(check.getRequiredTokens());
+        Assert.assertTrue("Comments are also TokenType token", check.isCommentNodesRequired());
     }
+
+    @Test
+    public void testCommentToken()
+            throws Exception {
+        final DefaultConfiguration checkConfig =
+                createCheckConfig(IllegalTokenTextCheck.class);
+        checkConfig.addAttribute("tokens", "COMMENT_CONTENT");
+        checkConfig.addAttribute("format", "a href");
+
+        checkConfig.addAttribute("message", null);
+        final String[] expected = {
+            "35:28: " + getCheckMessage(MSG_KEY, "a href"),
+        };
+        verify(checkConfig, getPath("InputIllegalTokens.java"), expected);
+    }
+
 }
