@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -32,27 +32,35 @@ import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 
 import org.apache.commons.beanutils.ConversionException;
-import org.apache.commons.lang3.ArrayUtils;
+import org.junit.Rule;
 import org.junit.Test;
+import org.junit.rules.TemporaryFolder;
 import org.junit.runner.RunWith;
 import org.powermock.api.mockito.PowerMockito;
 import org.powermock.core.classloader.annotations.PrepareForTest;
 import org.powermock.modules.junit4.PowerMockRunner;
 
 import com.puppycrawl.tools.checkstyle.BaseFileSetCheckTestSupport;
+import com.puppycrawl.tools.checkstyle.BriefUtLogger;
+import com.puppycrawl.tools.checkstyle.Checker;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 import com.puppycrawl.tools.checkstyle.api.CheckstyleException;
+import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
 @RunWith(PowerMockRunner.class)
 @PrepareForTest({ HeaderCheck.class, HeaderCheckTest.class, AbstractHeaderCheck.class })
 public class HeaderCheckTest extends BaseFileSetCheckTestSupport {
+
+    @Rule
+    public final TemporaryFolder temporaryFolder = new TemporaryFolder();
+
     @Override
     protected String getPath(String filename) throws IOException {
         return super.getPath("checks" + File.separator
                 + "header" + File.separator + filename);
     }
 
-    protected String getConfigPath(String filename) throws IOException {
+    private String getConfigPath(String filename) throws IOException {
         return super.getPath("configs" + File.separator + filename);
     }
 
@@ -72,7 +80,22 @@ public class HeaderCheckTest extends BaseFileSetCheckTestSupport {
         final DefaultConfiguration checkConfig = createCheckConfig(HeaderCheck.class);
         try {
             createChecker(checkConfig);
-            final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
+            final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
+            verify(checkConfig, getPath("InputRegexpHeader1.java"), expected);
+        }
+        catch (CheckstyleException ex) {
+            // Exception is not expected
+            fail("Exception is not expected");
+        }
+    }
+
+    @Test
+    public void testWhitespaceHeader() throws Exception {
+        final DefaultConfiguration checkConfig = createCheckConfig(HeaderCheck.class);
+        checkConfig.addAttribute("header", "\n    \n");
+        try {
+            createChecker(checkConfig);
+            final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
             verify(checkConfig, getPath("InputRegexpHeader1.java"), expected);
         }
         catch (CheckstyleException ex) {
@@ -93,8 +116,9 @@ public class HeaderCheckTest extends BaseFileSetCheckTestSupport {
             assertTrue(ex.getMessage()
                     .startsWith("cannot initialize module"
                             + " com.puppycrawl.tools.checkstyle.checks.header.HeaderCheck"
-                            + " - Unable to find: "));
-            assertTrue(ex.getMessage().endsWith("nonExisting.file"));
+                            + " - illegal value "));
+            assertTrue(ex.getCause().getCause().getCause().getMessage()
+                    .startsWith("Unable to find: "));
         }
     }
 
@@ -133,6 +157,23 @@ public class HeaderCheckTest extends BaseFileSetCheckTestSupport {
         }
     }
 
+    @Test
+    public void testNullFilename() throws Exception {
+        final DefaultConfiguration checkConfig = createCheckConfig(HeaderCheck.class);
+        checkConfig.addAttribute("headerFile", null);
+        try {
+            createChecker(checkConfig);
+            fail("Checker creation should not succeed with null headerFile");
+        }
+        catch (CheckstyleException ex) {
+            assertEquals("cannot initialize module"
+                    + " com.puppycrawl.tools.checkstyle.checks.header.HeaderCheck"
+                    + " - Cannot set property 'headerFile' to 'null' in module"
+                    + " com.puppycrawl.tools.checkstyle.checks.header.HeaderCheck",
+                    ex.getMessage());
+        }
+    }
+
     @Test
     public void testNotMatch() throws Exception {
         final DefaultConfiguration checkConfig = createCheckConfig(HeaderCheck.class);
@@ -150,7 +191,7 @@ public class HeaderCheckTest extends BaseFileSetCheckTestSupport {
         final DefaultConfiguration checkConfig = createCheckConfig(HeaderCheck.class);
         checkConfig.addAttribute("headerFile", getConfigPath("java.header"));
         checkConfig.addAttribute("ignoreLines", "2");
-        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
+        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         verify(checkConfig, getConfigPath("java2.header"), expected);
     }
 
@@ -190,7 +231,7 @@ public class HeaderCheckTest extends BaseFileSetCheckTestSupport {
         PowerMockito.doThrow(new IOException("expected exception")).when(check, "loadHeader",
                 anyObject());
 
-        check.setHeaderFile(getPath("InputRegexpHeader1.java"));
+        check.setHeaderFile(CommonUtils.getUriByFilename(getPath("InputRegexpHeader1.java")));
 
         final Method loadHeaderFile = AbstractHeaderCheck.class.getDeclaredMethod("loadHeaderFile");
         loadHeaderFile.setAccessible(true);
@@ -200,8 +241,52 @@ public class HeaderCheckTest extends BaseFileSetCheckTestSupport {
         }
         catch (InvocationTargetException ex) {
             assertTrue(ex.getCause() instanceof CheckstyleException);
-            assertEquals("unable to load header file "
-                    + getPath("InputRegexpHeader1.java"), ex.getCause().getMessage());
+            assertTrue(ex.getCause().getMessage().startsWith("unable to load header file "));
         }
     }
+
+    @Test
+    public void testCacheHeaderFile() throws Exception {
+        final DefaultConfiguration checkConfig = createCheckConfig(HeaderCheck.class);
+        checkConfig.addAttribute("headerFile", getConfigPath("java.header"));
+
+        final DefaultConfiguration checkerConfig = new DefaultConfiguration("checkstyle_checks");
+        checkerConfig.addChild(checkConfig);
+        checkerConfig.addAttribute("cacheFile", temporaryFolder.newFile().getPath());
+
+        final Checker checker = new Checker();
+        checker.setModuleClassLoader(Thread.currentThread().getContextClassLoader());
+        checker.configure(checkerConfig);
+        checker.addListener(new BriefUtLogger(stream));
+
+        final String[] expected = {
+            "1: " + getCheckMessage(MSG_MISSING),
+        };
+
+        verify(checker, getPath("InputHeader.java"), expected);
+        // One more time to use cache.
+        verify(checker, getPath("InputHeader.java"), expected);
+
+    }
+
+    @Test
+    public void testCacheHeaderWithoutFile() throws Exception {
+        final DefaultConfiguration checkConfig = createCheckConfig(HeaderCheck.class);
+        checkConfig.addAttribute("header", "Test");
+
+        final DefaultConfiguration checkerConfig = new DefaultConfiguration("checkstyle_checks");
+        checkerConfig.addChild(checkConfig);
+        checkerConfig.addAttribute("cacheFile", temporaryFolder.newFile().getPath());
+
+        final Checker checker = new Checker();
+        checker.setModuleClassLoader(Thread.currentThread().getContextClassLoader());
+        checker.configure(checkerConfig);
+        checker.addListener(new BriefUtLogger(stream));
+
+        final String[] expected = {
+            "1: " + getCheckMessage(MSG_MISMATCH, "Test"),
+        };
+
+        verify(checker, getPath("InputHeader.java"), expected);
+    }
 }
