@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -25,13 +25,13 @@ import static org.junit.Assert.assertArrayEquals;
 import java.io.File;
 import java.io.IOException;
 
-import org.apache.commons.lang3.ArrayUtils;
 import org.junit.Test;
 
 import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 import com.puppycrawl.tools.checkstyle.api.Scope;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
+import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
 public class JavadocVariableCheckTest
     extends BaseCheckTestSupport {
@@ -66,7 +66,7 @@ public class JavadocVariableCheckTest
 
     @Test
     public void testDefault()
-        throws Exception {
+            throws Exception {
         final DefaultConfiguration checkConfig =
             createCheckConfig(JavadocVariableCheck.class);
         final String[] expected = {
@@ -80,7 +80,7 @@ public class JavadocVariableCheckTest
 
     @Test
     public void testAnother()
-        throws Exception {
+            throws Exception {
         final DefaultConfiguration checkConfig =
             createCheckConfig(JavadocVariableCheck.class);
         final String[] expected = {
@@ -93,17 +93,17 @@ public class JavadocVariableCheckTest
 
     @Test
     public void testAnother2()
-        throws Exception {
+            throws Exception {
         final DefaultConfiguration checkConfig =
             createCheckConfig(JavadocVariableCheck.class);
         checkConfig.addAttribute("scope", Scope.PUBLIC.getName());
-        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
+        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputInner.java"), expected);
     }
 
     @Test
     public void testAnother3()
-        throws Exception {
+            throws Exception {
         final DefaultConfiguration checkConfig =
             createCheckConfig(JavadocVariableCheck.class);
         final String[] expected = {
@@ -120,7 +120,7 @@ public class JavadocVariableCheckTest
 
     @Test
     public void testAnother4()
-        throws Exception {
+            throws Exception {
         final DefaultConfiguration checkConfig =
             createCheckConfig(JavadocVariableCheck.class);
         checkConfig.addAttribute("scope", Scope.PUBLIC.getName());
@@ -242,7 +242,7 @@ public class JavadocVariableCheckTest
 
     @Test
     public void testIgnoredVariableNames()
-        throws Exception {
+            throws Exception {
         final DefaultConfiguration checkConfig =
                 createCheckConfig(JavadocVariableCheck.class);
         checkConfig.addAttribute("ignoreNamePattern", "log|logger");
@@ -291,7 +291,7 @@ public class JavadocVariableCheckTest
 
     @Test
     public void testDoNotIgnoreAnythingWhenIgnoreNamePatternIsEmpty()
-        throws Exception {
+            throws Exception {
         final DefaultConfiguration checkConfig =
                 createCheckConfig(JavadocVariableCheck.class);
         checkConfig.addAttribute("ignoreNamePattern", "");
@@ -338,4 +338,13 @@ public class JavadocVariableCheckTest
                 getPath("InputNoJavadoc.java"),
                 expected);
     }
+
+    @Test
+    public void testLambdaLocalVariablesDoNotNeedJavadoc() throws Exception {
+        final DefaultConfiguration checkConfig = createCheckConfig(JavadocVariableCheck.class);
+        final String[] expected = {
+            "6:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
+        };
+        verify(checkConfig, getPath("InputNoJavadocNeededInLambda.java"), expected);
+    }
 }
