@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -25,12 +25,12 @@ import static org.junit.Assert.assertArrayEquals;
 import java.io.File;
 import java.io.IOException;
 
-import org.apache.commons.lang3.ArrayUtils;
 import org.junit.Test;
 
 import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
+import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
 public class ParameterNameCheckTest
     extends BaseCheckTestSupport {
@@ -49,17 +49,17 @@ public class ParameterNameCheckTest
 
     @Test
     public void testCatch()
-        throws Exception {
+            throws Exception {
         final DefaultConfiguration checkConfig =
             createCheckConfig(ParameterNameCheck.class);
         checkConfig.addAttribute("format", "^NO_WAY_MATEY$");
-        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
+        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputCatchOnly.java"), expected);
     }
 
     @Test
     public void testSpecified()
-        throws Exception {
+            throws Exception {
         final DefaultConfiguration checkConfig =
             createCheckConfig(ParameterNameCheck.class);
         checkConfig.addAttribute("format", "^a[A-Z][a-zA-Z0-9]*$");
@@ -76,10 +76,10 @@ public class ParameterNameCheckTest
 
     @Test
     public void testDefault()
-        throws Exception {
+            throws Exception {
         final DefaultConfiguration checkConfig =
             createCheckConfig(ParameterNameCheck.class);
-        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
+        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputSimple.java"), expected);
     }
 
@@ -95,7 +95,7 @@ public class ParameterNameCheckTest
 
     @Test
     public void testSkipMethodsWithOverrideAnnotationTrue()
-        throws Exception {
+            throws Exception {
         final DefaultConfiguration checkConfig =
             createCheckConfig(ParameterNameCheck.class);
         checkConfig.addAttribute("format", "^h$");
@@ -117,7 +117,7 @@ public class ParameterNameCheckTest
 
     @Test
     public void testSkipMethodsWithOverrideAnnotationFalse()
-        throws Exception {
+            throws Exception {
         final DefaultConfiguration checkConfig =
             createCheckConfig(ParameterNameCheck.class);
         checkConfig.addAttribute("format", "^h$");
@@ -138,13 +138,41 @@ public class ParameterNameCheckTest
         verify(checkConfig, getPath("InputOverrideAnnotation.java"), expected);
     }
 
+    @Test
+    public void testPublicAccessModifier()
+            throws Exception {
+        final DefaultConfiguration checkConfig =
+            createCheckConfig(ParameterNameCheck.class);
+        checkConfig.addAttribute("format", "^h$");
+        checkConfig.addAttribute("accessModifiers", AccessModifier.PUBLIC.toString());
+
+        final String pattern = "^h$";
+
+        final String[] expected = {
+            "5:36: " + getCheckMessage(MSG_INVALID_PATTERN, "pubconstr", pattern),
+            "9:31: " + getCheckMessage(MSG_INVALID_PATTERN, "inner", pattern),
+            "19:24: " + getCheckMessage(MSG_INVALID_PATTERN, "pubpub", pattern),
+            "30:21: " + getCheckMessage(MSG_INVALID_PATTERN, "pubifc", pattern),
+            "44:24: " + getCheckMessage(MSG_INVALID_PATTERN, "packpub", pattern),
+            "60:21: " + getCheckMessage(MSG_INVALID_PATTERN, "packifc", pattern),
+            };
+        verify(checkConfig, getPath("InputAccessModifier.java"), expected);
+    }
+
     @Test
     public void testIsOverriddenNoNullPointerException()
-        throws Exception {
+            throws Exception {
         final DefaultConfiguration checkConfig = createCheckConfig(ParameterNameCheck.class);
         checkConfig.addAttribute("format", "^[a-z][a-zA-Z0-9]*$");
         checkConfig.addAttribute("ignoreOverridden", "true");
-        final String[] expected = ArrayUtils.EMPTY_STRING_ARRAY;
+        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputOverrideAnnotationNoNPE.java"), expected);
     }
+
+    @Test
+    public void testReceiverParameter() throws Exception {
+        final DefaultConfiguration checkConfig = createCheckConfig(ParameterNameCheck.class);
+        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
+        verify(checkConfig, getPath("InputParameterNameReceiver.java"), expected);
+    }
 }
