@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -30,7 +30,6 @@ import org.junit.Before;
 import org.junit.Test;
 
 import antlr.CommonHiddenStreamToken;
-
 import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
@@ -174,6 +173,15 @@ public class NoWhitespaceAfterCheckTest
         verify(checkConfig, getPath("InputNoWhitespaceAfterArrayDeclarations2.java"), expected);
     }
 
+    @Test
+    public void testSynchronized() throws Exception {
+        checkConfig.addAttribute("tokens", "LITERAL_SYNCHRONIZED");
+        final String[] expected = {
+            "14:21: " + getCheckMessage(MSG_KEY, "synchronized"),
+        };
+        verify(checkConfig, getPath("InputNoWhitespaceAfterSynchronized.java"), expected);
+    }
+
     @Test
     public void testNpe() throws Exception {
         verify(checkConfig, getPath("InputNoWhiteSpaceAfterFormerNpe.java"));
@@ -182,16 +190,14 @@ public class NoWhitespaceAfterCheckTest
     @Test
     public void testMethodReference() throws Exception {
         final String[] expected = {
-            "10:40: " + getCheckMessage(MSG_KEY, "int"),
-            "11:63: " + getCheckMessage(MSG_KEY, "Message"),
+            "9:40: " + getCheckMessage(MSG_KEY, "int"),
+            "10:61: " + getCheckMessage(MSG_KEY, "String"),
         };
-        verify(checkConfig,
-            getNonCompilablePath("InputNoWhitespaceAfterMethodRef.java"),
-                 expected);
+        verify(checkConfig, getPath("InputNoWhitespaceAfterMethodRef.java"), expected);
     }
 
     @Test
-    public void testVisitTokenSwitchReflection() throws Exception {
+    public void testVisitTokenSwitchReflection() {
         //unexpected parent for ARRAY_DECLARATOR token
         final DetailAST astImport = mockAST(TokenTypes.IMPORT, "import", "mockfile");
         final DetailAST astArrayDeclarator = mockAST(TokenTypes.ARRAY_DECLARATOR, "[", "mockfile");
