@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -26,13 +26,12 @@ import java.io.IOException;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Locale;
+import java.util.stream.Collectors;
 
 import org.apache.commons.beanutils.ConversionException;
-import org.apache.commons.lang3.ArrayUtils;
 import org.junit.Assert;
 import org.junit.Test;
 
-import com.google.common.collect.Lists;
 import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
 import com.puppycrawl.tools.checkstyle.BriefUtLogger;
 import com.puppycrawl.tools.checkstyle.Checker;
@@ -41,13 +40,11 @@ import com.puppycrawl.tools.checkstyle.TreeWalker;
 import com.puppycrawl.tools.checkstyle.api.AuditEvent;
 import com.puppycrawl.tools.checkstyle.api.CheckstyleException;
 import com.puppycrawl.tools.checkstyle.api.Configuration;
-import com.puppycrawl.tools.checkstyle.api.LocalizedMessage;
-import com.puppycrawl.tools.checkstyle.api.SeverityLevel;
 import com.puppycrawl.tools.checkstyle.checks.FileContentsHolder;
 import com.puppycrawl.tools.checkstyle.checks.coding.IllegalCatchCheck;
 import com.puppycrawl.tools.checkstyle.checks.naming.ConstantNameCheck;
 import com.puppycrawl.tools.checkstyle.checks.naming.MemberNameCheck;
-
+import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 import nl.jqno.equalsverifier.EqualsVerifier;
 
 public class SuppressionCommentFilterTest
@@ -80,7 +77,7 @@ public class SuppressionCommentFilterTest
     @Test
     public void testNone() throws Exception {
         final DefaultConfiguration filterConfig = null;
-        final String[] suppressed = ArrayUtils.EMPTY_STRING_ARRAY;
+        final String[] suppressed = CommonUtils.EMPTY_STRING_ARRAY;
         verifySuppressed(filterConfig, suppressed);
     }
 
@@ -204,7 +201,7 @@ public class SuppressionCommentFilterTest
 
     private void verifySuppressed(Configuration aFilterConfig,
             String... aSuppressed)
-        throws Exception {
+            throws Exception {
         verify(createChecker(aFilterConfig),
                getPath("InputSuppressionCommentFilter.java"),
                removeSuppressed(ALL_MESSAGES, aSuppressed));
@@ -240,8 +237,7 @@ public class SuppressionCommentFilterTest
     }
 
     private static String[] removeSuppressed(String[] from, String... remove) {
-        final Collection<String> coll =
-            Lists.newArrayList(Arrays.asList(from));
+        final Collection<String> coll = Arrays.stream(from).collect(Collectors.toList());
         coll.removeAll(Arrays.asList(remove));
         return coll.toArray(new String[coll.size()]);
     }
@@ -265,9 +261,9 @@ public class SuppressionCommentFilterTest
         final DefaultConfiguration filterConfig =
             createFilterConfig(SuppressionCommentFilter.class);
         filterConfig.addAttribute("checkFormat", "e[l");
-        final String[] suppressed = ArrayUtils.EMPTY_STRING_ARRAY;
 
         try {
+            final String[] suppressed = CommonUtils.EMPTY_STRING_ARRAY;
             verifySuppressed(filterConfig, suppressed);
         }
         catch (CheckstyleException ex) {
@@ -282,9 +278,9 @@ public class SuppressionCommentFilterTest
         final DefaultConfiguration filterConfig =
             createFilterConfig(SuppressionCommentFilter.class);
         filterConfig.addAttribute("messageFormat", "e[l");
-        final String[] suppressed = ArrayUtils.EMPTY_STRING_ARRAY;
 
         try {
+            final String[] suppressed = CommonUtils.EMPTY_STRING_ARRAY;
             verifySuppressed(filterConfig, suppressed);
         }
         catch (CheckstyleException ex) {
@@ -302,17 +298,6 @@ public class SuppressionCommentFilterTest
         Assert.assertTrue(filter.accept(auditEvent));
     }
 
-    @Test
-    public void testAcceptNullFileContents() {
-        final LocalizedMessage message =
-            new LocalizedMessage(1, 1,
-                "messages.properties", "key", null, SeverityLevel.ERROR, null,
-                    getClass(), null);
-        final AuditEvent auditEvent = new AuditEvent(this, "Test.java", message);
-        final SuppressionCommentFilter filter = new SuppressionCommentFilter();
-        Assert.assertTrue(filter.accept(auditEvent));
-    }
-
     @Test
     public void testSuppressById() throws Exception {
         final DefaultConfiguration filterConfig =
