@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -21,6 +21,7 @@ package com.puppycrawl.tools.checkstyle.filters;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.io.IOException;
 import java.lang.reflect.Method;
@@ -57,11 +58,11 @@ public class SuppressionsLoaderTest extends BaseCheckTestSupport {
 
     @Test
     public void testNoSuppressions()
-        throws CheckstyleException {
+            throws CheckstyleException {
         final FilterSet fc =
             SuppressionsLoader.loadSuppressions(getPath("suppressions_none.xml"));
         final FilterSet fc2 = new FilterSet();
-        assertEquals(fc, fc2);
+        assertEquals(fc2, fc);
     }
 
     @Test
@@ -88,19 +89,31 @@ public class SuppressionsLoaderTest extends BaseCheckTestSupport {
         }
     }
 
-    @Test(expected = CheckstyleException.class)
-    public void testLoadFromMalformedUrl() throws CheckstyleException {
-        SuppressionsLoader.loadSuppressions("http");
+    @Test
+    public void testLoadFromMalformedUrl() {
+        try {
+            SuppressionsLoader.loadSuppressions("http");
+            fail("exception expected");
+        }
+        catch (CheckstyleException ex) {
+            assertEquals("Unable to find: http", ex.getMessage());
+        }
     }
 
-    @Test(expected = CheckstyleException.class)
-    public void testLoadFromNonExistingUrl() throws CheckstyleException {
-        SuppressionsLoader.loadSuppressions("http://^%$^* %&% %^&");
+    @Test
+    public void testLoadFromNonExistingUrl() {
+        try {
+            SuppressionsLoader.loadSuppressions("http://^%$^* %&% %^&");
+            fail("exception expected");
+        }
+        catch (CheckstyleException ex) {
+            assertEquals("Unable to find: http://^%$^* %&% %^&", ex.getMessage());
+        }
     }
 
     @Test
     public void testMultipleSuppression()
-        throws CheckstyleException {
+            throws CheckstyleException {
         final FilterSet fc =
             SuppressionsLoader.loadSuppressions(getPath("suppressions_multiple.xml"));
         final FilterSet fc2 = new FilterSet();
@@ -120,7 +133,7 @@ public class SuppressionsLoaderTest extends BaseCheckTestSupport {
         se3.setLines("1,2-3");
         se3.setColumns("1,2-3");
         fc2.addFilter(se3);
-        assertEquals(fc, fc2);
+        assertEquals(fc2, fc);
     }
 
     @Test
@@ -130,10 +143,9 @@ public class SuppressionsLoaderTest extends BaseCheckTestSupport {
             SuppressionsLoader.loadSuppressions(fn);
         }
         catch (CheckstyleException ex) {
-            assertEquals(
-                "Unable to parse " + fn + " - Attribute \"files\" is required and must be"
-                    + " specified for element type \"suppress\".",
-                ex.getMessage());
+            assertTrue(ex.getMessage().startsWith("Unable to parse " + fn));
+            assertTrue(ex.getMessage().contains("\"files\""));
+            assertTrue(ex.getMessage().contains("\"suppress\""));
         }
     }
 
@@ -144,10 +156,9 @@ public class SuppressionsLoaderTest extends BaseCheckTestSupport {
             SuppressionsLoader.loadSuppressions(fn);
         }
         catch (CheckstyleException ex) {
-            assertEquals(
-                "Unable to parse " + fn + " - Attribute \"checks\" is required and must be"
-                    + " specified for element type \"suppress\".",
-                ex.getMessage());
+            assertTrue(ex.getMessage().startsWith("Unable to parse " + fn));
+            assertTrue(ex.getMessage().contains("\"checks\""));
+            assertTrue(ex.getMessage().contains("\"suppress\""));
         }
     }
 
@@ -270,10 +281,10 @@ public class SuppressionsLoaderTest extends BaseCheckTestSupport {
 
     @Test
     public void testLoadFromClasspath()
-        throws CheckstyleException {
+            throws CheckstyleException {
         final FilterSet fc =
             SuppressionsLoader.loadSuppressions(getPath("suppressions_none.xml"));
         final FilterSet fc2 = new FilterSet();
-        assertEquals(fc, fc2);
+        assertEquals(fc2, fc);
     }
 }
