@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -24,6 +24,8 @@ import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
 import java.nio.charset.Charset;
+import java.nio.charset.StandardCharsets;
+import java.nio.file.Files;
 
 import org.antlr.v4.runtime.ANTLRInputStream;
 import org.antlr.v4.runtime.BaseErrorListener;
@@ -34,15 +36,12 @@ import org.antlr.v4.runtime.tree.ParseTree;
 import org.junit.Assert;
 import org.junit.Test;
 
-import com.google.common.base.Charsets;
-import com.google.common.io.Files;
-
 public class JavadocParseTreeTest {
-    private JavadocParser parser;
     private final BaseErrorListener errorListener = new FailOnErrorListener();
+    private JavadocParser parser;
 
     private ParseTree parseJavadoc(String aBlockComment)
-        throws IOException {
+            throws IOException {
         final Charset utf8Charset = Charset.forName("UTF-8");
         final InputStream in = new ByteArrayInputStream(aBlockComment.getBytes(utf8Charset));
 
@@ -61,8 +60,8 @@ public class JavadocParseTreeTest {
     }
 
     private static String getFileContent(File filename)
-        throws IOException {
-        return Files.toString(filename, Charsets.UTF_8);
+            throws IOException {
+        return new String(Files.readAllBytes(filename.toPath()), StandardCharsets.UTF_8);
     }
 
     private static String getPath(String filename) throws IOException {
@@ -81,7 +80,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void oneSimpleHtmlTag()
-        throws IOException {
+            throws IOException {
         final String filename = getHtmlPath("InputOneSimpleHtmlTag.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeOneSimpleHtmlTag();
@@ -90,7 +89,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void textBeforeJavadocTags()
-        throws IOException {
+            throws IOException {
         final String filename = getDocPath("InputTextBeforeJavadocTags.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeTextBeforeJavadocTags();
@@ -99,7 +98,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void customJavadocTags()
-        throws IOException {
+            throws IOException {
         final String filename = getDocPath("InputCustomJavadocTags.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeCustomJavadocTags();
@@ -108,7 +107,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void javadocTagDescriptionWithInlineTags()
-        throws IOException {
+            throws IOException {
         final String filename = getDocPath("InputJavadocTagDescriptionWithInlineTags.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeJavadocTagDescriptionWithInlineTags();
@@ -117,7 +116,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void leadingAsterisks()
-        throws IOException {
+            throws IOException {
         final String filename = getPath("InputLeadingAsterisks.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeLeadingAsterisks();
@@ -126,7 +125,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void authorWithMailto()
-        throws IOException {
+            throws IOException {
         final String filename = getDocPath("InputAuthorWithMailto.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeAuthorWithMailto();
@@ -135,7 +134,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void htmlTagsInParagraph()
-        throws IOException {
+            throws IOException {
         final String filename = getHtmlPath("InputHtmlTagsInParagraph.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeHtmlTagsInParagraph();
@@ -144,7 +143,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void linkInlineTags()
-        throws IOException {
+            throws IOException {
         final String filename = getDocPath("InputLinkInlineTags.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeLinkInlineTags();
@@ -153,7 +152,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void seeReferenceWithFewNestedClasses()
-        throws IOException {
+            throws IOException {
         final String filename = getDocPath("InputSeeReferenceWithFewNestedClasses.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeSeeReferenceWithFewNestedClasses();
@@ -162,7 +161,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void paramWithGeneric()
-        throws IOException {
+            throws IOException {
         final String filename = getDocPath("InputParamWithGeneric.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeParamWithGeneric();
@@ -171,7 +170,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void serial()
-        throws IOException {
+            throws IOException {
         final String filename = getDocPath("InputSerial.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeSerial();
@@ -180,7 +179,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void since()
-        throws IOException {
+            throws IOException {
         final String filename = getDocPath("InputSince.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeSince();
@@ -189,7 +188,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void unclosedAndClosedParagraphs()
-        throws IOException {
+            throws IOException {
         final String filename = getHtmlPath("InputUnclosedAndClosedParagraphs.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeUnclosedAndClosedParagraphs();
@@ -198,7 +197,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void listWithUnclosedItemInUnclosedParagraph()
-        throws IOException {
+            throws IOException {
         final String filename = getHtmlPath("InputListWithUnclosedItemInUnclosedParagraph.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder
@@ -208,7 +207,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void unclosedParagraphFollowedByJavadocTag()
-        throws IOException {
+            throws IOException {
         final String filename = getHtmlPath("InputUnclosedParagraphFollowedByJavadocTag.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeUnclosedParagraphFollowedByJavadocTag();
@@ -217,7 +216,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void allJavadocInlineTags()
-        throws IOException {
+            throws IOException {
         final String filename = getDocPath("InputAllJavadocInlineTags.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeAllJavadocInlineTags();
@@ -226,7 +225,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void docRootInheritDoc()
-        throws IOException {
+            throws IOException {
         final String filename = getDocPath("InputDocRootInheritDoc.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeDocRootInheritDoc();
@@ -235,7 +234,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void fewWhiteSpacesAsSeparator()
-        throws IOException {
+            throws IOException {
         final String filename = getDocPath("InputFewWhiteSpacesAsSeparator.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeFewWhiteSpacesAsSeparator();
@@ -244,7 +243,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void mixedCaseOfHtmlTags()
-        throws IOException {
+            throws IOException {
         final String filename = getHtmlPath("InputMixedCaseOfHtmlTags.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeMixedCaseOfHtmlTags();
@@ -253,7 +252,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void htmlComments()
-        throws IOException {
+            throws IOException {
         final String filename = getHtmlPath("InputComments.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeComments();
@@ -262,7 +261,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void negativeNumberInAttribute()
-        throws IOException {
+            throws IOException {
         final String filename = getHtmlPath("InputNegativeNumberInAttribute.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeNegativeNumberInAttribute();
@@ -271,7 +270,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void dollarInLink()
-        throws IOException {
+            throws IOException {
         final String filename = getDocPath("InputDollarInLink.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeDollarInLink();
@@ -280,7 +279,7 @@ public class JavadocParseTreeTest {
 
     @Test
     public void dotCharacterInCustomTags()
-        throws IOException {
+            throws IOException {
         final String filename = getDocPath("InputCustomTagWithDot.txt");
         final ParseTree generatedTree = parseJavadoc(getFileContent(new File(filename)));
         final ParseTree expectedTree = ParseTreeBuilder.treeCustomTagWithDot();
