@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -29,6 +29,7 @@ import java.util.HashSet;
 import java.util.Locale;
 import java.util.Properties;
 import java.util.Set;
+import java.util.stream.Collectors;
 
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
@@ -40,27 +41,50 @@ import org.w3c.dom.NodeList;
 
 import com.google.common.collect.ImmutableSet;
 import com.google.common.reflect.ClassPath;
+import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
+import com.puppycrawl.tools.checkstyle.api.AbstractFileSetCheck;
 import com.puppycrawl.tools.checkstyle.api.AutomaticBean;
+import com.puppycrawl.tools.checkstyle.api.BeforeExecutionFileFilter;
 import com.puppycrawl.tools.checkstyle.api.Filter;
+import com.puppycrawl.tools.checkstyle.api.RootModule;
 import com.puppycrawl.tools.checkstyle.checks.regexp.RegexpMultilineCheck;
 import com.puppycrawl.tools.checkstyle.checks.regexp.RegexpSinglelineCheck;
 import com.puppycrawl.tools.checkstyle.checks.regexp.RegexpSinglelineJavaCheck;
+import com.puppycrawl.tools.checkstyle.utils.JavadocUtils;
 import com.puppycrawl.tools.checkstyle.utils.TokenUtils;
 
 public final class CheckUtil {
     private CheckUtil() {
     }
 
-    public static Set<String> getConfigCheckStyleChecks() {
-        return getCheckStyleChecksReferencedInConfig("config/checkstyle_checks.xml");
+    public static Set<String> getConfigCheckStyleModules() {
+        return getCheckStyleModulesReferencedInConfig("config/checkstyle_checks.xml");
     }
 
-    public static Set<String> getConfigSunStyleChecks() {
-        return getCheckStyleChecksReferencedInConfig("src/main/resources/sun_checks.xml");
+    public static Set<String> getConfigSunStyleModules() {
+        return getCheckStyleModulesReferencedInConfig("src/main/resources/sun_checks.xml");
     }
 
-    public static Set<String> getConfigGoogleStyleChecks() {
-        return getCheckStyleChecksReferencedInConfig("src/main/resources/google_checks.xml");
+    public static Set<String> getConfigGoogleStyleModules() {
+        return getCheckStyleModulesReferencedInConfig("src/main/resources/google_checks.xml");
+    }
+
+    /**
+     * Retrieves a list of class names, removing 'Check' from the end if the class is
+     * a checkstyle check.
+     * @param checks class instances.
+     * @return a set of simple names.
+     */
+    public static Set<String> getSimpleNames(Set<Class<?>> checks) {
+        return checks.stream().map(check -> {
+            String name = check.getSimpleName();
+
+            if (name.endsWith("Check")) {
+                name = name.substring(0, name.length() - 5);
+            }
+
+            return name;
+        }).collect(Collectors.toSet());
     }
 
     /**
@@ -70,7 +94,7 @@ public final class CheckUtil {
      *            file path of checkstyle_checks.xml.
      * @return names of checkstyle's checks which are referenced in checkstyle_checks.xml.
      */
-    private static Set<String> getCheckStyleChecksReferencedInConfig(String configFilePath) {
+    private static Set<String> getCheckStyleModulesReferencedInConfig(String configFilePath) {
         try {
             final DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
 
@@ -102,9 +126,7 @@ public final class CheckUtil {
                 if (currentNode.getNodeType() == Node.ELEMENT_NODE) {
                     final Element module = (Element) currentNode;
                     final String checkName = module.getAttribute("name");
-                    if (!"Checker".equals(checkName) && !"TreeWalker".equals(checkName)) {
-                        checksReferencedInCheckstyleChecksXml.add(checkName);
-                    }
+                    checksReferencedInCheckstyleChecksXml.add(checkName);
                 }
             }
             return checksReferencedInCheckstyleChecksXml;
@@ -115,9 +137,11 @@ public final class CheckUtil {
     }
 
     /**
-     * Gets the checkstyle's non abstract checks.
-     * @return the set of checkstyle's non abstract check classes.
+     * Gets all checkstyle's non-abstract checks.
+     * @return the set of checkstyle's non-abstract check classes.
      * @throws IOException if the attempt to read class path resources failed.
+     * @see #isValidCheckstyleClass(Class, String)
+     * @see #isCheckstyleCheck(Class)
      */
     public static Set<Class<?>> getCheckstyleChecks() throws IOException {
         final Set<Class<?>> checkstyleChecks = new HashSet<>();
@@ -132,7 +156,8 @@ public final class CheckUtil {
         for (ClassPath.ClassInfo clazz : checkstyleClasses) {
             final String className = clazz.getSimpleName();
             final Class<?> loadedClass = clazz.load();
-            if (isCheckstyleNonAbstractCheck(loadedClass, className)) {
+            if (isValidCheckstyleClass(loadedClass, className)
+                    && isCheckstyleCheck(loadedClass)) {
                 checkstyleChecks.add(loadedClass);
             }
         }
@@ -140,12 +165,10 @@ public final class CheckUtil {
     }
 
     /**
-     * Gets the checkstyle's modules.
-     * Checkstyle's modules are nonabstract classes from com.puppycrawl.tools.checkstyle package
-     * which names end with 'Check', do not contain the word 'Input' (are not input files for UTs),
-     * checkstyle's filters and SuppressWarningsHolder class.
-     * @return a set of checkstyle's modules names.
+     * Gets all checkstyle's modules.
+     * @return the set of checkstyle's module classes.
      * @throws IOException if the attempt to read class path resources failed.
+     * @see #isCheckstyleModule(Class)
      */
     public static Set<Class<?>> getCheckstyleModules() throws IOException {
         final Set<Class<?>> checkstyleModules = new HashSet<>();
@@ -167,47 +190,83 @@ public final class CheckUtil {
     }
 
     /**
-     * Checks whether a class may be considered as the checkstyle check.
-     * Checkstyle's checks are nonabstract classes which names end with 'Check',
-     * do not contain the word 'Input' (are not input files for UTs).
-     * @param loadedClass class to check.
-     * @param className class name to check.
-     * @return true if a class may be considered as the checkstyle check.
-     */
-    private static boolean isCheckstyleNonAbstractCheck(Class<?> loadedClass, String className) {
-        return !Modifier.isAbstract(loadedClass.getModifiers())
-            && className.endsWith("Check")
-            && !className.contains("Input");
-    }
-
-    /**
-     * Checks whether a class may be considered as the checkstyle module.
-     * Checkstyle's modules are nonabstract classes which names end with 'Check',
-     * do not contain the word 'Input' (are not input files for UTs),
-     * checkstyle's filters and SuppressWarningsHolder class.
+     * Checks whether a class may be considered as a checkstyle module. Checkstyle's modules are
+     * non-abstract classes, which names do not start with the word 'Input' (are not input files for
+     * UTs), and are either checkstyle's checks, file sets, filters, file filters, or root module.
      * @param loadedClass class to check.
      * @return true if the class may be considered as the checkstyle module.
      */
     private static boolean isCheckstyleModule(Class<?> loadedClass) {
         final String className = loadedClass.getSimpleName();
-        return isCheckstyleNonAbstractCheck(loadedClass, className)
-            || isFilterModule(loadedClass, className)
-            || "SuppressWarningsHolder".equals(className)
-            || "FileContentsHolder".equals(className);
+        return isValidCheckstyleClass(loadedClass, className)
+            && (isCheckstyleCheck(loadedClass)
+                    || isFileSetModule(loadedClass)
+                    || isFilterModule(loadedClass)
+                    || isFileFilterModule(loadedClass)
+                    || isRootModule(loadedClass));
+    }
+
+    /**
+     * Checks whether a class extends 'AutomaticBean', is non-abstract, and doesn't start with the
+     * word 'Input' (are not input files for UTs).
+     * @param loadedClass class to check.
+     * @param className class name to check.
+     * @return true if a class may be considered a valid production class.
+     */
+    public static boolean isValidCheckstyleClass(Class<?> loadedClass, String className) {
+        return AutomaticBean.class.isAssignableFrom(loadedClass)
+                && !Modifier.isAbstract(loadedClass.getModifiers())
+                && !className.contains("Input");
+    }
+
+    /**
+     * Checks whether a class may be considered as the checkstyle check.
+     * Checkstyle's checks are classes which implement 'AbstractCheck' interface.
+     * @param loadedClass class to check.
+     * @return true if a class may be considered as the checkstyle check.
+     */
+    public static boolean isCheckstyleCheck(Class<?> loadedClass) {
+        return AbstractCheck.class.isAssignableFrom(loadedClass);
+    }
+
+    /**
+     * Checks whether a class may be considered as the checkstyle file set.
+     * Checkstyle's file sets are classes which implement 'AbstractFileSetCheck' interface.
+     * @param loadedClass class to check.
+     * @return true if a class may be considered as the checkstyle file set.
+     */
+    public static boolean isFileSetModule(Class<?> loadedClass) {
+        return AbstractFileSetCheck.class.isAssignableFrom(loadedClass);
     }
 
     /**
      * Checks whether a class may be considered as the checkstyle filter.
-     * Checkstyle's filters are classes which are subclasses of AutomaticBean,
-     * implement 'Filter' interface, and which names end with 'Filter'.
+     * Checkstyle's filters are classes which implement 'Filter' interface.
      * @param loadedClass class to check.
-     * @param className class name to check.
      * @return true if a class may be considered as the checkstyle filter.
      */
-    private static boolean isFilterModule(Class<?> loadedClass, String className) {
-        return Filter.class.isAssignableFrom(loadedClass)
-            && AutomaticBean.class.isAssignableFrom(loadedClass)
-            && className.endsWith("Filter");
+    public static boolean isFilterModule(Class<?> loadedClass) {
+        return Filter.class.isAssignableFrom(loadedClass);
+    }
+
+    /**
+     * Checks whether a class may be considered as the checkstyle file filter.
+     * Checkstyle's file filters are classes which implement 'BeforeExecutionFileFilter' interface.
+     * @param loadedClass class to check.
+     * @return true if a class may be considered as the checkstyle file filter.
+     */
+    public static boolean isFileFilterModule(Class<?> loadedClass) {
+        return BeforeExecutionFileFilter.class.isAssignableFrom(loadedClass);
+    }
+
+    /**
+     * Checks whether a class may be considered as the checkstyle root module.
+     * Checkstyle's root modules are classes which implement 'RootModule' interface.
+     * @param loadedClass class to check.
+     * @return true if a class may be considered as the checkstyle root module.
+     */
+    public static boolean isRootModule(Class<?> loadedClass) {
+        return RootModule.class.isAssignableFrom(loadedClass);
     }
 
     /**
@@ -253,24 +312,32 @@ public final class CheckUtil {
      * Gets the check message 'as is' from appropriate 'messages.properties'
      * file.
      *
-     * @param messageKey the key of message in 'messages.properties' file.
-     * @param arguments the arguments of message in 'messages.properties' file.
+     * @param locale the locale to get the message for.
+     * @param messageKey the key of message in 'messages*.properties' file.
+     * @param arguments the arguments of message in 'messages*.properties' file.
      * @return the check's formatted message.
      */
-    public static String getCheckMessage(Class<?> module, String messageKey, Object... arguments) {
+    public static String getCheckMessage(Class<?> module, Locale locale, String messageKey,
+            Object... arguments) {
         final Properties pr = new Properties();
         try {
-            pr.load(module.getResourceAsStream("messages.properties"));
+            if (locale == Locale.ENGLISH) {
+                pr.load(module.getResourceAsStream("messages.properties"));
+            }
+            else {
+                pr.load(module
+                        .getResourceAsStream("messages_" + locale.getLanguage() + ".properties"));
+            }
         }
         catch (IOException ex) {
             return null;
         }
-        final MessageFormat formatter = new MessageFormat(pr.getProperty(messageKey), Locale.ROOT);
+        final MessageFormat formatter = new MessageFormat(pr.getProperty(messageKey), locale);
         return formatter.format(arguments);
     }
 
     public static String getTokenText(int[] tokens, int... subtractions) {
-        if (Arrays.equals(tokens, TokenUtils.getAllTokenIds()) && subtractions.length == 0) {
+        if (subtractions.length == 0 && Arrays.equals(tokens, TokenUtils.getAllTokenIds())) {
             return "TokenTypes.";
         }
         else {
@@ -311,4 +378,52 @@ public final class CheckUtil {
             return result.toString();
         }
     }
+
+    public static Set<String> getTokenTextSet(int... tokens) {
+        final Set<String> result = new HashSet<>();
+
+        for (int token : tokens) {
+            result.add(TokenUtils.getTokenName(token));
+        }
+
+        return result;
+    }
+
+    public static String getJavadocTokenText(int[] tokens, int... subtractions) {
+        final StringBuilder result = new StringBuilder();
+        boolean first = true;
+
+        for (int token : tokens) {
+            boolean found = false;
+
+            for (int subtraction : subtractions) {
+                if (subtraction == token) {
+                    found = true;
+                    break;
+                }
+            }
+
+            if (found) {
+                continue;
+            }
+
+            if (first) {
+                first = false;
+            }
+            else {
+                result.append(", ");
+            }
+
+            result.append(JavadocUtils.getTokenName(token));
+        }
+
+        if (result.length() == 0) {
+            result.append("empty");
+        }
+        else {
+            result.append(".");
+        }
+
+        return result.toString();
+    }
 }
