@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -38,7 +38,7 @@ import org.w3c.dom.NodeList;
 import org.xml.sax.SAXException;
 
 public final class XDocUtil {
-    private static final String DIRECTORY_PATH = "src/xdocs";
+    public static final String DIRECTORY_PATH = "src/xdocs";
 
     private XDocUtil() {
     }
@@ -50,8 +50,8 @@ public final class XDocUtil {
      */
     public static Set<Path> getXdocsFilePaths() throws IOException {
         final Path directory = Paths.get(DIRECTORY_PATH);
-        final Set<Path> xdocs = new HashSet<>();
         try (DirectoryStream<Path> stream = Files.newDirectoryStream(directory, "*.xml")) {
+            final Set<Path> xdocs = new HashSet<>();
             for (Path entry : stream) {
                 xdocs.add(entry);
             }
