@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -21,6 +21,7 @@ package com.puppycrawl.tools.checkstyle.utils;
 
 import static com.puppycrawl.tools.checkstyle.internal.TestUtils.assertUtilsClassHasPrivateConstructor;
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.fail;
 
 import org.junit.Assert;
 import org.junit.Test;
@@ -36,13 +37,13 @@ public class CheckUtilsTest {
     }
 
     @Test
-    public void testParseDoubleWithIncorrectToken() throws Exception {
+    public void testParseDoubleWithIncorrectToken() {
         final double parsedDouble = CheckUtils.parseDouble("1_02", TokenTypes.ASSIGN);
         assertEquals(0.0, parsedDouble, 0.0);
     }
 
     @Test
-    public void testElseWithCurly() throws Exception {
+    public void testElseWithCurly() {
         final DetailAST ast = new DetailAST();
         ast.setType(TokenTypes.ASSIGN);
         ast.setText("ASSIGN");
@@ -75,7 +76,7 @@ public class CheckUtilsTest {
     }
 
     @Test
-    public void testEquals() throws Exception {
+    public void testEquals() {
         final DetailAST litStatic = new DetailAST();
         litStatic.setType(TokenTypes.LITERAL_STATIC);
 
@@ -112,7 +113,34 @@ public class CheckUtilsTest {
         metDef.addChild(parameters);
 
         Assert.assertFalse(CheckUtils.isEqualsMethod(metDef));
-
     }
 
+    @Test
+    public void testGetAccessModifierFromModifiersTokenWrongTokenType() {
+        final DetailAST modifiers = new DetailAST();
+        modifiers.setType(TokenTypes.METHOD_DEF);
+
+        try {
+            CheckUtils.getAccessModifierFromModifiersToken(modifiers);
+            fail(IllegalArgumentException.class.getSimpleName() + " was expcted.");
+        }
+        catch (IllegalArgumentException exc) {
+            final String expectedExceptionMsg = "expected non-null AST-token with type 'MODIFIERS'";
+            final String actualExceptionMsg = exc.getMessage();
+            assertEquals(expectedExceptionMsg, actualExceptionMsg);
+        }
+    }
+
+    @Test
+    public void testGetAccessModifierFromModifiersTokenWithNullParameter() {
+        try {
+            CheckUtils.getAccessModifierFromModifiersToken(null);
+            fail(IllegalArgumentException.class.getSimpleName() + " was expcted.");
+        }
+        catch (IllegalArgumentException exc) {
+            final String expectedExceptionMsg = "expected non-null AST-token with type 'MODIFIERS'";
+            final String actualExceptionMsg = exc.getMessage();
+            assertEquals(expectedExceptionMsg, actualExceptionMsg);
+        }
+    }
 }
