@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -62,8 +62,7 @@ public class CommonUtilsTest {
      * Test CommonUtils.countCharInString.
      */
     @Test
-    public void testLengthExpandedTabs()
-        throws Exception {
+    public void testLengthExpandedTabs() {
         final String s1 = "\t";
         assertEquals(8, CommonUtils.lengthExpandedTabs(s1, s1.length(), 8));
 
@@ -82,14 +81,26 @@ public class CommonUtilsTest {
         assertEquals(3, CommonUtils.lengthMinusTrailingWhitespace(" 23 \t "));
     }
 
-    @Test(expected = ConversionException.class)
+    @Test
     public void testBadRegex() {
-        CommonUtils.createPattern("[");
+        try {
+            CommonUtils.createPattern("[");
+            fail("exception expected");
+        }
+        catch (ConversionException ex) {
+            assertEquals("Failed to initialise regular expression [", ex.getMessage());
+        }
     }
 
-    @Test(expected = ConversionException.class)
+    @Test
     public void testBadRegex2() {
-        CommonUtils.createPattern("[", Pattern.MULTILINE);
+        try {
+            CommonUtils.createPattern("[", Pattern.MULTILINE);
+            fail("exception expected");
+        }
+        catch (ConversionException ex) {
+            assertEquals("Failed to initialise regular expression [", ex.getMessage());
+        }
     }
 
     @Test
@@ -197,15 +208,24 @@ public class CommonUtilsTest {
         assertTrue(closeable.closed);
     }
 
-    @Test(expected = IllegalStateException.class)
+    @Test
     public void testCloseWithException() {
-        CommonUtils.close(new Closeable() {
-
-            @Override
-            public void close() throws IOException {
+        try {
+            CommonUtils.close(() -> {
                 throw new IOException("Test IOException");
-            }
-        });
+            });
+            fail("exception expected");
+        }
+        catch (IllegalStateException ex) {
+            assertEquals("Cannot close the stream", ex.getMessage());
+        }
+    }
+
+    @Test
+    public void testGetFileExtensionForFileNameWithoutExtension() {
+        final String fileNameWithoutExtension = "file";
+        final String extension = CommonUtils.getFileExtension(fileNameWithoutExtension);
+        assertEquals("", extension);
     }
 
     @Test
