@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2017 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -215,18 +215,36 @@ public class JavadocUtilsTest {
         assertEquals("EOF", JavadocUtils.getTokenName(JavadocTokenTypes.EOF));
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testGetTokenNameForLargeId() {
-        JavadocUtils.getTokenName(20074);
+        try {
+            JavadocUtils.getTokenName(20074);
+            fail("exception expected");
+        }
+        catch (IllegalArgumentException ex) {
+            assertEquals("Unknown javadoc token id. Given id: 20074", ex.getMessage());
+        }
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testGetTokenNameForInvalidId() {
-        JavadocUtils.getTokenName(100);
+        try {
+            JavadocUtils.getTokenName(100);
+            fail("exception expected");
+        }
+        catch (IllegalArgumentException ex) {
+            assertEquals("Unknown javadoc token id. Given id: 100", ex.getMessage());
+        }
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testGetTokenIdThatIsUnknown() {
-        JavadocUtils.getTokenId("");
+        try {
+            JavadocUtils.getTokenId("");
+            fail("exception expected");
+        }
+        catch (IllegalArgumentException ex) {
+            assertEquals("Unknown javadoc token name. Given name ", ex.getMessage());
+        }
     }
 }
