@@ -1,6 +1,6 @@
 package com.puppycrawl.tools.checkstyle.checks.javadoc;
 
-import com.google.common.base.Function;
+import java.util.function.Function;
 
 class Foo5 {
 
