@@ -25,4 +25,10 @@ public class InputJavadocMethodsNotSkipWritten {
     @MyAnnotation
     public void test2() {
     }
+
+    /** Description. */
+    @MyAnnotation
+    public String test3(int a) throws Exception {
+        return "";
+    }
 }
