@@ -9,10 +9,10 @@ import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;
 import java.lang.annotation.RetentionPolicy;
 import java.lang.annotation.Target;
+import java.util.function.Function;
+import java.util.function.Supplier;
+
 
-import com.google.common.annotations.GwtCompatible;
-import com.google.common.base.Function;
-import com.google.common.base.Supplier;
 
 class myFoo
 {
@@ -23,7 +23,7 @@ class myFoo
 	private void foo()
 	{
 		int i = 0;
-		String[][] x = {{"foo"}};
+		String[][] x = { {"foo"} };
 		int len = 0;
 		String sequence = null;
 		for (int first = 0; first < len && matches(sequence.charAt(first)); first++) {}
@@ -56,7 +56,7 @@ class WithEmptyAnonymous
 @Target(
     ElementType.ANNOTATION_TYPE)
 @Documented
-@GwtCompatible
+@Deprecated
 @interface Beta {}
 @interface MapFeature {
 	@interface Require {
