@@ -1,6 +1,6 @@
 package com.puppycrawl.tools.checkstyle.checks.whitespace;
 
-import com.google.common.annotations.Beta;
+import com.puppycrawl.tools.checkstyle.TreeWalker;
 
 import javax.accessibility.AccessibleAttributeSequence;
 import java.util.concurrent.atomic.AtomicIntegerFieldUpdater;
